@@ -328,7 +328,7 @@ class SpecialJordanAlgebra(JordanAlgebra):
     algebra_generators = basis
 
     # TODO: Keep this until we can better handle R.<...> shorthand
-    def gens(self):
+    def gens(self) -> tuple:
         """
         Return the generators of ``self``.
 
@@ -426,7 +426,7 @@ class SpecialJordanAlgebra(JordanAlgebra):
 
         def __bool__(self) -> bool:
             """
-            Return if ``self`` is non-zero.
+            Return if ``self`` is nonzero.
 
             EXAMPLES::
 
@@ -583,9 +583,9 @@ class SpecialJordanAlgebra(JordanAlgebra):
 
             INPUT:
 
-            - ``copy`` -- (default: ``True``) if ``self`` is internally
-              represented by a dictionary ``d``, then make a copy of ``d``;
-              if ``False``, then this can cause undesired behavior by
+            - ``copy`` -- boolean (default: ``True``); if ``self`` is
+              internally represented by a dictionary ``d``, then make a copy of
+              ``d``; if ``False``, then this can cause undesired behavior by
               mutating ``d``
 
             EXAMPLES::
@@ -763,7 +763,7 @@ class JordanAlgebraSymmetricBilinear(JordanAlgebra):
 
     algebra_generators = basis
 
-    def gens(self):
+    def gens(self) -> tuple:
         """
         Return the generators of ``self``.
 
@@ -851,7 +851,7 @@ class JordanAlgebraSymmetricBilinear(JordanAlgebra):
 
         def __bool__(self) -> bool:
             """
-            Return if ``self`` is non-zero.
+            Return if ``self`` is nonzero.
 
             TESTS::
 
@@ -1298,7 +1298,6 @@ class ExceptionalJordanAlgebra(JordanAlgebra):
             sage: len(B)
             27
         """
-        import itertools
         R = self.base_ring()
         OB = self._O.basis()
         base = [R.zero()] * 3 + [self._O.zero()] * 3
@@ -1316,7 +1315,7 @@ class ExceptionalJordanAlgebra(JordanAlgebra):
 
     algebra_generators = basis
 
-    def gens(self):
+    def gens(self) -> tuple:
         """
         Return the generators of ``self``.
 
@@ -1571,7 +1570,7 @@ class ExceptionalJordanAlgebra(JordanAlgebra):
 
         def __bool__(self) -> bool:
             """
-            Return if ``self`` is non-zero.
+            Return if ``self`` is nonzero.
 
             TESTS::
 
