@@ -29,13 +29,13 @@ class NilpotentLieAlgebra_dense(LieAlgebraWithStructureCoefficients):
     INPUT:
 
     - ``R`` -- the base ring
-    - ``s_coeff`` -- a dictionary of structural coefficients
-    - ``names`` -- (default:``None``) list of strings to use as names of basis
+    - ``s_coeff`` -- dictionary of structural coefficients
+    - ``names`` -- (default: ``None``) list of strings to use as names of basis
       elements; if ``None``, the names will be inferred from the structural
       coefficients
-    - ``index_set`` -- (default:``None``) list of hashable and comparable
+    - ``index_set`` -- (default: ``None``) list of hashable and comparable
       elements to use for indexing
-    - ``step`` -- (optional) an integer; the nilpotency step of the
+    - ``step`` -- integer (optional); the nilpotency step of the
       Lie algebra if known; otherwise it will be computed when needed
     - ``category`` -- (optional) a subcategory of finite dimensional
       nilpotent Lie algebras with basis
@@ -174,9 +174,9 @@ class FreeNilpotentLieAlgebra(NilpotentLieAlgebra_dense):
     INPUT:
 
     - ``R`` -- the base ring
-    - ``r`` -- an integer; the number of generators
-    - ``s`` -- an integer; the nilpotency step of the algebra
-    - ``names`` -- (optional) a string or a list of strings used to name the
+    - ``r`` -- integer; the number of generators
+    - ``s`` -- integer; the nilpotency step of the algebra
+    - ``names`` -- (optional) string or list of strings used to name the
       basis elements; if ``names`` is a string, then names for the basis
       will be autogenerated as determined by the ``naming`` parameter
     - ``naming`` -- (optional) a string; the naming scheme to use for
@@ -340,7 +340,7 @@ class FreeNilpotentLieAlgebra(NilpotentLieAlgebra_dense):
 
     def __init__(self, R, r, s, names, naming, category, **kwds):
         r"""
-        Initialize ``self``
+        Initialize ``self``.
 
         EXAMPLES::
 
