@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.combinat sage.groups sage.modules
 r"""
 `q`-Commuting Polynomials
 
@@ -146,7 +147,7 @@ class qCommutingPolynomials_generic(CombinatorialFreeModule):
         return self.monomial(self._indices.gen(i))
 
     @cached_method
-    def gens(self):
+    def gens(self) -> tuple:
         r"""
         Return the generators of ``self``.
 
@@ -172,7 +173,7 @@ class qCommutingPolynomials_generic(CombinatorialFreeModule):
             Finite family {'x': x, 'y': y, 'z': z}
         """
         d = {v: self.gen(i) for i, v in enumerate(self.variable_names())}
-        return Family(self.variable_names(), d.__getitem__, name="generator")
+        return Family(self.variable_names(), d.__getitem__, name='generator')
 
     def degree_on_basis(self, m):
         r"""
