@@ -5,6 +5,7 @@ Weyl Algebras
 AUTHORS:
 
 - Travis Scrimshaw (2013-09-06): Initial version
+- Joseph McDonough (2025-06-13): Added ``InfGenDifferentialWeylAlgebra``
 """
 
 # ****************************************************************************
@@ -25,12 +26,14 @@ from sage.structure.parent import Parent
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.categories.action import Action
 from sage.categories.rings import Rings
-from sage.categories.algebras_with_basis import AlgebrasWithBasis
+from sage.categories.cartesian_product import cartesian_product
 from sage.sets.family import Family
 import sage.data_structures.blas_dict as blas
 from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
 from sage.rings.polynomial.multi_polynomial_ring_base import MPolynomialRing_base
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+from sage.rings.polynomial.infinite_polynomial_ring import InfinitePolynomialRing_dense
+from sage.rings.polynomial.infinite_polynomial_element import InfinitePolynomial
 from sage.structure.global_options import GlobalOptions
 from sage.modules.with_basis.indexed_element import IndexedFreeModuleElement
 
@@ -257,6 +260,13 @@ class DifferentialWeylAlgebraElement(IndexedFreeModuleElement):
         False
         sage: x + 1 == 1
         False
+        sage: a = (x*y + z) * dx
+        sage: 3/2 * a
+        3/2*x*y*dx + 3/2*z*dx
+        sage: a * 3/2
+        3/2*x*y*dx + 3/2*z*dx
+        sage: a / 2
+        1/2*x*y*dx + 1/2*z*dx
         sage: W(x^3 - y*z) == x^3 - y*z
         True
         sage: W.<x,y,z> = DifferentialWeylAlgebra(QQ)
@@ -665,7 +675,7 @@ class DifferentialWeylAlgebra(UniqueRepresentation, Parent):
         they are considered to be graded rings (algebras).
     """
     @staticmethod
-    def __classcall__(cls, R, names=None):
+    def __classcall_private__(cls, R, names=None, n=None):
         """
         Normalize input to ensure a unique representation.
 
@@ -676,17 +686,22 @@ class DifferentialWeylAlgebra(UniqueRepresentation, Parent):
             sage: W1 is W2
             True
         """
+        from sage.rings.infinity import PlusInfinity
+        if n is PlusInfinity():  # hook for Infinite weyl algebra
+            return InfGenDifferentialWeylAlgebra(R, names)
         if isinstance(R, (PolynomialRing_generic, MPolynomialRing_base)):
             if names is None:
                 names = R.variable_names()
                 R = R.base_ring()
+        elif isinstance(R, InfinitePolynomialRing_dense) and names is None:
+            return InfGenDifferentialWeylAlgebra(R.base_ring(), R.variable_names())
         elif names is None:
             raise ValueError("the names must be specified")
         elif R not in Rings().Commutative():
             raise TypeError("argument R must be a commutative ring")
         return super().__classcall__(cls, R, names)
 
-    def __init__(self, R, names=None) -> None:
+    def __init__(self, R, names=None, n=None) -> None:
         r"""
         Initialize ``self``.
 
@@ -696,6 +711,8 @@ class DifferentialWeylAlgebra(UniqueRepresentation, Parent):
             sage: W = DifferentialWeylAlgebra(R)
             sage: TestSuite(W).run()
         """
+        from sage.categories.algebras_with_basis import AlgebrasWithBasis
+
         self._n = len(names)
         self._poly_ring = PolynomialRing(R, names)
         names = names + tuple('d' + n for n in names)
@@ -899,13 +916,13 @@ class DifferentialWeylAlgebra(UniqueRepresentation, Parent):
         def elt_map(u):
             return (tuple(u[:n]), tuple(u[n:]))
 
-        I = IntegerListsNN(length=2 * n, element_constructor=elt_map)
+        index_set = IntegerListsNN(length=2 * n, element_constructor=elt_map)
         one = self.base_ring().one()
 
         def f(x):
             return self.element_class(self, {(x[0], x[1]): one})
 
-        return Family(I, f, name="basis map")
+        return Family(index_set, f, name="basis map")
 
     @cached_method
     def algebra_generators(self):
@@ -1123,3 +1140,525 @@ class DifferentialWeylAlgebraAction(Action):
         D = {y: c for (y, dy), c in f.monomial_coefficients(copy=False).items()
              if all(dyi == 0 for dyi in dy)}
         return self.right_domain()(D)
+
+
+class InfGenDifferentialWeylAlgebraElement(IndexedFreeModuleElement):
+    """
+    An element of an infinitely generated differential Weyl algebra.
+
+    EXAMPLES::
+
+        sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+        sage: W.inject_variables(verbose=False)
+        sage: W.zero() == 0
+        True
+        sage: W.one() == 1
+        True
+        sage: W.zero() == 1
+        False
+        sage: x[1] == 1
+        False
+        sage: W(x[1]) == x[1]
+        True
+        sage: W(dx[1]) == dx[1]
+        True
+        sage: W(x[1] + dx[2]^2) == x[1] + dx[2]^2
+        True
+        sage: x[1] == x[11]
+        False
+        sage: x[1] / 2
+        1/2*x[1]
+        sage: W(2) / 2
+        1
+        sage: (x[1] + dx[1]) * (-4/3)
+        -4/3*dx[1] - 4/3*x[1]
+        sage: (-4/3) * (x[1] + dx[1])
+        -4/3*dx[1] - 4/3*x[1]
+    """
+    def _repr_(self) -> str:
+        """
+        Return a string representation of ``self``.
+
+        TESTS::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: dx = W.differentials()
+            sage: dx[1]^2*x[1]^2
+            x[1]^2*dx[1]^2 + 4*x[1]*dx[1] + 2
+        """
+        def term(m):
+            res = ''
+            if not m[0].is_one():
+                res += m[0]._repr_()
+            if not m[1].is_one():
+                if res != '':
+                    res += '*'
+                res += m[1]._repr_()
+            return res if res != '' else '1'
+        return repr_from_monomials(self.list(), term)
+
+    def _mul_(self, other):
+        """
+        Multiply ``self`` by ``other``.
+
+        TESTS::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: dx = W.differentials()
+            sage: dx[1]*(x[1]*x[2] + x[3])
+            x[1]*x[2]*dx[1] + x[3]*dx[1] + x[2]
+            sage: dx[132]*x[132] - x[132]*dx[132] == 1
+            True
+        """
+        out = {}
+        zero = self.parent().base_ring().zero()
+        zero_m = self.parent()._diff_index.one()
+        # multiply each pair of monomials
+        for ml in self._monomial_coefficients:
+            cl = self._monomial_coefficients[ml]
+            for mr in other._monomial_coefficients:
+                cr = other._monomial_coefficients[mr]
+                # apply derivative terms of ml to mr and simplify
+                cur = [((mr[0], zero_m), cl*cr)]
+                ldd = ml[1].dict()
+
+                for i in ldd:
+                    p = ldd[i]
+                    # applying dx[i] p times
+                    for _ in range(p):
+                        next = []
+                        for m, c in cur:
+                            diff = m[1].dict()
+                            diff[i] = diff.get(i, zero) + 1
+                            next.append(((m[0], self.parent()._diff_index(diff)), c))
+                            # power rule if m has x[i] term
+                            poly = m[0].dict()
+                            if i in poly:
+                                c *= poly[i]
+                                poly[i] -= 1
+                                next.append(((self.parent()._var_index(poly), m[1]), c))
+                        cur = next
+
+                for m, c in cur:
+                    m = (ml[0] * m[0], m[1] * mr[1])
+                    out[m] = out.get(m, zero) + c
+                    if out[m] == zero:
+                        del out[m]
+        return self.__class__(self.parent(), out)
+
+    def __iter__(self):
+        """
+        Return an iterator of ``self``.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ,n=oo)
+            sage: dx = W.differentials()
+            sage: p = x[5] + dx[1]*x[1]
+            sage: list(p)
+            [((x[1], dx[1]), 1), ((x[5], 1), 1), ((1, 1), 1)]
+        """
+        return iter(self.list())
+
+    def list(self):
+        """
+        Return ``self`` as a list.
+
+        This list consists of pairs `(m, c)` where `m` is a pair of
+        :class:`IndexedFreeAbelianMonoid<sage.monoids.indexed_free_monoid.IndexedFreeAbelianMonoid>`
+        elements indexing a basis element of ``self``, and `c` is the
+        corresponding (nonzero) coefficient. The list is sorted using graded lex
+        order on the differentials, followed by graded lex order on the
+        polynomial generators.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: dx = W.differentials()
+            sage: p = x[5] + dx[1]*x[1]
+            sage: p.list()
+            [((x[1], dx[1]), 1), ((x[5], 1), 1), ((1, 1), 1)]
+        """
+        return sorted(self._monomial_coefficients.items(),
+                      key=lambda x: (-x[0][1].length(), x[0][1], -x[0][0].length(), x[0][0]))
+
+
+class InfGenDifferentialWeylAlgebra(UniqueRepresentation, Parent):
+    r"""
+    The differential Weyl algebra of the polynomial ring in countably many
+    variables.
+
+    Let `R` be a commutative ring, and `\{x_i\}` a countable family of
+    indeterminants. The differential Weyl algebra `W` is an `R`-algebra
+    generated by symbols `x_i`, and `\partial_{x_i}`, subject to the relations
+    `[x_i,x_j] = [\partial_{x_i}, \partial_{x_j}] = 0`, and
+    `[\partial_{x_i}, x_j] = \delta_{ij}`.
+
+    INPUT:
+
+    - ``R`` -- a commutative ring
+    - ``names`` -- length 1 tuple of strings denoting the prefix
+      for the variable names
+
+    EXAMPLES:
+
+    We construct an infinite Weyl algebra by using ``n=oo`` in
+    :class:`DifferentialWeylAlgebra`::
+
+        sage: W.<y> = DifferentialWeylAlgebra(QQ, n=oo); W
+        Differential Weyl algebra in countably many variables y over Rational Field
+
+    Alternatively, one can first define an
+    :class:`InfinitePolynomialRing`<sage.rings.infinite_polynomial_ring.InfinitePolynomialRing_dense>`
+    and then define the differential Weyl algebra of that ring::
+
+        sage: R.<x> = InfinitePolynomialRing(QQ)
+        sage: W = DifferentialWeylAlgebra(R); W
+        Differential Weyl algebra in countably many variables x over Rational Field
+
+    .. WARNING::
+
+        Due to a bug in ``InfinitePolynomialRing`` (:issue:`36788`) trying to define the infinite Weyl
+        algebra of an infinite polynomial ring with coefficients in another infinite
+        polynomial ring will result in unexpected behavior::
+
+            sage: R.<x> = InfinitePolynomialRing(QQ)
+            sage: R2.<y> = InfinitePolynomialRing(R)
+            sage: W = DifferentialWeylAlgebra(R2); W # known bug
+            Differential Weyl algebra in countably many variables y over Infinite
+            polynomial ring in x over Rational Field
+
+
+    To access the variables, we can call ``W.inject_variables()``. The symbols
+    defined are families that allow you to access the `i`'th polynomial or differential
+    generator for each nonnegative integer `i`. Alternatively, we can access the families
+    directly using the :meth:`polynomial_gens` and :meth:`differentials` methods
+    respectively::
+
+        sage: W.inject_variables()
+        Defining x, dx
+        sage: dx
+        Lazy family (dx(i))_{i in Non negative integers}
+        sage: dx[1]*x[1] - x[1]*dx[1]
+        1
+        sage: (dx[1] + x[1]*dx[2])*(x[5]*dx[1] + 1)
+        x[5]*dx[1]^2 + x[1]*x[5]*dx[1]*dx[2] + dx[1] + x[1]*dx[2]
+
+    TESTS::
+
+        sage: R1.<x> = InfinitePolynomialRing(QQ)
+        sage: W = DifferentialWeylAlgebra(R1['y']); W
+        Differential Weyl algebra of polynomials in y over Infinite polynomial
+         ring in x over Rational Field
+        sage: W.inject_variables(verbose=False); R1.inject_variables(verbose=False)
+        sage: dy*x[1]*y
+        x_1*y*dy + x_1
+        sage: R2.<x> = InfinitePolynomialRing(QQ['y'])
+        sage: W = DifferentialWeylAlgebra(R2); W
+        Differential Weyl algebra in countably many variables x over Univariate
+         Polynomial Ring in y over Rational Field
+        sage: W.differential(1)*R2.base_ring()('y')*W.gen(1)
+        y*x[1]*dx[1] + y
+    """
+    @staticmethod
+    def __classcall_private__(cls, R, names=None):
+        """
+        Normalize input to ensure a unique representation.
+
+        EXAMPLES::
+
+            sage: W1.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: R = InfinitePolynomialRing(QQ)
+            sage: W2 = DifferentialWeylAlgebra(R, n=oo)
+            sage: W1 is W2
+            True
+        """
+        if isinstance(R, InfinitePolynomialRing_dense) and names is None:
+            names = R.variable_names()
+            if len(names) > 1:
+                raise NotImplementedError("only one set of variables supported")
+            R = R.base_ring()
+        if R not in Rings().Commutative():
+            raise TypeError("argument R must be a commutative ring")
+        return super().__classcall__(cls, R, tuple(names))
+
+    def __init__(self, R, names=None):
+        """
+        Initialize ``self``.
+
+        EXAMPLES::
+
+            sage: R = InfinitePolynomialRing(QQ)
+            sage: W = DifferentialWeylAlgebra(R, n=oo)
+            sage: W.inject_variables()
+            Defining x, dx
+            sage: TestSuite(W).run()
+        """
+        from sage.categories.algebras_with_basis import AlgebrasWithBasis
+        from sage.monoids.indexed_free_monoid import IndexedFreeAbelianMonoid
+        from sage.sets.non_negative_integers import NonNegativeIntegers
+
+        names = (names[0], 'd' + names[0])
+        # could probably get away with only using one copy, but the distinction is nice
+        self._var_index = IndexedFreeAbelianMonoid(NonNegativeIntegers(), prefix=names[0])
+        self._diff_index = IndexedFreeAbelianMonoid(NonNegativeIntegers(), prefix=names[1])
+        if R.is_field():
+            cat = AlgebrasWithBasis(R).NoZeroDivisors().Super()
+        else:
+            cat = AlgebrasWithBasis(R).Super()
+        Parent.__init__(self, base=R, names=names, category=cat)
+
+    def _repr_(self) -> str:
+        """
+        Return a string representation of ``self``.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo); W
+            Differential Weyl algebra in countably many variables x over Rational Field
+        """
+        return f"Differential Weyl algebra in countably many variables {self.variable_names()[0]} over {self.base_ring()}"
+
+    def _element_constructor_(self, x):
+        """
+        Construct an element of ``self`` from ``x``.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: W(1)
+            1
+            sage: a = W(x[1]); a.parent() is W
+            True
+            sage: R.<x> = InfinitePolynomialRing(QQ)
+            sage: W(x[0]^2 + x[1]*x[3] + x[2])
+            x[0]^2 + x[1]*x[3] + x[2]
+        """
+        R = self.base_ring()
+        if x in R:
+            if x == self.base_ring().zero():
+                return self.zero()
+            return self.element_class(self, {(self._var_index.one(), self._diff_index.one()): x})
+
+        if isinstance(x, InfinitePolynomial):
+            if x.parent().base_ring() is R:
+                return self.element_class(self, {
+                    (prod(self._var_index.gen(len(m)-i-1)**m[i] for i in range(len(m))),
+                     self._diff_index.one()): R(c) for m, c in x.monomial_coefficients().items()
+                })
+        if isinstance(x, InfGenDifferentialWeylAlgebraElement):
+            if x.parent().base_ring() is R:
+                return self.element_class(self, dict(x))
+            # attempt to coerce coefficients to R
+            zero = R.zero()
+            return self.element_class(self, {m: R(c) for m, c in x if R(c) != zero})
+
+        return self.element_class(self,
+                                  {(self._var_index(m[0]),
+                                    self._diff_index(m[1])): R(c)
+                                      for m, c in x.items()})
+
+    def _coerce_map_from_(self, R):
+        """
+        Return data which determines if there is a coercion map
+        from ``R`` to ``self``.
+
+        If such a map exists, the output could be a map, callable,
+        or ``True``, which constructs a generic map. Otherwise the output
+        must be ``False`` or ``None``.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: dx = W.differentials()
+            sage: W2.<x> = DifferentialWeylAlgebra(ZZ, n=oo)
+            sage: W._coerce_map_from_(W2)
+            True
+            sage: W3.<y> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: W._coerce_map_from_(W3)
+            False
+            sage: R.<x> = InfinitePolynomialRing(QQ)
+            sage: W._coerce_map_from_(R)
+            True
+            sage: dx[1]*R(x[1])
+            x[1]*dx[1] + 1
+        """
+        if isinstance(R, InfGenDifferentialWeylAlgebra):
+            return (self.variable_names() == R.variable_names()
+                    and self.base_ring().has_coerce_map_from(R.base_ring()))
+
+        if isinstance(R, InfinitePolynomialRing_dense):
+            return (self.variable_names()[:-1] == R.variable_names()
+                    and self.base_ring().has_coerce_map_from(R.base_ring()))
+
+        return super()._coerce_map_from_(R)
+
+    def gen(self, i):
+        r"""
+        Return the ``i``-th polynomial generator of ``self``.
+
+        INPUT:
+
+        - ``i`` -- nonnegative integer
+
+        OUTPUT: The polynomial generator `x_i`
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: W.gen(1)
+            x[1]
+            sage: W.gen(1) == x[1]
+            True
+        """
+        return self.element_class(self, {(self._var_index.gen(i),
+                                          self._diff_index.one()): self.base_ring().one()})
+
+    @cached_method
+    def polynomial_gens(self):
+        r"""
+        Return the polynomial generators of ``self``.
+
+        OUTPUT: A (lazy) family containing the polynomial generators `x_i`.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: x = W.polynomial_gens(); x
+            Lazy family (x(i))_{i in Non negative integers}
+            sage: x[3] == W.gen(3)
+            True
+        """
+        from sage.sets.non_negative_integers import NonNegativeIntegers
+        return Family(NonNegativeIntegers(), lambda x: self.gen(x), name=self.variable_names()[0])
+
+    @cached_method
+    def gens(self):
+        """
+        Return the algebra generators of ``self``.
+
+        OUTPUT: an ordered pair (x, dx) containing families indexing each set
+        of generators.
+
+        EXAMPLES::
+
+            sage: R = InfinitePolynomialRing(QQ)
+            sage: W = DifferentialWeylAlgebra(R, n=oo)
+            sage: x, dx = W.gens()
+        """
+        return (self.polynomial_gens(), self.differentials())
+
+    def differential(self, i):
+        r"""
+        Return the ``i``-th differential of ``self``.
+
+        INPUT:
+
+        - ``i`` -- nonnegative integer
+
+        OUTPUT: The differential generator `\partial_{x_i}`
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: W.inject_variables()
+            Defining x, dx
+            sage: W.differential(1)
+            dx[1]
+            sage: W.differential(1) == dx[1]
+            True
+        """
+        return self.element_class(self, {(self._var_index.one(),
+                                          self._diff_index.gen(i)): self.base_ring().one()})
+
+    @cached_method
+    def differentials(self):
+        r"""
+        Return the differential generators of ``self``.
+
+        OUTPUT: A (lazy) family containing the differential generators `\partial_{x_i}`
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: dx = W.differentials(); dx
+            Lazy family (dx(i))_{i in Non negative integers}
+            sage: dx[3] == W.differential(3)
+            True
+        """
+        from sage.sets.non_negative_integers import NonNegativeIntegers
+        return Family(NonNegativeIntegers(), lambda x: self.differential(x), name=self.variable_names()[1])
+
+    @cached_method
+    def zero(self):
+        """
+        Return the additive identity element `0` of ``self``.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: x[1] + W.zero() == x[1]
+            True
+            sage: x[1]*W.zero() == W.zero()
+            True
+        """
+        return self.element_class(self, {})
+
+    @cached_method
+    def one_basis(self):
+        """
+        Return the multiplicative identity element `1` of ``self``.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: W.one_basis() == W.one().leading_support()
+            True
+            sage: x[1]*W.one() == x[1]
+            True
+        """
+        return (self._var_index.one(), self._diff_index.one())
+
+    @cached_method
+    def basis(self):
+        """
+        Return a basis for ``self``.
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: B = W.basis(); B
+            Lazy family (basis map(i))_{i in The Cartesian product of
+             (Free abelian monoid indexed by Non negative integers,
+             Free abelian monoid indexed by Non negative integers)}
+            sage: idx = W._var_index
+            sage: B[(idx.an_element(), idx.one())]
+            x[0]*x[1]^2*x[2]^3*x[42]
+        """
+        index_set = cartesian_product([self._var_index, self._diff_index])
+        one = self.base_ring().one()
+        return Family(index_set,
+                      lambda x: self.element_class(self, {(x[0], x[1]): one}),
+                      name='basis map')
+
+    def degree_on_basis(self, x):
+        """
+        Return the degree of basis element indexed by ``x``. This is the total
+         degree of the polynomial and differential parts of ``x``.
+
+        INPUT:
+
+        - ``x`` -- an index for a basis element
+
+        OUTPUT: A nonnegative integer
+
+        EXAMPLES::
+
+            sage: W.<x> = DifferentialWeylAlgebra(QQ, n=oo)
+            sage: W.inject_variables(verbose=False);
+            sage: f = x[2]*x[3]*dx[1]^2; f.degree()
+            4
+        """
+        return x[0].length() + x[1].length()
+
+    Element = InfGenDifferentialWeylAlgebraElement
