@@ -159,7 +159,7 @@ class Algebras(CategoryWithAxiom_over_base_ring):
             """
             return self.base_ring().characteristic()
 
-        def has_standard_involution(self):
+        def has_standard_involution(self) -> bool:
             r"""
             Return ``True`` if the algebra has a standard involution and ``False`` otherwise.
 
