@@ -20,7 +20,7 @@ from sage.misc.lazy_import import LazyImport
 
 class Bialgebras(Category_over_base_ring):
     """
-    The category of bialgebras
+    The category of bialgebras.
 
     EXAMPLES::
 
