@@ -547,7 +547,7 @@ class KirillovReshetikhinCrystals(Category_singleton):
             from sage.rings.integer_ring import ZZ
             if ell is None:
                 if (self.cartan_type().dual().type() == 'BC'
-                    and self.cartan_type().rank() - 1 == self.r()):
+                        and self.cartan_type().rank() - 1 == self.r()):
                     return True
                 ell = self.s() / self.cartan_type().c()[self.r()]
                 if ell not in ZZ:
@@ -557,9 +557,9 @@ class KirillovReshetikhinCrystals(Category_singleton):
                 raise ValueError("perfectness not defined for non-integral levels")
 
             # [FOS2010]_ check
-            if self.cartan_type().classical().type() not in ['E','F','G']:
+            if self.cartan_type().classical().type() not in ['E', 'F', 'G']:
                 if (self.cartan_type().dual().type() == 'BC'
-                    and self.cartan_type().rank() - 1 == self.r()):
+                        and self.cartan_type().rank() - 1 == self.r()):
                     return ell == self.s()
                 return ell == self.s() / self.cartan_type().c()[self.r()]
 
@@ -580,9 +580,9 @@ class KirillovReshetikhinCrystals(Category_singleton):
             rank = len(I)
             La = self.weight_lattice_realization().basis()
             from sage.combinat.integer_vector import IntegerVectors
-            for n in range(1, ell+1):
+            for n in range(1, ell + 1):
                 for c in IntegerVectors(n, rank):
-                    w = sum(c[i]*La[i] for i in I)
+                    w = sum(c[i] * La[i] for i in I)
                     if w.level() == ell:
                         weights.append(w)
             return sorted(b.Phi() for b in MPhi) == sorted(weights)
@@ -629,7 +629,7 @@ class KirillovReshetikhinCrystals(Category_singleton):
             if not self.is_perfect():
                 raise ValueError("this crystal is not perfect")
             if (self.cartan_type().dual().type() == 'BC'
-                and self.cartan_type().rank() - 1 == self.r()):
+                    and self.cartan_type().rank() - 1 == self.r()):
                 return self.s()
             return self.s() / self.cartan_type().c()[self.r()]
 
@@ -764,7 +764,7 @@ class KirillovReshetikhinCrystals(Category_singleton):
                 """
                 n = len(self.crystals)
                 I0 = self.cartan_type().classical().index_set()
-                it = [ iter(self.crystals[-1].classically_highest_weight_vectors()) ]
+                it = [iter(self.crystals[-1].classically_highest_weight_vectors())]
                 path = []
                 ret = []
                 while it:
@@ -773,18 +773,19 @@ class KirillovReshetikhinCrystals(Category_singleton):
                     except StopIteration:
                         it.pop()
                         if path:
-                            path.pop(0)
+                            path.pop()
                         continue
 
-                    b = self.element_class(self, [x] + path)
+                    path.append(x)
+                    b = self.element_class(self, reversed(path))
                     if not b.is_highest_weight(index_set=I0):
+                        path.pop()
                         continue
-                    path.insert(0, x)
                     if len(path) == n:
                         ret.append(b)
-                        path.pop(0)
+                        path.pop()
                     else:
-                        it.append( iter(self.crystals[-len(path)-1]) )
+                        it.append(iter(self.crystals[-len(path) - 1]))
                 return tuple(ret)
 
             # TODO: This is duplicated in KR crystals category
@@ -822,7 +823,7 @@ class KirillovReshetikhinCrystals(Category_singleton):
 
                 - ``q`` -- (default: ``None``) a variable or ``None``;
                   if ``None``, a variable `q` is set in the code
-                - ``group_components`` -- (default: ``True``) boolean; if
+                - ``group_components`` -- boolean (default: ``True``); if
                   ``True``, then the terms are grouped by classical component
 
                 The one-dimensional configuration sum is the sum of the
@@ -873,9 +874,10 @@ class KirillovReshetikhinCrystals(Category_singleton):
                 if group_components:
                     G = self.digraph(index_set=self.cartan_type().classical().index_set())
                     C = G.connected_components(sort=False)
-                    return B.sum(q**(c[0].energy_function())*B.sum(B(P0(b.weight())) for b in c)
+                    return B.sum(q**(c[0].energy_function()) * B.sum(B(P0(b.weight()))
+                                                                     for b in c)
                                  for c in C)
-                return B.sum(q**(b.energy_function())*B(P0(b.weight())) for b in self)
+                return B.sum(q**(b.energy_function()) * B(P0(b.weight())) for b in self)
 
         class ElementMethods:
             def energy_function(self, algorithm=None):
@@ -924,7 +926,7 @@ class KirillovReshetikhinCrystals(Category_singleton):
                   factors are perfect of the same level and otherwise
                   this uses ``'definition'``
 
-                OUTPUT: an integer
+                OUTPUT: integer
 
                 EXAMPLES::
 
@@ -975,8 +977,8 @@ class KirillovReshetikhinCrystals(Category_singleton):
                 from sage.arith.misc import integer_ceil as ceil
 
                 C = self.parent().crystals[0]
-                ell = ceil(C.s()/C.cartan_type().c()[C.r()])
-                is_perfect = all(ell == K.s()/K.cartan_type().c()[K.r()]
+                ell = ceil(C.s() / C.cartan_type().c()[C.r()])
+                is_perfect = all(ell == K.s() / K.cartan_type().c()[K.r()]
                                  for K in self.parent().crystals)
                 if algorithm is None:
                     if is_perfect:
@@ -995,12 +997,12 @@ class KirillovReshetikhinCrystals(Category_singleton):
                     from sage.rings.integer_ring import ZZ
                     energy = ZZ.zero()
                     R_mats = [[K.R_matrix(Kp) for Kp in self.parent().crystals[i+1:]]
-                              for i,K in enumerate(self.parent().crystals)]
+                              for i, K in enumerate(self.parent().crystals)]
                     H_funcs = [[K.local_energy_function(Kp) for Kp in self.parent().crystals[i+1:]]
-                               for i,K in enumerate(self.parent().crystals)]
+                               for i, K in enumerate(self.parent().crystals)]
 
-                    for i,b in enumerate(self):
-                        for j,R in enumerate(R_mats[i]):
+                    for i, b in enumerate(self):
+                        for j, R in enumerate(R_mats[i]):
                             H = H_funcs[i][j]
                             bp = self[i+j+1]
                             T = R.domain()
@@ -1021,7 +1023,7 @@ class KirillovReshetikhinCrystals(Category_singleton):
                 :meth:`e_string_to_ground_state`) and counting the number
                 of affine Kashiwara operators `e_0` applied on the way.
 
-                OUTPUT: an integer
+                OUTPUT: integer
 
                 EXAMPLES::
 
@@ -1128,7 +1130,7 @@ class KirillovReshetikhinCrystals(Category_singleton):
 
 
 #####################################################################
-## Local energy function
+# Local energy function
 
 class LocalEnergyFunction(Map):
     r"""
@@ -1246,9 +1248,9 @@ class LocalEnergyFunction(Map):
             for i in self._I0:
                 b = cur.e(i)
                 if b is not None and b not in visited:
-                    visited[b] = visited[cur] # No change
+                    visited[b] = visited[cur]  # No change
                     return b
-            return None # is classically HW or all have been visited
+            return None  # is classically HW or all have been visited
 
         cur = x
         # Get the affine node (it might not be 0 if the type
@@ -1270,19 +1272,19 @@ class LocalEnergyFunction(Map):
 
                 bp = self._R_matrix(b)
                 cp = bp.e(i0)
-                if b[1] == c[1] and bp[1] == cp[1]: # LL case
+                if b[1] == c[1] and bp[1] == cp[1]:  # LL case
                     visited[c] = visited[b] + 1
-                elif b[0] == c[0] and bp[0] == cp[0]: # RR case
+                elif b[0] == c[0] and bp[0] == cp[0]:  # RR case
                     visited[c] = visited[b] - 1
                 else:
-                    visited[c] = visited[b] # Otherwise no change
+                    visited[c] = visited[b]  # Otherwise no change
                 b = c
 
             cur = b
             check0.append(b)
 
         baseline = self._known_values[cur] - visited[cur]
-        for y in visited:
-            self._known_values[y] = baseline + visited[y]
+        for y, vy in visited.items():
+            self._known_values[y] = baseline + vy
 
         return self._known_values[x]
