@@ -45,7 +45,7 @@ class Modules(Category_module):
     INPUT:
 
     - ``base_ring`` -- a ring `R` or subcategory of ``Rings()``
-    - ``dispatch`` -- a boolean (for internal use; default: ``True``)
+    - ``dispatch`` -- boolean (for internal use; default: ``True``)
 
     When the base ring is a field, the category of vector spaces is
     returned instead (unless ``dispatch == False``).
@@ -558,7 +558,6 @@ class Modules(Category_module):
                     sage: Modules(QQ).FiniteDimensional().TensorProducts().FiniteDimensional()
                     Category of tensor products of finite dimensional vector spaces
                      over Rational Field
-
                 """
                 return [self.base_category()]
 
@@ -637,7 +636,7 @@ class Modules(Category_module):
         @cached_method
         def tensor_square(self):
             """
-            Returns the tensor square of ``self``
+            Return the tensor square of ``self``.
 
             EXAMPLES::
 
@@ -660,7 +659,7 @@ class Modules(Category_module):
 
             INPUT:
 
-            - ``self`` -- a parent `X` in ``Modules(R)``.
+            - ``self`` -- a parent `X` in ``Modules(R)``
 
             - ``function`` -- a function `f` from `X` to `Y`
 
@@ -681,7 +680,6 @@ class Modules(Category_module):
                  2-dimensional vector space over the Rational Field
                 sage: neg(e[0])
                 Element -e_0 of the 2-dimensional vector space over the Rational Field
-
             """
             # Make sure that we only create a module morphism, even if
             # domain and codomain have more structure
@@ -699,7 +697,7 @@ class Modules(Category_module):
               something that can be turned into one via
               ``self.submodule(submodule)``
 
-            - ``check``, other keyword arguments: passed on to
+            - ``check``, other keyword arguments -- passed on to
               :meth:`quotient_module`.
 
             This method just delegates to :meth:`quotient_module`.
@@ -717,7 +715,6 @@ class Modules(Category_module):
                 <bound method Rings.ParentMethods.quotient of
                  Tensor Algebra of Free module generated by {'a', 'b', 'c'}
                  over Rational Field>
-
             """
             return self.quotient_module(submodule, check=check, **kwds)
 
@@ -772,7 +769,8 @@ class Modules(Category_module):
                 This ``base_ring`` method is actually overridden by
                 :meth:`sage.structure.category_object.CategoryObject.base_ring`::
 
-                    sage: H.base_ring.__module__                                        # needs sage.modules
+                    sage: H.base_ring.__module__
+                    'sage.structure.category_object'
 
                 Here we call it directly::
 
@@ -837,7 +835,7 @@ class Modules(Category_module):
 
     class CartesianProducts(CartesianProductsCategory):
         """
-        The category of modules constructed as Cartesian products of modules
+        The category of modules constructed as Cartesian products of modules.
 
         This construction gives the direct product of modules. The
         implementation is based on the following resources:
@@ -896,7 +894,7 @@ class Modules(Category_module):
                      (Vector space of dimension 2 over Rational Field,
                       Univariate Polynomial Ring in x over Rational Field)
                     sage: A.category()                                                  # needs sage.modules
-                    Category of Cartesian products of vector spaces
+                    Category of Cartesian products of vector spaces with basis
                      over (number fields and quotient fields and metric spaces)
                     sage: A.base_ring()                                                 # needs sage.modules
                     Rational Field
@@ -970,16 +968,10 @@ class Modules(Category_module):
                      (Free Algebra on 2 generators (None0, None1) over Rational Field,
                       Free Algebra on 2 generators (None0, None1) over Rational Field))
                 """
-                try:
-                    factors = self.tensor_factors()
-                except (TypeError, NotImplementedError):
-                    from sage.misc.superseded import deprecation
-                    deprecation(34393, "implementations of Modules().TensorProducts() now must define the method tensor_factors")
-                    return None
-                return (TensorProductFunctor(),
-                        factors)
+                factors = self.tensor_factors()
+                return (TensorProductFunctor(), factors)
 
-            @abstract_method(optional=True)
+            @abstract_method
             def tensor_factors(self):
                 """
                 Return the tensor factors of this tensor product.
@@ -988,23 +980,11 @@ class Modules(Category_module):
 
                     sage: # needs sage.modules
                     sage: F = CombinatorialFreeModule(ZZ, [1,2])
-                    sage: F.rename("F")
+                    sage: F.rename('F')
                     sage: G = CombinatorialFreeModule(ZZ, [3,4])
-                    sage: G.rename("G")
+                    sage: G.rename('G')
                     sage: T = tensor([F, G]); T
                     F # G
                     sage: T.tensor_factors()
                     (F, G)
-
-                TESTS::
-
-                    sage: Cat = ModulesWithBasis(ZZ).FiniteDimensional().TensorProducts()
-                    sage: M = CombinatorialFreeModule(ZZ,                               # needs sage.modules
-                    ....:                             ((1, 1), (1, 2), (2, 1), (2, 2)),
-                    ....:                             category=Cat)
-                    sage: M.construction()                                              # needs sage.modules
-                    doctest:warning...
-                    DeprecationWarning: implementations of Modules().TensorProducts() now must define the method tensor_factors
-                    See https://github.com/sagemath/sage/issues/34393 for details.
-                    (VectorFunctor, Integer Ring)
                 """
