@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-categories
 r"""
 Quantum Group Representations
 
@@ -24,6 +25,7 @@ from sage.categories.category_types import Category_module
 from sage.categories.category_with_axiom import CategoryWithAxiom_over_base_ring
 from sage.categories.tensor import tensor, TensorProductsCategory
 
+
 class QuantumGroupRepresentations(Category_module):
     """
     The category of quantum group representations.
@@ -51,7 +53,7 @@ class QuantumGroupRepresentations(Category_module):
 
             sage: from sage.categories.quantum_group_representations import QuantumGroupRepresentations
             sage: Cat = QuantumGroupRepresentations(ZZ['q'].fraction_field())
-            sage: Cat.example()                                                         # optional - sage.combinat sage.modules
+            sage: Cat.example()                                                         # needs sage.combinat sage.graphs sage.modules
             V((2, 1, 0))
         """
         from sage.algebras.quantum_groups.representations import AdjointRepresentation
@@ -96,34 +98,35 @@ class QuantumGroupRepresentations(Category_module):
 
                     EXAMPLES::
 
-                        sage: from sage.algebras.quantum_groups.representations import (  # optional - sage.combinat sage.modules
+                        sage: # needs sage.combinat sage.graphs sage.modules
+                        sage: from sage.algebras.quantum_groups.representations import (
                         ....:     MinusculeRepresentation, AdjointRepresentation)
                         sage: R = ZZ['q'].fraction_field()
-                        sage: CM = crystals.Tableaux(['D',4], shape=[1])                # optional - sage.combinat sage.modules
-                        sage: VM = MinusculeRepresentation(R, CM)                       # optional - sage.combinat sage.modules
-                        sage: CA = crystals.Tableaux(['D',4], shape=[1,1])              # optional - sage.combinat sage.modules
-                        sage: VA = AdjointRepresentation(R, CA)                         # optional - sage.combinat sage.modules
-                        sage: v = tensor([VM.an_element(), VA.an_element()]); v         # optional - sage.combinat sage.modules
+                        sage: CM = crystals.Tableaux(['D',4], shape=[1])
+                        sage: VM = MinusculeRepresentation(R, CM)
+                        sage: CA = crystals.Tableaux(['D',4], shape=[1,1])
+                        sage: VA = AdjointRepresentation(R, CA)
+                        sage: v = tensor([VM.an_element(), VA.an_element()]); v
                         4*B[[[1]]] # B[[[1], [2]]] + 4*B[[[1]]] # B[[[1], [3]]]
                          + 6*B[[[1]]] # B[[[2], [3]]] + 4*B[[[2]]] # B[[[1], [2]]]
                          + 4*B[[[2]]] # B[[[1], [3]]] + 6*B[[[2]]] # B[[[2], [3]]]
                          + 6*B[[[3]]] # B[[[1], [2]]] + 6*B[[[3]]] # B[[[1], [3]]]
                          + 9*B[[[3]]] # B[[[2], [3]]]
-                        sage: v.e(1)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.e(1)  # indirect doctest
                         4*B[[[1]]] # B[[[1], [2]]]
                          + ((4*q+6)/q)*B[[[1]]] # B[[[1], [3]]]
                          + 6*B[[[1]]] # B[[[2], [3]]]
                          + 6*q*B[[[2]]] # B[[[1], [3]]]
                          + 9*B[[[3]]] # B[[[1], [3]]]
-                        sage: v.e(2)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.e(2)  # indirect doctest
                         4*B[[[1]]] # B[[[1], [2]]]
                          + ((6*q+4)/q)*B[[[2]]] # B[[[1], [2]]]
                          + 6*B[[[2]]] # B[[[1], [3]]]
                          + 9*B[[[2]]] # B[[[2], [3]]]
                          + 6*q*B[[[3]]] # B[[[1], [2]]]
-                        sage: v.e(3)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.e(3)  # indirect doctest
                         0
-                        sage: v.e(4)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.e(4)  # indirect doctest
                         0
                     """
                     K_elt = [self._sets[k].K_on_basis(i, elt, -1) for k,elt in enumerate(b)]
@@ -146,38 +149,39 @@ class QuantumGroupRepresentations(Category_module):
 
                     EXAMPLES::
 
-                        sage: from sage.algebras.quantum_groups.representations import (  # optional - sage.combinat sage.modules
+                        sage: # needs sage.combinat sage.graphs sage.modules
+                        sage: from sage.algebras.quantum_groups.representations import (
                         ....:     MinusculeRepresentation, AdjointRepresentation)
                         sage: R = ZZ['q'].fraction_field()
-                        sage: KM = crystals.KirillovReshetikhin(['B',3,1], 3,1)         # optional - sage.combinat sage.modules
-                        sage: VM = MinusculeRepresentation(R, KM)                       # optional - sage.combinat sage.modules
-                        sage: KA = crystals.KirillovReshetikhin(['B',3,1], 2,1)         # optional - sage.combinat sage.modules
-                        sage: VA = AdjointRepresentation(R, KA)                         # optional - sage.combinat sage.modules
-                        sage: v = tensor([VM.an_element(), VA.an_element()]); v         # optional - sage.combinat sage.modules
+                        sage: KM = crystals.KirillovReshetikhin(['B',3,1], 3,1)
+                        sage: VM = MinusculeRepresentation(R, KM)
+                        sage: KA = crystals.KirillovReshetikhin(['B',3,1], 2,1)
+                        sage: VA = AdjointRepresentation(R, KA)
+                        sage: v = tensor([VM.an_element(), VA.an_element()]); v
                         4*B[[+++, []]] # B[[]] + 4*B[[+++, []]] # B[[[1], [2]]]
                          + 6*B[[+++, []]] # B[[[1], [3]]] + 4*B[[++-, []]] # B[[]]
                          + 4*B[[++-, []]] # B[[[1], [2]]]
                          + 6*B[[++-, []]] # B[[[1], [3]]] + 6*B[[+-+, []]] # B[[]]
                          + 6*B[[+-+, []]] # B[[[1], [2]]]
                          + 9*B[[+-+, []]] # B[[[1], [3]]]
-                        sage: v.f(0)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.f(0)  # indirect doctest
                         ((4*q^4+4)/q^2)*B[[+++, []]] # B[[[1], [2]]]
                          + ((4*q^4+4)/q^2)*B[[++-, []]] # B[[[1], [2]]]
                          + ((6*q^4+6)/q^2)*B[[+-+, []]] # B[[[1], [2]]]
-                        sage: v.f(1)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.f(1)  # indirect doctest
                         6*B[[+++, []]] # B[[[2], [3]]]
                          + 6*B[[++-, []]] # B[[[2], [3]]]
                          + 9*B[[+-+, []]] # B[[[2], [3]]]
                          + 6*B[[-++, []]] # B[[]]
                          + 6*B[[-++, []]] # B[[[1], [2]]]
                          + 9*q^2*B[[-++, []]] # B[[[1], [3]]]
-                        sage: v.f(2)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.f(2)  # indirect doctest
                         4*B[[+++, []]] # B[[[1], [3]]]
                          + 4*B[[++-, []]] # B[[[1], [3]]]
                          + 4*B[[+-+, []]] # B[[]]
                          + 4*q^2*B[[+-+, []]] # B[[[1], [2]]]
                          + ((6*q^2+6)/q^2)*B[[+-+, []]] # B[[[1], [3]]]
-                        sage: v.f(3)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.f(3)  # indirect doctest
                         6*B[[+++, []]] # B[[[1], [0]]]
                          + 4*B[[++-, []]] # B[[]]
                          + 4*B[[++-, []]] # B[[[1], [2]]]
@@ -209,22 +213,23 @@ class QuantumGroupRepresentations(Category_module):
 
                     EXAMPLES::
 
-                        sage: from sage.algebras.quantum_groups.representations import (  # optional - sage.combinat sage.modules
+                        sage: # needs sage.combinat sage.graphs sage.modules
+                        sage: from sage.algebras.quantum_groups.representations import (
                         ....:     MinusculeRepresentation, AdjointRepresentation)
                         sage: R = ZZ['q'].fraction_field()
-                        sage: CM = crystals.Tableaux(['A',2], shape=[1])                # optional - sage.combinat sage.modules
-                        sage: VM = MinusculeRepresentation(R, CM)                       # optional - sage.combinat sage.modules
-                        sage: CA = crystals.Tableaux(['A',2], shape=[2,1])              # optional - sage.combinat sage.modules
-                        sage: VA = AdjointRepresentation(R, CA)                         # optional - sage.combinat sage.modules
-                        sage: v = tensor([sum(VM.basis()), VA.module_generator()]); v   # optional - sage.combinat sage.modules
+                        sage: CM = crystals.Tableaux(['A',2], shape=[1])
+                        sage: VM = MinusculeRepresentation(R, CM)
+                        sage: CA = crystals.Tableaux(['A',2], shape=[2,1])
+                        sage: VA = AdjointRepresentation(R, CA)
+                        sage: v = tensor([sum(VM.basis()), VA.module_generator()]); v
                         B[[[1]]] # B[[[1, 1], [2]]]
                          + B[[[2]]] # B[[[1, 1], [2]]]
                          + B[[[3]]] # B[[[1, 1], [2]]]
-                        sage: v.K(1)  # indirect doctest                                # optional - sage.combinat sage.modules
+                        sage: v.K(1)  # indirect doctest
                         q^2*B[[[1]]] # B[[[1, 1], [2]]]
                          + B[[[2]]] # B[[[1, 1], [2]]]
                          + q*B[[[3]]] # B[[[1, 1], [2]]]
-                        sage: v.K(2, -1)  # indirect doctest                            # optional - sage.combinat sage.modules
+                        sage: v.K(2, -1)  # indirect doctest
                         1/q*B[[[1]]] # B[[[1, 1], [2]]]
                          + 1/q^2*B[[[2]]] # B[[[1, 1], [2]]]
                          + B[[[3]]] # B[[[1, 1], [2]]]
@@ -241,24 +246,25 @@ class QuantumGroupRepresentations(Category_module):
 
                 EXAMPLES::
 
-                    sage: from sage.algebras.quantum_groups.representations import (    # optional - sage.combinat sage.modules
+                    sage: # needs sage.combinat sage.graphs sage.modules
+                    sage: from sage.algebras.quantum_groups.representations import (
                     ....:     MinusculeRepresentation, AdjointRepresentation)
                     sage: R = ZZ['q'].fraction_field()
-                    sage: CM = crystals.Tableaux(['D',4], shape=[1])                    # optional - sage.combinat sage.modules
-                    sage: CA = crystals.Tableaux(['D',4], shape=[1,1])                  # optional - sage.combinat sage.modules
-                    sage: V = MinusculeRepresentation(R, CM)                            # optional - sage.combinat sage.modules
-                    sage: V.tensor(V, V)                                                # optional - sage.combinat sage.modules
+                    sage: CM = crystals.Tableaux(['D',4], shape=[1])
+                    sage: CA = crystals.Tableaux(['D',4], shape=[1,1])
+                    sage: V = MinusculeRepresentation(R, CM)
+                    sage: V.tensor(V, V)
                     V((1, 0, 0, 0)) # V((1, 0, 0, 0)) # V((1, 0, 0, 0))
-                    sage: A = MinusculeRepresentation(R, CA)                            # optional - sage.combinat sage.modules
-                    sage: V.tensor(A)                                                   # optional - sage.combinat sage.modules
+                    sage: A = MinusculeRepresentation(R, CA)
+                    sage: V.tensor(A)
                     V((1, 0, 0, 0)) # V((1, 1, 0, 0))
-                    sage: B = crystals.Tableaux(['A',2], shape=[1])                     # optional - sage.combinat sage.modules
-                    sage: W = MinusculeRepresentation(R, B)                             # optional - sage.combinat sage.modules
-                    sage: tensor([W,V])                                                 # optional - sage.combinat sage.modules
+                    sage: B = crystals.Tableaux(['A',2], shape=[1])
+                    sage: W = MinusculeRepresentation(R, B)
+                    sage: tensor([W,V])
                     Traceback (most recent call last):
                     ...
                     ValueError: all factors must be of the same Cartan type
-                    sage: tensor([V,A,W])                                               # optional - sage.combinat sage.modules
+                    sage: tensor([V,A,W])
                     Traceback (most recent call last):
                     ...
                     ValueError: all factors must be of the same Cartan type
@@ -279,15 +285,16 @@ class QuantumGroupRepresentations(Category_module):
 
                 EXAMPLES::
 
-                    sage: from sage.algebras.quantum_groups.representations import AdjointRepresentation  # optional - sage.combinat sage.modules
-                    sage: C = crystals.Tableaux(['G',2], shape=[1,1])                   # optional - sage.combinat sage.modules
-                    sage: R = ZZ['q'].fraction_field()                                  # optional - sage.combinat sage.modules
-                    sage: V = AdjointRepresentation(R, C)                               # optional - sage.combinat sage.modules
-                    sage: v = V.an_element(); v                                         # optional - sage.combinat sage.modules
+                    sage: # needs sage.combinat sage.graphs sage.modules
+                    sage: from sage.algebras.quantum_groups.representations import AdjointRepresentation
+                    sage: C = crystals.Tableaux(['G',2], shape=[1,1])
+                    sage: R = ZZ['q'].fraction_field()
+                    sage: V = AdjointRepresentation(R, C)
+                    sage: v = V.an_element(); v
                     2*B[[[1], [2]]] + 2*B[[[1], [3]]] + 3*B[[[2], [3]]]
-                    sage: v.e(1)                                                        # optional - sage.combinat sage.modules
+                    sage: v.e(1)
                     ((3*q^4+3*q^2+3)/q^2)*B[[[1], [3]]]
-                    sage: v.e(2)                                                        # optional - sage.combinat sage.modules
+                    sage: v.e(2)
                     2*B[[[1], [2]]]
                 """
                 F = self.parent()
@@ -305,21 +312,22 @@ class QuantumGroupRepresentations(Category_module):
 
                 EXAMPLES::
 
-                    sage: from sage.algebras.quantum_groups.representations import AdjointRepresentation  # optional - sage.combinat sage.modules
-                    sage: K = crystals.KirillovReshetikhin(['D',4,1], 2,1)              # optional - sage.combinat sage.modules
-                    sage: R = ZZ['q'].fraction_field()                                  # optional - sage.combinat sage.modules
-                    sage: V = AdjointRepresentation(R, K)                               # optional - sage.combinat sage.modules
-                    sage: v = V.an_element(); v                                         # optional - sage.combinat sage.modules
+                    sage: # needs sage.combinat sage.graphs sage.modules
+                    sage: from sage.algebras.quantum_groups.representations import AdjointRepresentation
+                    sage: K = crystals.KirillovReshetikhin(['D',4,1], 2,1)
+                    sage: R = ZZ['q'].fraction_field()
+                    sage: V = AdjointRepresentation(R, K)
+                    sage: v = V.an_element(); v
                     2*B[[]] + 2*B[[[1], [2]]] + 3*B[[[1], [3]]]
-                    sage: v.f(0)                                                        # optional - sage.combinat sage.modules
+                    sage: v.f(0)
                     ((2*q^2+2)/q)*B[[[1], [2]]]
-                    sage: v.f(1)                                                        # optional - sage.combinat sage.modules
+                    sage: v.f(1)
                     3*B[[[2], [3]]]
-                    sage: v.f(2)                                                        # optional - sage.combinat sage.modules
+                    sage: v.f(2)
                     2*B[[[1], [3]]]
-                    sage: v.f(3)                                                        # optional - sage.combinat sage.modules
+                    sage: v.f(3)
                     3*B[[[1], [4]]]
-                    sage: v.f(4)                                                        # optional - sage.combinat sage.modules
+                    sage: v.f(4)
                     3*B[[[1], [-4]]]
                 """
                 F = self.parent()
@@ -338,19 +346,20 @@ class QuantumGroupRepresentations(Category_module):
 
                 EXAMPLES::
 
-                    sage: from sage.algebras.quantum_groups.representations import AdjointRepresentation  # optional - sage.combinat sage.modules
-                    sage: K = crystals.KirillovReshetikhin(['D',4,2], 1,1)              # optional - sage.combinat sage.modules
-                    sage: R = ZZ['q'].fraction_field()                                  # optional - sage.combinat sage.modules
-                    sage: V = AdjointRepresentation(R, K)                               # optional - sage.combinat sage.modules
-                    sage: v = V.an_element(); v                                         # optional - sage.combinat sage.modules
+                    sage: # needs sage.combinat sage.graphs sage.modules
+                    sage: from sage.algebras.quantum_groups.representations import AdjointRepresentation
+                    sage: K = crystals.KirillovReshetikhin(['D',4,2], 1,1)
+                    sage: R = ZZ['q'].fraction_field()
+                    sage: V = AdjointRepresentation(R, K)
+                    sage: v = V.an_element(); v
                     2*B[[]] + 2*B[[[1]]] + 3*B[[[2]]]
-                    sage: v.K(0)                                                        # optional - sage.combinat sage.modules
+                    sage: v.K(0)
                     2*B[[]] + 2/q^2*B[[[1]]] + 3*B[[[2]]]
-                    sage: v.K(1)                                                        # optional - sage.combinat sage.modules
+                    sage: v.K(1)
                     2*B[[]] + 2*q^2*B[[[1]]] + 3/q^2*B[[[2]]]
-                    sage: v.K(1, 2)                                                     # optional - sage.combinat sage.modules
+                    sage: v.K(1, 2)
                     2*B[[]] + 2*q^4*B[[[1]]] + 3/q^4*B[[[2]]]
-                    sage: v.K(1, -1)                                                    # optional - sage.combinat sage.modules
+                    sage: v.K(1, -1)
                     2*B[[]] + 2/q^2*B[[[1]]] + 3*q^2*B[[[2]]]
                 """
                 F = self.parent()
@@ -388,12 +397,13 @@ class QuantumGroupRepresentations(Category_module):
 
                 EXAMPLES::
 
-                    sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation  # optional - sage.combinat sage.modules
-                    sage: C = crystals.Tableaux(['C',2], shape=[1])                     # optional - sage.combinat sage.modules
-                    sage: R = ZZ['q'].fraction_field()                                  # optional - sage.combinat sage.modules
-                    sage: V = MinusculeRepresentation(R, C)                             # optional - sage.combinat sage.modules
-                    sage: T = tensor([V,V])                                             # optional - sage.combinat sage.modules
-                    sage: T.cartan_type()                                               # optional - sage.combinat sage.modules
+                    sage: # needs sage.combinat sage.graphs sage.modules
+                    sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation
+                    sage: C = crystals.Tableaux(['C',2], shape=[1])
+                    sage: R = ZZ['q'].fraction_field()
+                    sage: V = MinusculeRepresentation(R, C)
+                    sage: T = tensor([V,V])
+                    sage: T.cartan_type()
                     ['C', 2]
                 """
                 return self._sets[0].cartan_type()
@@ -407,18 +417,19 @@ class QuantumGroupRepresentations(Category_module):
 
             EXAMPLES::
 
-                sage: from sage.algebras.quantum_groups.representations import (        # optional - sage.combinat sage.modules
+                sage: # needs sage.combinat sage.graphs sage.modules
+                sage: from sage.algebras.quantum_groups.representations import (
                 ....:  MinusculeRepresentation, AdjointRepresentation)
-                sage: C = crystals.Tableaux(['G',2], shape=[1,1])                       # optional - sage.combinat sage.modules
-                sage: R = ZZ['q'].fraction_field()                                      # optional - sage.combinat sage.modules
-                sage: V = AdjointRepresentation(R, C)                                   # optional - sage.combinat sage.modules
-                sage: V._test_representation()                                          # optional - sage.combinat sage.modules
+                sage: C = crystals.Tableaux(['G',2], shape=[1,1])
+                sage: R = ZZ['q'].fraction_field()
+                sage: V = AdjointRepresentation(R, C)
+                sage: V._test_representation()
 
             We verify that ``C`` does not define a minuscule
             representation::
 
-                sage: M = MinusculeRepresentation(R, C)                                 # optional - sage.combinat sage.modules
-                sage: M._test_representation()                                          # optional - sage.combinat sage.modules
+                sage: M = MinusculeRepresentation(R, C)                                 # needs sage.combinat sage.graphs sage.modules
+                sage: M._test_representation()                                          # needs sage.combinat sage.graphs sage.modules
                 Traceback (most recent call last):
                 ...
                 AssertionError: [e,f] = (K-K^-1)/(q_i-q_i^-1) -- i: 1 j: 1
@@ -489,11 +500,12 @@ class QuantumGroupRepresentations(Category_module):
 
             EXAMPLES::
 
-                sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation  # optional - sage.combinat sage.modules
-                sage: C = crystals.Tableaux(['C',4], shape=[1])                         # optional - sage.combinat sage.modules
-                sage: R = ZZ['q'].fraction_field()                                      # optional - sage.combinat sage.modules
-                sage: V = MinusculeRepresentation(R, C)                                 # optional - sage.combinat sage.modules
-                sage: V.cartan_type()                                                   # optional - sage.combinat sage.modules
+                sage: # needs sage.combinat sage.graphs sage.modules
+                sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation
+                sage: C = crystals.Tableaux(['C',4], shape=[1])
+                sage: R = ZZ['q'].fraction_field()
+                sage: V = MinusculeRepresentation(R, C)
+                sage: V.cartan_type()
                 ['C', 4]
             """
 
@@ -504,11 +516,12 @@ class QuantumGroupRepresentations(Category_module):
 
             EXAMPLES::
 
-                sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation  # optional - sage.combinat sage.modules
-                sage: C = crystals.Tableaux(['C',4], shape=[1])                         # optional - sage.combinat sage.modules
-                sage: R = ZZ['q'].fraction_field()                                      # optional - sage.combinat sage.modules
-                sage: V = MinusculeRepresentation(R, C)                                 # optional - sage.combinat sage.modules
-                sage: V.index_set()                                                     # optional - sage.combinat sage.modules
+                sage: # needs sage.combinat sage.graphs sage.modules
+                sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation
+                sage: C = crystals.Tableaux(['C',4], shape=[1])
+                sage: R = ZZ['q'].fraction_field()
+                sage: V = MinusculeRepresentation(R, C)
+                sage: V.index_set()
                 (1, 2, 3, 4)
             """
             return self.cartan_type().index_set()
@@ -519,11 +532,12 @@ class QuantumGroupRepresentations(Category_module):
 
             EXAMPLES::
 
-                sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation  # optional - sage.combinat sage.modules
-                sage: C = crystals.Tableaux(['C',4], shape=[1])                         # optional - sage.combinat sage.modules
-                sage: R = ZZ['q'].fraction_field()                                      # optional - sage.combinat sage.modules
-                sage: V = MinusculeRepresentation(R, C)                                 # optional - sage.combinat sage.modules
-                sage: V.q()                                                             # optional - sage.combinat sage.modules
+                sage: # needs sage.combinat sage.graphs sage.modules
+                sage: from sage.algebras.quantum_groups.representations import MinusculeRepresentation
+                sage: C = crystals.Tableaux(['C',4], shape=[1])
+                sage: R = ZZ['q'].fraction_field()
+                sage: V = MinusculeRepresentation(R, C)
+                sage: V.q()
                 q
             """
             return self._q
