@@ -18,7 +18,7 @@ from sage.categories.coxeter_groups import CoxeterGroups
 
 class WeylGroups(Category_singleton):
     r"""
-    The category of Weyl groups
+    The category of Weyl groups.
 
     See the :wikipedia:`Wikipedia page of Weyl Groups <Weyl_group>`.
 
@@ -94,7 +94,7 @@ class WeylGroups(Category_singleton):
 
         def pieri_factors(self, *args, **keywords):
             r"""
-            Returns the set of Pieri factors in this Weyl group.
+            Return the set of Pieri factors in this Weyl group.
 
             For any type, the set of Pieri factors forms a lower ideal
             in Bruhat order, generated by all the conjugates of some
@@ -171,7 +171,7 @@ class WeylGroups(Category_singleton):
 
             - ``y`` -- an element in the group `W`
 
-            - ``side`` (default: ``'upper'``) -- must be one of the following:
+            - ``side`` -- (default: ``'upper'``) must be one of the following:
 
               * ``'upper'`` -- return the upper Bruhat cone of the interval [``x``, ``y``]
               * ``'lower'`` -- return the lower Bruhat cone of the interval [``x``, ``y``]
@@ -243,7 +243,7 @@ class WeylGroups(Category_singleton):
 
             EXAMPLES::
 
-                sage: W = WeylGroup(['A',3], prefix="s")
+                sage: W = WeylGroup(['A',3], prefix='s')
                 sage: g = W.quantum_bruhat_graph((1,3))
                 sage: g
                 Parabolic Quantum Bruhat Graph of Weyl Group of type ['A', 3]
@@ -260,7 +260,7 @@ class WeylGroups(Category_singleton):
                  (s2, s1*s2, alpha[1] + alpha[2]),
                  (s2, s3*s2, alpha[2] + alpha[3]),
                  (1, s2, alpha[2])]
-                sage: W = WeylGroup(['A',3,1], prefix="s")
+                sage: W = WeylGroup(['A',3,1], prefix='s')
                 sage: g = W.quantum_bruhat_graph()
                 Traceback (most recent call last):
                 ...
@@ -317,14 +317,14 @@ class WeylGroups(Category_singleton):
             from sage.graphs.digraph import DiGraph
             return DiGraph(visited,
                            name="Parabolic Quantum Bruhat Graph of %s for nodes %s" % (self, index_set),
-                           format="dict_of_dicts",
-                           data_structure="static_sparse")
+                           format='dict_of_dicts',
+                           data_structure='static_sparse')
 
     class ElementMethods:
 
         def is_pieri_factor(self):
             r"""
-            Returns whether ``self`` is a Pieri factor, as used for
+            Return whether ``self`` is a Pieri factor, as used for
             computing Stanley symmetric functions.
 
             .. SEEALSO::
@@ -357,7 +357,7 @@ class WeylGroups(Category_singleton):
 
         def left_pieri_factorizations(self, max_length=None):
             r"""
-            Returns all factorizations of ``self`` as `uv`, where `u`
+            Return all factorizations of ``self`` as `uv`, where `u`
             is a Pieri factor and `v` is an element of the Weyl group.
 
             .. SEEALSO::
@@ -426,7 +426,7 @@ class WeylGroups(Category_singleton):
         @cached_in_parent_method
         def stanley_symmetric_function_as_polynomial(self, max_length=None):
             r"""
-            Returns a multivariate generating function for the number
+            Return a multivariate generating function for the number
             of factorizations of a Weyl group element into Pieri
             factors of decreasing length, weighted by a statistic on
             Pieri factors.
@@ -440,7 +440,7 @@ class WeylGroups(Category_singleton):
             INPUT:
 
                 - ``self`` -- an element `w` of a Weyl group `W`
-                - ``max_length`` -- a non negative integer or infinity (default: infinity)
+                - ``max_length`` -- nonnegative integer or infinity (default: infinity)
 
             Returns the generating series for the Pieri factorizations
             `w = u_1 \cdots u_k`, where `u_i` is a Pieri factor for
@@ -585,7 +585,7 @@ class WeylGroups(Category_singleton):
 
             EXAMPLES::
 
-                sage: W = WeylGroup(['C',2],prefix="s")
+                sage: W = WeylGroup(['C',2], prefix='s')
                 sage: W.from_reduced_word([1,2,1]).reflection_to_root()
                 2*alpha[1] + alpha[2]
                 sage: W.from_reduced_word([1,2]).reflection_to_root()
@@ -614,7 +614,7 @@ class WeylGroups(Category_singleton):
 
             EXAMPLES::
 
-                sage: W = WeylGroup(['C',2],prefix="s")
+                sage: W = WeylGroup(['C',2], prefix='s')
                 sage: W.from_reduced_word([1,2,1]).reflection_to_coroot()
                 alphacheck[1] + alphacheck[2]
                 sage: W.from_reduced_word([1,2]).reflection_to_coroot()
@@ -655,7 +655,7 @@ class WeylGroups(Category_singleton):
 
             EXAMPLES::
 
-                sage: W = WeylGroup(['C',2], prefix="s")
+                sage: W = WeylGroup(['C',2], prefix='s')
                 sage: w = W.from_reduced_word([1,2])
                 sage: w.inversions()
                 [s2, s2*s1*s2]
@@ -743,7 +743,7 @@ class WeylGroups(Category_singleton):
 
             EXAMPLES::
 
-                sage: W = WeylGroup(['A',3], prefix="s")
+                sage: W = WeylGroup(['A',3], prefix='s')
                 sage: w = W.from_reduced_word([3,1,2,1])
                 sage: w.bruhat_lower_covers_coroots()
                 [(s1*s2*s1, alphacheck[1] + alphacheck[2] + alphacheck[3]),
@@ -754,7 +754,7 @@ class WeylGroups(Category_singleton):
 
         def bruhat_upper_covers_coroots(self):
             r"""
-            Returns all 2-tuples (``v``, `\alpha`) where ``v`` is covers ``self`` and `\alpha`
+            Return all 2-tuples (``v``, `\alpha`) where ``v`` is covers ``self`` and `\alpha`
             is the positive coroot such that ``self`` = ``v`` `s_\alpha` where `s_\alpha` is
             the reflection orthogonal to `\alpha`.
 
@@ -764,7 +764,7 @@ class WeylGroups(Category_singleton):
 
             EXAMPLES::
 
-                sage: W = WeylGroup(['A',4], prefix="s")
+                sage: W = WeylGroup(['A',4], prefix='s')
                 sage: w = W.from_reduced_word([3,1,2,1])
                 sage: w.bruhat_upper_covers_coroots()
                 [(s1*s2*s3*s2*s1, alphacheck[3]),
@@ -791,17 +791,17 @@ class WeylGroups(Category_singleton):
               simple reflections used to generate the parabolic subgroup;
               the default value indicates that the subgroup is the identity
 
-            - ``roots`` -- (default: ``False``) if ``True``, returns the
-              list of 2-tuples (``w``, `\alpha`) where ``w`` is a successor
+            - ``roots`` -- boolean (default: ``False``); if ``True``, returns
+              the list of 2-tuples (``w``, `\alpha`) where ``w`` is a successor
               and `\alpha` is the positive root associated with the
               successor relation
 
-            - ``quantum_only`` -- (default: ``False``) if ``True``, returns
-              only the quantum successors
+            - ``quantum_only`` -- boolean (default: ``False``); if ``True``,
+              returns only the quantum successors
 
             EXAMPLES::
 
-                sage: W = WeylGroup(['A',3], prefix="s")
+                sage: W = WeylGroup(['A',3], prefix='s')
                 sage: w = W.from_reduced_word([3,1,2])
                 sage: w.quantum_bruhat_successors([1], roots = True)
                 [(s3, alpha[2]), (s1*s2*s3*s2, alpha[3]),
