@@ -35,6 +35,7 @@ from sage.coding.encoder import Encoder
 from sage.modules.free_module_element import vector
 from sage.coding.all import codes
 
+
 def _columnize(element):
     """
     Convert a finite field element to a column vector over the prime field.
@@ -79,7 +80,7 @@ class GoppaCode(AbstractLinearCode):
     - ``generating_pol`` -- a monic polynomial with coefficients in a finite
       field `\GF{p^m}`, the code is defined over `\GF{p}`, `p` must be a prime number
 
-    - ``defining_set`` -- a set of elements of `\GF{p^m}` that are not roots
+    - ``defining_set`` -- set of elements of `\GF{p^m}` that are not roots
       of `g`, its cardinality is the length of the code
 
     EXAMPLES::
@@ -126,7 +127,7 @@ class GoppaCode(AbstractLinearCode):
 
     def _repr_(self):
         """
-        Representation of a Goppa code
+        Representation of a Goppa code.
 
         EXAMPLES::
 
@@ -315,7 +316,7 @@ class GoppaCode(AbstractLinearCode):
 
 class GoppaCodeEncoder(Encoder):
     r"""
-    Encoder for Goppa codes
+    Encoder for Goppa codes.
 
     Encodes words represented as vectors of length `k`, where `k` is
     the dimension of ``self``, with entries from `\GF{p}`, the prime field of
@@ -393,7 +394,7 @@ class GoppaCodeEncoder(Encoder):
 
     def __eq__(self, other):
         """
-        Test equality with ``other``
+        Test equality with ``other``.
 
         EXAMPLES::
 
@@ -412,7 +413,7 @@ class GoppaCodeEncoder(Encoder):
 
     def generator_matrix(self):
         r"""
-        A generator matrix for ``self``
+        A generator matrix for ``self``.
 
         Dimension of resulting matrix is `k \times n`, where `k` is
         the dimension of ``self`` and `n` is the length of ``self``.
