@@ -1,14 +1,14 @@
 r"""
 Combinatorics
 
-Introductory material
----------------------
+Introduction
+------------
 
 - :ref:`sage.combinat.quickref`
 - :ref:`sage.combinat.tutorial`
 
-Thematic indexes
-----------------
+Topics
+------
 
 - :ref:`sage.combinat.algebraic_combinatorics`
 
@@ -17,15 +17,15 @@ Thematic indexes
   - :ref:`sage.combinat.crystals.all`
   - :ref:`sage.combinat.root_system.all`
   - :ref:`sage.combinat.sf.all`
-  - :class:`~sage.combinat.fully_commutative_elements.FullyCommutativeElements`
+  - :ref:`sage.combinat.fully_commutative_elements`
 
 - :ref:`sage.combinat.counting`
 - :ref:`sage.combinat.enumerated_sets`
 - :ref:`sage.combinat.catalog_partitions`
 - :ref:`sage.combinat.finite_state_machine`
+- :ref:`sage.combinat.posets.all`
 - :ref:`sage.combinat.species.all`
 - :ref:`sage.combinat.designs.all`
-- :ref:`sage.combinat.posets.all`
 - :ref:`sage.combinat.words.all`
 - :ref:`sage.combinat.bijectionist`
 
@@ -34,15 +34,8 @@ Utilities
 
 - :ref:`sage.combinat.output`
 - :ref:`sage.combinat.ranker`
-- :func:`Combinatorial maps <sage.combinat.combinatorial_map.combinatorial_map>`
+- :ref:`sage.combinat.combinatorial_map`
 - :ref:`sage.combinat.misc`
-
-Related topics
---------------
-
-- :ref:`sage.coding`
-- :ref:`sage.dynamics`
-- :ref:`sage.graphs`
 """
 from sage.misc.namespace_package import install_doc, install_dict
 # install the docstring of this module to the containing package
