@@ -18,3 +18,5 @@ from sage.misc.lazy_import import lazy_import
 
 lazy_import('sage.combinat.chas.fsym', ['FreeSymmetricFunctions'])
 lazy_import('sage.combinat.chas.wqsym', ['WordQuasiSymmetricFunctions'])
+del lazy_import
+del install_doc
