@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.modules
 r"""
-Mutually Orthogonal Latin Squares (MOLS)
+Mutually orthogonal Latin squares (MOLS)
 
 The main function of this module is :func:`mutually_orthogonal_latin_squares`
 and can be can be used to generate MOLS (or check that they exist)::
@@ -126,6 +126,8 @@ from itertools import repeat
 from sage.rings.integer import Integer
 from sage.categories.sets_cat import EmptySetError
 from sage.misc.unknown import Unknown
+from sage.arith.misc import is_prime_power
+from sage.rings.finite_rings.finite_field_constructor import GF
 
 
 def are_mutually_orthogonal_latin_squares(l, verbose=False):
@@ -239,22 +241,22 @@ def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
 
         sage: designs.mutually_orthogonal_latin_squares(4,5)                            # needs sage.schemes
         [
-        [0 2 4 1 3]  [0 3 1 4 2]  [0 4 3 2 1]  [0 1 2 3 4]
-        [4 1 3 0 2]  [3 1 4 2 0]  [2 1 0 4 3]  [4 0 1 2 3]
-        [3 0 2 4 1]  [1 4 2 0 3]  [4 3 2 1 0]  [3 4 0 1 2]
-        [2 4 1 3 0]  [4 2 0 3 1]  [1 0 4 3 2]  [2 3 4 0 1]
-        [1 3 0 2 4], [2 0 3 1 4], [3 2 1 0 4], [1 2 3 4 0]
+        [0 1 2 3 4]  [0 1 2 3 4]  [0 1 2 3 4]  [0 1 2 3 4]
+        [1 2 3 4 0]  [2 3 4 0 1]  [3 4 0 1 2]  [4 0 1 2 3]
+        [2 3 4 0 1]  [4 0 1 2 3]  [1 2 3 4 0]  [3 4 0 1 2]
+        [3 4 0 1 2]  [1 2 3 4 0]  [4 0 1 2 3]  [2 3 4 0 1]
+        [4 0 1 2 3], [3 4 0 1 2], [2 3 4 0 1], [1 2 3 4 0]
         ]
 
         sage: designs.mutually_orthogonal_latin_squares(3,7)                            # needs sage.schemes
         [
-        [0 2 4 6 1 3 5]  [0 3 6 2 5 1 4]  [0 4 1 5 2 6 3]
-        [6 1 3 5 0 2 4]  [5 1 4 0 3 6 2]  [4 1 5 2 6 3 0]
-        [5 0 2 4 6 1 3]  [3 6 2 5 1 4 0]  [1 5 2 6 3 0 4]
-        [4 6 1 3 5 0 2]  [1 4 0 3 6 2 5]  [5 2 6 3 0 4 1]
-        [3 5 0 2 4 6 1]  [6 2 5 1 4 0 3]  [2 6 3 0 4 1 5]
-        [2 4 6 1 3 5 0]  [4 0 3 6 2 5 1]  [6 3 0 4 1 5 2]
-        [1 3 5 0 2 4 6], [2 5 1 4 0 3 6], [3 0 4 1 5 2 6]
+        [0 1 2 3 4 5 6]  [0 1 2 3 4 5 6]  [0 1 2 3 4 5 6]
+        [1 2 3 4 5 6 0]  [2 3 4 5 6 0 1]  [3 4 5 6 0 1 2]
+        [2 3 4 5 6 0 1]  [4 5 6 0 1 2 3]  [6 0 1 2 3 4 5]
+        [3 4 5 6 0 1 2]  [6 0 1 2 3 4 5]  [2 3 4 5 6 0 1]
+        [4 5 6 0 1 2 3]  [1 2 3 4 5 6 0]  [5 6 0 1 2 3 4]
+        [5 6 0 1 2 3 4]  [3 4 5 6 0 1 2]  [1 2 3 4 5 6 0]
+        [6 0 1 2 3 4 5], [5 6 0 1 2 3 4], [4 5 6 0 1 2 3]
         ]
 
         sage: designs.mutually_orthogonal_latin_squares(2,5,partitions=True)            # needs sage.schemes
@@ -268,16 +270,16 @@ def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
           [2, 7, 12, 17, 22],
           [3, 8, 13, 18, 23],
           [4, 9, 14, 19, 24]],
-         [[0, 8, 11, 19, 22],
-          [3, 6, 14, 17, 20],
-          [1, 9, 12, 15, 23],
-          [4, 7, 10, 18, 21],
-          [2, 5, 13, 16, 24]],
          [[0, 9, 13, 17, 21],
-          [2, 6, 10, 19, 23],
-          [4, 8, 12, 16, 20],
           [1, 5, 14, 18, 22],
-          [3, 7, 11, 15, 24]]]
+          [2, 6, 10, 19, 23],
+          [3, 7, 11, 15, 24],
+          [4, 8, 12, 16, 20]],
+         [[0, 8, 11, 19, 22],
+          [1, 9, 12, 15, 23],
+          [2, 5, 13, 16, 24],
+          [3, 6, 14, 17, 20],
+          [4, 7, 10, 18, 21]]]
 
     What is the maximum number of MOLS of size 8 that Sage knows how to build?::
 
@@ -341,6 +343,21 @@ def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
         [3 4 5 6 7 1 2 0 8 9]  [5 6 7 1 2 3 4 0 9 8]
         [4 5 6 7 1 2 3 9 0 8], [7 1 2 3 4 5 6 9 8 0]
         ]
+
+    Verify the construction from [KD2015]_::
+
+        sage: designs.mutually_orthogonal_latin_squares(2, 9)
+        [
+        [0 1 2 3 4 5 6 7 8]  [0 1 2 3 4 5 6 7 8]
+        [2 3 6 4 1 8 0 5 7]  [3 8 4 7 5 2 1 0 6]
+        [3 8 4 7 5 2 1 0 6]  [4 7 1 5 8 6 3 2 0]
+        [4 7 1 5 8 6 3 2 0]  [5 0 8 2 6 1 7 4 3]
+        [5 0 8 2 6 1 7 4 3]  [6 4 0 1 3 7 2 8 5]
+        [6 4 0 1 3 7 2 8 5]  [7 6 5 0 2 4 8 3 1]
+        [7 6 5 0 2 4 8 3 1]  [8 2 7 6 0 3 5 1 4]
+        [8 2 7 6 0 3 5 1 4]  [1 5 3 8 7 0 4 6 2]
+        [1 5 3 8 7 0 4 6 2], [2 3 6 4 1 8 0 5 7]
+        ]
     """
     from sage.combinat.designs.orthogonal_arrays import orthogonal_array
     from sage.matrix.constructor import Matrix
@@ -366,6 +383,22 @@ def mutually_orthogonal_latin_squares(k, n, partitions=False, check=True):
 
         matrices = construction()[:k]
 
+    # Implements the construction from Theorem 5.2.4 of [KD2015]_ for prime powers.
+    # This was implemented to fix :issue:`26107`, which pointed out that this
+    # function was unacceptably slow when n was a large prime power
+    elif is_prime_power(n):
+        F = list(GF(n))
+
+        # We need the first element of the list to be 0
+        assert F[0] == 0
+
+        # This dictionary is used to convert from field elements to integers
+        conv = {F[i] : i for i in range(n)}
+
+        # Make the matrices
+        matrices = [Matrix([[conv[F[i] + F[r]*F[j]] for i in range(n)]
+                 for j in range(n)]) for r in range(1, k+1)]
+
     elif orthogonal_array(k + 2, n, existence=True) is not Unknown:
         # Forwarding non-existence results
         if orthogonal_array(k + 2, n, existence=True):
