@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.combinat sage.groups sage.modules
 r"""
-Latin Squares
+Latin squares
 
 A *latin square* of order `n` is an `n \times n` array such that
 each symbol `s \in \{ 0, 1, \dots, n-1\}` appears precisely once in each
@@ -728,10 +728,7 @@ class LatinSquare:
             return False
 
         # By necessity self must be a partial latin square:
-        if not self.is_partial_latin_square():
-            return False
-
-        return True
+        return self.is_partial_latin_square()
 
     def permissable_values(self, r, c):
         """
