@@ -1,10 +1,10 @@
 # sage.doctest: needs sage.combinat sage.modules
 """
-Symmetric Functions in Non-Commuting Variables
+Symmetric functions in non-commuting variables
 
 AUTHORS:
 
-- Travis Scrimshaw (08-04-2013): Initial version
+- Travis Scrimshaw (08-04-2013): initial version
 """
 # ****************************************************************************
 #       Copyright (C) 2013 Travis Scrimshaw <tscrim at ucdavis.edu>
@@ -293,7 +293,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
         -4*p[] + 2*p[1] + p[2, 2]
     """
 
-    def __init__(self, R):
+    def __init__(self, R) -> None:
         """
         Initialize ``self``.
 
@@ -309,7 +309,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
         category = GradedHopfAlgebras(R).Cocommutative()
         Parent.__init__(self, category=category.WithRealizations())
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         r"""
         EXAMPLES::
 
@@ -322,9 +322,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
         r"""
         Return the realization of the powersum basis of ``self``.
 
-        OUTPUT:
-
-        - The powersum basis of symmetric functions in non-commuting variables.
+        OUTPUT: the powersum basis of symmetric functions in non-commuting variables
 
         EXAMPLES::
 
@@ -333,7 +331,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
         """
         return self.powersum()
 
-    _shorthands = tuple(['chi', 'cp', 'm', 'e', 'h', 'p', 'rho', 'x'])
+    _shorthands = ('chi', 'cp', 'm', 'e', 'h', 'p', 'rho', 'x')
 
     def dual(self):
         r"""
@@ -386,11 +384,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the powersum basis
+            OUTPUT: an element of the powersum basis
 
             TESTS::
 
@@ -403,10 +399,8 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
             def lt(s, t):
                 if s == t:
                     return False
-                for p in s:
-                    if len([z for z in t if z.intersection(p)]) != 1:
-                        return False
-                return True
+                return all(len([1 for z in t if z.intersection(p)]) == 1
+                           for p in s)
 
             p = self.realization_of().p()
             P = Poset((A.coarsenings(), lt))
@@ -420,11 +414,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{cp}` basis
+            OUTPUT: an element of the `\mathbf{cp}` basis
 
             TESTS::
 
@@ -457,9 +449,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             - ``f`` -- an element of the symmetric functions
 
-            OUTPUT:
-
-            - An element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             EXAMPLES::
 
@@ -500,9 +490,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
             r"""
             Return the dual basis to the monomial basis.
 
-            OUTPUT:
-
-            - the `\mathbf{w}` basis of the dual Hopf algebra
+            OUTPUT: the `\mathbf{w}` basis of the dual Hopf algebra
 
             EXAMPLES::
 
@@ -524,9 +512,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
             - ``y`` -- an element of the dual of symmetric functions in
               non-commuting variables
 
-            OUTPUT:
-
-            - an element of the base ring of ``self``
+            OUTPUT: an element of the base ring of ``self``
 
             EXAMPLES::
 
@@ -564,9 +550,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             - ``A``, ``B`` -- set partitions
 
-            OUTPUT:
-
-            - an element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             EXAMPLES::
 
@@ -621,7 +605,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
             OUTPUT:
 
@@ -695,11 +679,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the tensor square of the `\mathbf{m}` basis
+            OUTPUT: an element of the tensor square of the `\mathbf{m}` basis
 
             EXAMPLES::
 
@@ -746,11 +728,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``la`` -- an integer partition
+            - ``la`` -- integer partition
 
-            OUTPUT:
-
-            - an element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             EXAMPLES::
 
@@ -789,8 +769,8 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
                 INPUT:
 
-                - ``n`` -- an integer
-                - ``alphabet`` -- (default: ``'x'``) a string
+                - ``n`` -- integer
+                - ``alphabet`` -- string (default: ``'x'``)
 
                 OUTPUT:
 
@@ -845,9 +825,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
                 taking the sizes of the parts and `n_i(\mu)` is the
                 multiplicity of `i` in `\mu`.
 
-                OUTPUT:
-
-                - an element of the symmetric functions in the monomial basis
+                OUTPUT: an element of the symmetric functions in the monomial basis
 
                 EXAMPLES::
 
@@ -894,15 +872,15 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
             #   get the coercion path m -> p -> e
             p = NCSym.p()
             self.module_morphism(self._e_to_p_on_basis, codomain=p,
-                                 triangular="upper").register_as_coercion()
+                                 triangular='upper').register_as_coercion()
             p.module_morphism(p._p_to_e_on_basis, codomain=self,
-                              triangular="upper").register_as_coercion()
+                              triangular='upper').register_as_coercion()
             # homogeneous
             h = NCSym.h()
             self.module_morphism(self._e_to_h_on_basis, codomain=h,
-                                 triangular="upper").register_as_coercion()
+                                 triangular='upper').register_as_coercion()
             h.module_morphism(h._h_to_e_on_basis, codomain=self,
-                              triangular="upper").register_as_coercion()
+                              triangular='upper').register_as_coercion()
 
         @cached_method
         def _e_to_m_on_basis(self, A):
@@ -911,11 +889,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             TESTS::
 
@@ -940,11 +916,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{h}` basis
+            OUTPUT: an element of the `\mathbf{h}` basis
 
             TESTS::
 
@@ -968,11 +942,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{p}` basis
+            OUTPUT: an element of the `\mathbf{p}` basis
 
             TESTS::
 
@@ -1000,9 +972,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
                 The involution `\omega` on `NCSym` is defined by
                 `\omega(\mathbf{e}_A) = \mathbf{h}_A`.
 
-                OUTPUT:
-
-                - an element in the basis ``self``
+                OUTPUT: an element in the basis ``self``
 
                 EXAMPLES::
 
@@ -1038,9 +1008,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
                 where `\lambda(A)` is the partition associated with `A` by
                 taking the sizes of the parts.
 
-                OUTPUT:
-
-                - An element of the symmetric functions in the elementary basis
+                OUTPUT: an element of the symmetric functions in the elementary basis
 
                 EXAMPLES::
 
@@ -1096,11 +1064,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             TESTS::
 
@@ -1124,11 +1090,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{e}` basis
+            OUTPUT: an element of the `\mathbf{e}` basis
 
             TESTS::
 
@@ -1153,11 +1117,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{p}` basis
+            OUTPUT: an element of the `\mathbf{p}` basis
 
             TESTS::
 
@@ -1185,9 +1147,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
                 The involution `\omega` on `NCSym` is defined by
                 `\omega(\mathbf{h}_A) = \mathbf{e}_A`.
 
-                OUTPUT:
-
-                - an element in the basis ``self``
+                OUTPUT: an element in the basis ``self``
 
                 EXAMPLES::
 
@@ -1223,9 +1183,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
                 where `\lambda(A)` is the partition associated with `A` by
                 taking the sizes of the parts.
 
-                OUTPUT:
-
-                - An element of the symmetric functions in the complete basis
+                OUTPUT: an element of the symmetric functions in the complete basis
 
                 EXAMPLES::
 
@@ -1283,14 +1241,14 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
             # Register coercions
             m = NCSym.m()
             self.module_morphism(self._p_to_m_on_basis, codomain=m,
-                                 unitriangular="lower").register_as_coercion()
+                                 unitriangular='lower').register_as_coercion()
             m.module_morphism(m._m_to_p_on_basis, codomain=self,
-                              unitriangular="lower").register_as_coercion()
+                              unitriangular='lower').register_as_coercion()
             x = NCSym.x()
             self.module_morphism(self._p_to_x_on_basis, codomain=x,
-                                 unitriangular="upper").register_as_coercion()
+                                 unitriangular='upper').register_as_coercion()
             x.module_morphism(x._x_to_p_on_basis, codomain=self,
-                              unitriangular="upper").register_as_coercion()
+                              unitriangular='upper').register_as_coercion()
 
         @cached_method
         def _p_to_m_on_basis(self, A):
@@ -1299,11 +1257,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             TESTS::
 
@@ -1324,11 +1280,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{e}` basis
+            OUTPUT: an element of the `\mathbf{e}` basis
 
             TESTS::
 
@@ -1352,11 +1306,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{h}` basis
+            OUTPUT: an element of the `\mathbf{h}` basis
 
             TESTS::
 
@@ -1380,11 +1332,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - An element of the `\mathbf{x}` basis
+            OUTPUT: an element of the `\mathbf{x}` basis
 
             TESTS::
 
@@ -1405,7 +1355,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
             OUTPUT:
 
@@ -1469,11 +1419,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the tensor square of ``self``
+            OUTPUT: an element of the tensor square of ``self``
 
             EXAMPLES::
 
@@ -1507,11 +1455,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element in the basis ``self``
+            OUTPUT: an element in the basis ``self``
 
             EXAMPLES::
 
@@ -1571,13 +1517,11 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
             - ``i`` -- (default: 1) index in the base set for ``A`` specifying
               which set of primitives this belongs to
 
-            OUTPUT:
-
-            - an element in the basis ``self``
+            OUTPUT: an element in the basis ``self``
 
             EXAMPLES::
 
@@ -1621,9 +1565,7 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
                 where `\lambda(A)` is the partition associated with `A` by
                 taking the sizes of the parts.
 
-                OUTPUT:
-
-                - an element of symmetric functions in the power sum basis
+                OUTPUT: an element of symmetric functions in the power sum basis
 
                 EXAMPLES::
 
@@ -1696,9 +1638,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
             # Register coercions
             m = NCSym.m()
             self.module_morphism(self._cp_to_m_on_basis, codomain=m,
-                                 unitriangular="lower").register_as_coercion()
+                                 unitriangular='lower').register_as_coercion()
             m.module_morphism(m._m_to_cp_on_basis, codomain=self,
-                              unitriangular="lower").register_as_coercion()
+                              unitriangular='lower').register_as_coercion()
 
         @cached_method
         def _cp_to_m_on_basis(self, A):
@@ -1707,11 +1649,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             TESTS::
 
@@ -1776,11 +1716,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the `\mathbf{p}` basis
+            OUTPUT: an element of the `\mathbf{p}` basis
 
             TESTS::
 
@@ -1793,10 +1731,8 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
             def lt(s, t):
                 if s == t:
                     return False
-                for p in s:
-                    if len([z for z in t if z.intersection(p)]) != 1:
-                        return False
-                return True
+                return all(len([1 for z in t if z.intersection(p)]) == 1
+                           for p in s)
 
             p = self.realization_of().p()
             P_refine = Poset((A.refinements(), lt))
@@ -1904,11 +1840,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             TESTS::
 
@@ -1933,11 +1867,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the `\rho` basis
+            OUTPUT: an element of the `\rho` basis
 
             TESTS::
 
@@ -2050,11 +1982,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the `\mathbf{m}` basis
+            OUTPUT: an element of the `\mathbf{m}` basis
 
             TESTS::
 
@@ -2117,11 +2047,9 @@ class SymmetricFunctionsNonCommutingVariables(UniqueRepresentation, Parent):
 
             INPUT:
 
-            - ``A`` -- a set partition
+            - ``A`` -- set partition
 
-            OUTPUT:
-
-            - an element of the `\chi` basis
+            OUTPUT: an element of the `\chi` basis
 
             TESTS::
 
