@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 """
-Ordered Rooted Trees
+Ordered rooted trees
 
 AUTHORS:
 
@@ -23,10 +22,10 @@ from sage.structure.parent import Parent
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
 from sage.misc.lazy_attribute import lazy_class_attribute
+from sage.misc.lazy_import import lazy_import
 from sage.combinat.abstract_tree import (AbstractClonableTree,
                                          AbstractLabelledClonableTree)
 from sage.combinat.combinatorial_map import combinatorial_map
-from sage.combinat.dyck_word import CompleteDyckWords_size
 from sage.misc.cachefunc import cached_method
 from sage.categories.sets_cat import Sets, EmptySetError
 from sage.rings.integer import Integer
@@ -35,6 +34,8 @@ from sage.sets.disjoint_union_enumerated_sets import DisjointUnionEnumeratedSets
 from sage.sets.family import Family
 from sage.rings.infinity import Infinity
 
+lazy_import('sage.combinat.dyck_word', 'CompleteDyckWords_size')
+
 
 class OrderedTree(AbstractClonableTree, ClonableList,
         metaclass=InheritComparisonClasscallMetaclass):
@@ -276,7 +277,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
         """
         return False
 
-    def _to_binary_tree_rec(self, bijection="left"):
+    def _to_binary_tree_rec(self, bijection='left'):
         r"""
         Internal recursive method to obtain a binary tree from an ordered
         tree.
@@ -289,12 +290,12 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             sage: T = OrderedTree([[],[]])
             sage: T._to_binary_tree_rec()
             [[., .], .]
-            sage: T._to_binary_tree_rec(bijection="right")
+            sage: T._to_binary_tree_rec(bijection='right')
             [., [., .]]
             sage: T = OrderedTree([[], [[], []], [[], [[]]]])
             sage: T._to_binary_tree_rec()
             [[[., .], [[., .], .]], [[., .], [., .]]]
-            sage: T._to_binary_tree_rec(bijection="right")
+            sage: T._to_binary_tree_rec(bijection='right')
             [., [[., [., .]], [[., [[., .], .]], .]]]
         """
         from sage.combinat.binary_tree import BinaryTree
@@ -359,21 +360,22 @@ class OrderedTree(AbstractClonableTree, ClonableList,
 
         EXAMPLES::
 
+            sage: # needs sage.combinat sage.modules
             sage: T = OrderedTree([[[], [[], [[]]]], [], [[[],[]]], [], []])
-            sage: T.to_parallelogram_polyomino(bijection='Boussicault-Socci')           # optional - sage.combinat
+            sage: T.to_parallelogram_polyomino(bijection='Boussicault-Socci')
             [[0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1],
              [1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0]]
             sage: T = OrderedTree( [] )
-            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
+            sage: T.to_parallelogram_polyomino()
             [[1], [1]]
             sage: T = OrderedTree( [[]] )
-            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
+            sage: T.to_parallelogram_polyomino()
             [[0, 1], [1, 0]]
             sage: T = OrderedTree( [[],[]] )
-            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
+            sage: T.to_parallelogram_polyomino()
             [[0, 1, 1], [1, 1, 0]]
             sage: T = OrderedTree( [[[]]] )
-            sage: T.to_parallelogram_polyomino()                                        # optional - sage.combinat
+            sage: T.to_parallelogram_polyomino()
             [[0, 0, 1], [1, 0, 0]]
         """
         if (bijection is None) or (bijection == 'Boussicault-Socci'):
@@ -389,22 +391,23 @@ class OrderedTree(AbstractClonableTree, ClonableList,
 
         EXAMPLES::
 
+            sage: # needs sage.combinat sage.modules
             sage: T = OrderedTree(
             ....:     [[[], [[], [[]]]], [], [[[],[]]], [], []]
             ....: )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
             [[0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1], [1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0]]
             sage: T = OrderedTree( [] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
             [[1], [1]]
             sage: T = OrderedTree( [[]] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
             [[0, 1], [1, 0]]
             sage: T = OrderedTree( [[],[]] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
             [[0, 1, 1], [1, 1, 0]]
             sage: T = OrderedTree( [[[]]] )
-            sage: T._to_parallelogram_polyomino_Boussicault_Socci()                     # optional - sage.combinat
+            sage: T._to_parallelogram_polyomino_Boussicault_Socci()
             [[0, 0, 1], [1, 0, 0]]
         """
         from sage.combinat.parallelogram_polyomino import ParallelogramPolyomino
@@ -490,7 +493,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             sage: T == T.to_binary_tree_right_branch().to_ordered_tree_right_branch()
             True
         """
-        return self._to_binary_tree_rec(bijection="right")
+        return self._to_binary_tree_rec(bijection='right')
 
     @combinatorial_map(name="To Dyck path")
     def to_dyck_word(self):
@@ -501,13 +504,13 @@ class OrderedTree(AbstractClonableTree, ClonableList,
         EXAMPLES::
 
             sage: T = OrderedTree([[],[]])
-            sage: T.to_dyck_word()                                                      # optional - sage.combinat
+            sage: T.to_dyck_word()                                                      # needs sage.combinat
             [1, 0, 1, 0]
             sage: T = OrderedTree([[],[[]]])
-            sage: T.to_dyck_word()                                                      # optional - sage.combinat
+            sage: T.to_dyck_word()                                                      # needs sage.combinat
             [1, 0, 1, 1, 0, 0]
             sage: T = OrderedTree([[], [[], []], [[], [[]]]])
-            sage: T.to_dyck_word()                                                      # optional - sage.combinat
+            sage: T.to_dyck_word()                                                      # needs sage.combinat
             [1, 0, 1, 1, 0, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0, 0]
         """
         word = []
@@ -588,8 +591,8 @@ class OrderedTree(AbstractClonableTree, ClonableList,
 
         INPUT:
 
-        - ``root_to_leaf`` -- boolean, true if the poset orientation should
-          be from root to leaves. It is false by default.
+        - ``root_to_leaf`` -- boolean (default: ``False``); ``True`` if the
+          poset orientation should be from root to leaves
 
         EXAMPLES::
 
@@ -597,14 +600,14 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             sage: t.to_poset()
             Finite poset containing 1 elements
             sage: p = OrderedTree([[[]],[],[]]).to_poset()
-            sage: p.height(), p.width()
+            sage: p.height(), p.width()                                                 # needs networkx
             (3, 3)
 
         If the tree is labelled, we use its labelling to label the poset.
         Otherwise, we use the poset canonical labelling::
 
             sage: t = OrderedTree([[[]],[],[]]).canonical_labelling().to_poset()
-            sage: t.height(), t.width()
+            sage: t.height(), t.width()                                                 # needs networkx
             (3, 3)
         """
         if self in LabelledOrderedTrees():
@@ -675,7 +678,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             o o o
             |
             o
-            sage: p.plot()                                                              # optional - sage.plot
+            sage: p.plot()                                                              # needs sage.plot
             Graphics object consisting of 10 graphics primitives
 
         .. PLOT::
@@ -692,7 +695,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
             2 3 5
               |
               4
-            sage: g.plot()                                                              # optional - sage.plot
+            sage: g.plot()                                                              # needs sage.plot
             Graphics object consisting of 10 graphics primitives
 
         .. PLOT::
@@ -706,8 +709,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
         except AttributeError:
             root = 1
             g = self.canonical_labelling().to_undirected_graph()
-        return g.plot(layout='tree', tree_root=root,
-                      tree_orientation="down")
+        return g.plot(layout='tree', tree_root=root, tree_orientation='down')
 
     def sort_key(self):
         """
@@ -772,7 +774,7 @@ class OrderedTree(AbstractClonableTree, ClonableList,
 
         INPUT:
 
-        - ``inplace`` -- boolean, (default ``False``) if ``True``,
+        - ``inplace`` -- boolean (default: ``False``); if ``True``,
           then ``self`` is modified and nothing returned. Otherwise
           the normalized tree is returned.
 
@@ -832,11 +834,11 @@ class OrderedTree(AbstractClonableTree, ClonableList,
 # Abstract class to serve as a Factory no instance are created.
 class OrderedTrees(UniqueRepresentation, Parent):
     """
-    Factory for ordered trees
+    Factory for ordered trees.
 
     INPUT:
 
-    - ``size`` -- (optional) an integer
+    - ``size`` -- integer (optional)
 
     OUTPUT:
 
@@ -878,13 +880,13 @@ class OrderedTrees(UniqueRepresentation, Parent):
             return OrderedTrees_all()
         else:
             if not (isinstance(n, (Integer, int)) and n >= 0):
-                raise ValueError("n must be a non negative integer")
+                raise ValueError("n must be a nonnegative integer")
             return OrderedTrees_size(Integer(n))
 
     @cached_method
     def leaf(self):
         """
-        Return a leaf tree with ``self`` as parent
+        Return a leaf tree with ``self`` as parent.
 
         EXAMPLES::
 
@@ -932,7 +934,7 @@ class OrderedTrees_all(DisjointUnionEnumeratedSets, OrderedTrees):
             sage: B is OrderedTrees_all()
             True
             sage: TestSuite(B).run() # long time
-            """
+        """
         DisjointUnionEnumeratedSets.__init__(
             self, Family(NonNegativeIntegers(), OrderedTrees_size),
             facade=True, keepkey=False)
@@ -960,7 +962,7 @@ class OrderedTrees_all(DisjointUnionEnumeratedSets, OrderedTrees):
 
     def unlabelled_trees(self):
         """
-        Return the set of unlabelled trees associated to ``self``
+        Return the set of unlabelled trees associated to ``self``.
 
         EXAMPLES::
 
@@ -971,7 +973,7 @@ class OrderedTrees_all(DisjointUnionEnumeratedSets, OrderedTrees):
 
     def labelled_trees(self):
         """
-        Return the set of labelled trees associated to ``self``
+        Return the set of labelled trees associated to ``self``.
 
         EXAMPLES::
 
@@ -1003,7 +1005,7 @@ from sage.combinat.composition import Compositions
 
 class OrderedTrees_size(OrderedTrees):
     """
-    The enumerated sets of binary trees of a given size
+    The enumerated sets of binary trees of a given size.
 
     EXAMPLES::
 
@@ -1060,7 +1062,7 @@ class OrderedTrees_size(OrderedTrees):
 
     def cardinality(self):
         """
-        The cardinality of ``self``
+        The cardinality of ``self``.
 
         This is a Catalan number.
 
@@ -1088,18 +1090,18 @@ class OrderedTrees_size(OrderedTrees):
 
         EXAMPLES::
 
-            sage: OrderedTrees(5).random_element()  # random                            # optional - sage.combinat
+            sage: OrderedTrees(5).random_element()  # random                            # needs sage.combinat
             [[[], []], []]
-            sage: OrderedTrees(0).random_element()                                      # optional - sage.combinat
+            sage: OrderedTrees(0).random_element()
             Traceback (most recent call last):
             ...
             EmptySetError: there are no ordered trees of size 0
-            sage: OrderedTrees(1).random_element()                                      # optional - sage.combinat
+            sage: OrderedTrees(1).random_element()                                      # needs sage.combinat
             []
 
         TESTS::
 
-            sage: all(OrderedTrees(10).random_element() in OrderedTrees(10)             # optional - sage.combinat
+            sage: all(OrderedTrees(10).random_element() in OrderedTrees(10)             # needs sage.combinat
             ....:     for i in range(20))
             True
         """
@@ -1109,7 +1111,7 @@ class OrderedTrees_size(OrderedTrees):
 
     def __iter__(self):
         """
-        A basic generator
+        A basic generator.
 
         .. TODO:: could be optimized.
 
@@ -1135,7 +1137,7 @@ class OrderedTrees_size(OrderedTrees):
     @lazy_attribute
     def _parent_for(self):
         """
-        Return the parent of the element generated by ``self``
+        Return the parent of the element generated by ``self``.
 
         TESTS::
 
@@ -1147,7 +1149,7 @@ class OrderedTrees_size(OrderedTrees):
     @lazy_attribute
     def element_class(self):
         """
-        The class of the element of ``self``
+        The class of the element of ``self``.
 
         EXAMPLES::
 
@@ -1189,7 +1191,7 @@ class LabelledOrderedTree(AbstractLabelledClonableTree, OrderedTree):
 
     INPUT:
 
-    - ``children`` -- a list or tuple or more generally any iterable
+    - ``children`` -- list or tuple or more generally any iterable
       of trees or object convertible to trees
     - ``label`` -- any Sage object (default: ``None``)
 
@@ -1395,7 +1397,7 @@ class LabelledOrderedTrees(UniqueRepresentation, Parent):
         t = LT([], label=3)
         t1 = LT([t, t], label=42)
         t2 = LT([[]], label=5)
-        return LT([t, t1, t2], label="toto")
+        return LT([t, t1, t2], label='toto')
 
     def _element_constructor_(self, *args, **keywords):
         """
