@@ -1,7 +1,6 @@
 # sage.doctest: needs sage.combinat sage.modules
 r"""
-Schubert Polynomials
-
+Schubert polynomials
 
 See :wikipedia:`Schubert_polynomial` and
 `SymmetricFunctions.com <https://www.symmetricfunctions.com/schubert.htm#schubert>`_.
