@@ -56,9 +56,7 @@ class Character_generic(SFA_generic):
 
         - ``la`` -- a partition
 
-        OUTPUT:
-
-        - an integer
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -128,11 +126,9 @@ class Character_generic(SFA_generic):
 
         INPUT:
 
-        - ``k`` -- a positive integer
+        - ``k`` -- positive integer
 
-        OUTPUT:
-
-        - an expression in the powersum basis of the symmetric functions
+        OUTPUT: an expression in the powersum basis of the symmetric functions
 
         EXAMPLES::
 
@@ -143,7 +139,6 @@ class Character_generic(SFA_generic):
             -1/2*p[1] + 1/2*p[2]
             sage: st._b_power_k(6)
             1/6*p[1] - 1/6*p[2] - 1/6*p[3] + 1/6*p[6]
-
         """
         if k == 1:
             return self._p([1])
@@ -224,7 +219,7 @@ class InducedTrivialCharacterBasis(Character_generic):
         """
         SFA_generic.__init__(self, Sym,
                              basis_name="induced trivial symmetric group character",
-                             prefix="ht", graded=False)
+                             prefix='ht', graded=False)
         self._other = Sym.complete()
         self._p = Sym.powersum()
 
@@ -248,9 +243,7 @@ class InducedTrivialCharacterBasis(Character_generic):
 
         - ``k``, ``r`` -- positive integers
 
-        OUTPUT:
-
-        - an expression in the powersum basis of the symmetric functions
+        OUTPUT: an expression in the powersum basis of the symmetric functions
 
         EXAMPLES::
 
@@ -261,7 +254,6 @@ class InducedTrivialCharacterBasis(Character_generic):
             2*p[1] + p[1, 1] - 2*p[2] - 2*p[2, 1] + p[2, 2]
             sage: ht._b_bar_power_k_r(3,2)
             3*p[1] + p[1, 1] - 3*p[3] - 2*p[3, 1] + p[3, 3]
-
         """
         p = self._p
         return k**r * p.prod( self._b_power_k(k)-j for j in range(r) )
@@ -288,9 +280,7 @@ class InducedTrivialCharacterBasis(Character_generic):
 
         - ``gamma`` -- a partition
 
-        OUTPUT:
-
-        - an expression in the powersum basis of the symmetric functions
+        OUTPUT: an expression in the powersum basis of the symmetric functions
 
         EXAMPLES::
 
@@ -301,7 +291,6 @@ class InducedTrivialCharacterBasis(Character_generic):
             2*p[1] - 3*p[1, 1] + p[1, 1, 1]
             sage: ht._b_bar_power_gamma(Partition([3,3,1]))
             3*p[1, 1] + p[1, 1, 1] - 3*p[3, 1] - 2*p[3, 1, 1] + p[3, 3, 1]
-
         """
         return self._p.prod(self._b_bar_power_k_r(Integer(k), Integer(r))
                             for k, r in gamma.to_exp_dict().items())
@@ -326,9 +315,7 @@ class InducedTrivialCharacterBasis(Character_generic):
 
         - ``lam`` -- a partition
 
-        OUTPUT:
-
-        - an expression in the power sum basis
+        OUTPUT: an expression in the power sum basis
 
         EXAMPLES::
 
@@ -337,7 +324,6 @@ class InducedTrivialCharacterBasis(Character_generic):
             p[1] - 2*p[1, 1] + 1/2*p[1, 1, 1] + 1/2*p[2, 1]
             sage: ht._self_to_power_on_basis([1,1,1])
             2*p[1] - 3*p[1, 1] + p[1, 1, 1]
-
         """
         return self._p.sum( c*self._b_bar_power_gamma(ga)
                             for (ga, c) in self._p(self._other(lam)) )
@@ -451,7 +437,7 @@ class IrreducibleCharacterBasis(Character_generic):
         """
         SFA_generic.__init__(self, Sym,
                              basis_name="irreducible symmetric group character",
-                             prefix="st", graded=False)
+                             prefix='st', graded=False)
         self._other = Sym.Schur()
         self._p = Sym.powersum()
 
@@ -475,9 +461,7 @@ class IrreducibleCharacterBasis(Character_generic):
 
         - ``k``, ``r`` -- positive integers
 
-        OUTPUT:
-
-        - an expression in the powersum basis of the symmetric functions
+        OUTPUT: an expression in the powersum basis of the symmetric functions
 
         EXAMPLES::
 
@@ -488,7 +472,6 @@ class IrreducibleCharacterBasis(Character_generic):
             p[] + 4*p[1] + p[1, 1] - 4*p[2] - 2*p[2, 1] + p[2, 2]
             sage: st._b_power_k_r(3,2)
             p[] + 5*p[1] + p[1, 1] - 5*p[3] - 2*p[3, 1] + p[3, 3]
-
         """
         p = self._p
         return p.sum( (-1)**(r-j) * k**j * binomial(r,j)
@@ -517,9 +500,7 @@ class IrreducibleCharacterBasis(Character_generic):
 
         - ``gamma`` -- a partition
 
-        OUTPUT:
-
-        - an expression in the powersum basis of the symmetric functions
+        OUTPUT: an expression in the powersum basis of the symmetric functions
 
         EXAMPLES::
 
@@ -530,7 +511,6 @@ class IrreducibleCharacterBasis(Character_generic):
             -p[] + 8*p[1] - 6*p[1, 1] + p[1, 1, 1]
             sage: st._b_power_gamma(Partition([3,1]))
             p[] - p[1, 1] - p[3] + p[3, 1]
-
         """
         return self._p.prod(self._b_power_k_r(Integer(k), Integer(r))
                             for k, r in gamma.to_exp_dict().items())
@@ -557,9 +537,7 @@ class IrreducibleCharacterBasis(Character_generic):
 
         - ``lam`` -- a partition
 
-        OUTPUT:
-
-        - an expression in the power sum basis
+        OUTPUT: an expression in the power sum basis
 
         EXAMPLES::
 
@@ -568,7 +546,6 @@ class IrreducibleCharacterBasis(Character_generic):
             3*p[1] - 2*p[1, 1] + 1/3*p[1, 1, 1] - 1/3*p[3]
             sage: st._self_to_power_on_basis([1,1])
             p[] - p[1] + 1/2*p[1, 1] - 1/2*p[2]
-
         """
         return self._p.sum( c*self._b_power_gamma(ga)
                             for (ga, c) in self._p(self._other(lam)) )
@@ -585,9 +562,7 @@ class IrreducibleCharacterBasis(Character_generic):
 
         - ``lam`` -- a partition
 
-        OUTPUT:
-
-        - an expression in the Schur basis
+        OUTPUT: an expression in the Schur basis
 
         EXAMPLES::
 
