@@ -1,8 +1,8 @@
 # sage.doctest: needs sage.combinat sage.modules
 r"""
-Tiling Solver
+Tiling solver
 
-Tiling a n-dimensional polyomino with n-dimensional polyominoes.
+Tiling a `n`-dimensional polyomino with n-dimensional polyominoes.
 
 This module defines two classes:
 
@@ -157,7 +157,7 @@ The following is a puzzle owned by Florent Hivert::
     sage: L.append(Polyomino([(0,0),(0,1),(0,2),(1,0),(1,1),(1,2)],"pink"))
 
 By default, rotations are allowed and reflections are not. In this case,
-there are no solution for tiling a `8 \times 8` rectangular box::
+there are no solutions for tiling a `8 \times 8` rectangular box::
 
     sage: T = TilingSolver(L, box=(8,8))
     sage: T.number_of_solutions()                                       # long time (2.5s)
@@ -304,12 +304,10 @@ def ncube_isometry_group(n, orientation_preserving=True):
     INPUT:
 
     - ``n`` -- positive integer, dimension of the space
-    - ``orientation_preserving`` -- bool (default: ``True``),
+    - ``orientation_preserving`` -- boolean (default: ``True``);
       whether the orientation is preserved
 
-    OUTPUT:
-
-    list of matrices
+    OUTPUT: list of matrices
 
     EXAMPLES::
 
@@ -372,12 +370,10 @@ def ncube_isometry_group_cosets(n, orientation_preserving=True):
     INPUT:
 
     - ``n`` -- positive integer, dimension of the space
-    - ``orientation_preserving`` -- bool (default: ``True``),
+    - ``orientation_preserving`` -- boolean (default: ``True``);
       whether the orientation is preserved
 
-    OUTPUT:
-
-    list of cosets, each coset being a sorted list of matrices
+    OUTPUT: list of cosets, each coset being a sorted list of matrices
 
     EXAMPLES::
 
@@ -485,8 +481,8 @@ class Polyomino(SageObject):
     INPUT:
 
     - ``coords`` -- iterable of integer coordinates in `\ZZ^d`
-    - ``color`` -- string (default: ``'gray'``), color for display
-    - ``dimension`` -- integer (default: ``None``), dimension of the space,
+    - ``color`` -- string (default: ``'gray'``); color for display
+    - ``dimension`` -- integer (default: ``None``); dimension of the space,
       if ``None``, it is guessed from the ``coords`` if ``coords`` is non
       empty
 
@@ -518,7 +514,6 @@ class Polyomino(SageObject):
 
             sage: Polyomino([], dimension=2)
             Polyomino: [], Color: gray
-
         """
         from sage.modules.free_module import FreeModule
         from sage.rings.integer_ring import ZZ
@@ -666,9 +661,7 @@ class Polyomino(SageObject):
 
         - ``other`` -- a polyomino
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -691,9 +684,7 @@ class Polyomino(SageObject):
 
         - ``other`` -- a polyomino
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -716,9 +707,7 @@ class Polyomino(SageObject):
 
         - ``other`` -- a polyomino
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -740,9 +729,7 @@ class Polyomino(SageObject):
 
         - ``other`` -- a polyomino
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -764,9 +751,7 @@ class Polyomino(SageObject):
 
         - ``other`` -- a polyomino
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -788,9 +773,7 @@ class Polyomino(SageObject):
 
         - ``other`` -- a polyomino
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -812,9 +795,7 @@ class Polyomino(SageObject):
 
         - ``other`` -- a polyomino
 
-        OUTPUT:
-
-        polyomino
+        OUTPUT: polyomino
 
         EXAMPLES::
 
@@ -840,9 +821,7 @@ class Polyomino(SageObject):
 
         - ``v`` -- tuple
 
-        OUTPUT:
-
-        polyomino
+        OUTPUT: polyomino
 
         EXAMPLES::
 
@@ -862,9 +841,7 @@ class Polyomino(SageObject):
 
         - ``v`` -- tuple
 
-        OUTPUT:
-
-        polyomino
+        OUTPUT: polyomino
 
         EXAMPLES::
 
@@ -883,11 +860,9 @@ class Polyomino(SageObject):
 
         INPUT:
 
-        - ``m`` -- square matrix, matching the dimension of ``self``.
+        - ``m`` -- square matrix, matching the dimension of ``self``
 
-        OUTPUT:
-
-        Polyomino
+        OUTPUT: polyomino
 
         EXAMPLES::
 
@@ -947,18 +922,16 @@ class Polyomino(SageObject):
 
         INPUT:
 
-        - ``orientation_preserving`` -- bool (default: ``True``);
+        - ``orientation_preserving`` -- boolean (default: ``True``);
           if ``True``, the group of isometries of the `n`-cube is restricted
           to those that preserve the orientation, i.e. of determinant 1.
 
-        - ``mod_box_isometries`` -- bool (default: ``False``), whether to
+        - ``mod_box_isometries`` -- boolean (default: ``False``); whether to
           quotient the group of isometries of the `n`-cube by the
           subgroup of isometries of the `a_1\times a_2\cdots \times a_n`
           rectangular box where are the `a_i` are assumed to be distinct.
 
-        OUTPUT:
-
-        set of Polyomino
+        OUTPUT: set of Polyomino
 
         EXAMPLES::
 
@@ -1006,11 +979,9 @@ class Polyomino(SageObject):
 
         INPUT:
 
-        - ``box`` -- Polyomino or tuple of integers (size of a box)
+        - ``box`` -- polyomino or tuple of integers (size of a box)
 
-        OUTPUT:
-
-        iterator of 3d polyominoes
+        OUTPUT: iterator of 3d polyominoes
 
         EXAMPLES::
 
@@ -1095,9 +1066,8 @@ class Polyomino(SageObject):
         minxyz, maxxyz = vector(minxyz), vector(maxxyz)
         size = maxxyz - minxyz
         boxminxyz, boxmaxxyz = box.bounding_box()
-        ranges = [range(a, b-c+1) for (a,b,c) in zip(boxminxyz,
-                                                   boxmaxxyz,
-                                                   size)]
+        ranges = [range(a, b - c + 1)
+                  for a, b, c in zip(boxminxyz, boxmaxxyz, size)]
         cano = self.canonical()
         for v in itertools.product(*ranges):
             translated = cano + v
@@ -1111,11 +1081,9 @@ class Polyomino(SageObject):
 
         INPUT:
 
-        - ``box`` -- Polyomino or tuple of integers (size of a box)
+        - ``box`` -- polyomino or tuple of integers (size of a box)
 
-        OUTPUT:
-
-        set of 3d polyominoes
+        OUTPUT: set of 3d polyominoes
 
         EXAMPLES::
 
@@ -1140,7 +1108,6 @@ class Polyomino(SageObject):
             sage: sorted(sorted(a.frozenset())
             ....:        for a in p.translated_copies_intersection(b))
             [[(0, 0)], [(0, 0), (1, 0)], [(0, 1)], [(0, 2)], [(1, 0), (2, 0)], [(2, 0)]]
-
         """
         if not isinstance(box, Polyomino):
             ranges = [range(a) for a in box]
@@ -1152,9 +1119,8 @@ class Polyomino(SageObject):
         minxyz, maxxyz = vector(minxyz), vector(maxxyz)
         size = maxxyz - minxyz
         boxminxyz, boxmaxxyz = box.bounding_box()
-        ranges = [range(a-c, b+1) for (a,b,c) in zip(boxminxyz,
-                                                   boxmaxxyz,
-                                                   size)]
+        ranges = [range(a - c, b + 1)
+                  for a, b, c in zip(boxminxyz, boxmaxxyz, size)]
         S = set()
         cano = self.canonical()
         for v in itertools.product(*ranges):
@@ -1165,19 +1131,19 @@ class Polyomino(SageObject):
         return S
 
     def isometric_copies(self, box, orientation_preserving=True,
-            mod_box_isometries=False):
+                         mod_box_isometries=False):
         r"""
         Return the translated and isometric images of ``self`` that lies in the box.
 
         INPUT:
 
-        - ``box`` -- Polyomino or tuple of integers (size of a box)
+        - ``box`` -- polyomino or tuple of integers (size of a box)
 
-        - ``orientation_preserving`` -- bool (default: ``True``);
-          If ``True``, the group of isometries of the `n`-cube is restricted
+        - ``orientation_preserving`` -- boolean (default: ``True``);
+          if ``True``, the group of isometries of the `n`-cube is restricted
           to those that preserve the orientation, i.e. of determinant 1.
 
-        - ``mod_box_isometries`` -- bool (default: ``False``), whether to
+        - ``mod_box_isometries`` -- boolean (default: ``False``); whether to
           quotient the group of isometries of the `n`-cube by the
           subgroup of isometries of the `a_1\times a_2\cdots \times a_n`
           rectangular box where are the `a_i` are assumed to be distinct.
@@ -1239,9 +1205,9 @@ class Polyomino(SageObject):
 
         INPUT:
 
-        - ``box`` -- Polyomino or tuple of integers (size of a box)
+        - ``box`` -- polyomino or tuple of integers (size of a box)
 
-        - ``orientation_preserving`` -- bool (default: ``True``);
+        - ``orientation_preserving`` -- boolean (default: ``True``);
           if ``True``, the group of isometries of the `n`-cube is restricted
           to those that preserve the orientation, i.e. of determinant 1.
 
@@ -1263,7 +1229,6 @@ class Polyomino(SageObject):
              [(1, 1)],
              [(1, 1), (1, 2)],
              [(1, 2)]]
-
         """
         all_distinct_cano = self.canonical_isometric_copies(orientation_preserving,
                                                             mod_box_isometries=False)
@@ -1394,7 +1359,7 @@ class Polyomino(SageObject):
         INPUT:
 
         - ``self`` -- a polyomino of dimension 3
-        - ``size`` -- number (default: ``1``), the size of each
+        - ``size`` -- number (default: ``1``); the size of each
           ``1 \times 1 \times 1`` cube. This does a homothety with respect
           to the center of the polyomino.
 
@@ -1424,12 +1389,9 @@ class Polyomino(SageObject):
         INPUT:
 
         - ``self`` -- a polyomino of dimension 2
-        - ``size`` -- number (default: ``0.7``), the size of each
-          square.
-        - ``color`` -- color (default: ``'black'``), color of
-          the boundary line.
-        - ``thickness`` -- number (default: ``1``), how thick the
-          boundary line is.
+        - ``size`` -- number (default: ``0.7``); the size of each square
+        - ``color`` -- color (default: ``'black'``); color of the boundary line
+        - ``thickness`` -- number (default: ``1``); how thick the boundary line is
 
         EXAMPLES::
 
@@ -1466,17 +1428,15 @@ class Polyomino(SageObject):
 
         - ``self`` -- a polyomino of dimension 2
         - ``radius`` -- integer
-        - ``remove_incomplete_copies`` -- bool (default: ``True``), whether
+        - ``remove_incomplete_copies`` -- boolean (default: ``True``); whether
           to keep only complete copies of ``self`` in the output
-        - ``ncpus`` -- integer (default: ``None``), maximal number of
+        - ``ncpus`` -- integer (default: ``None``); maximal number of
           subprocesses to use at the same time. If ``None``, it detects the
           number of effective CPUs in the system using
           :func:`sage.parallel.ncpus.ncpus()`.
           If ``ncpus=1``, the first solution is searched serially.
 
-        OUTPUT:
-
-        list of polyominoes
+        OUTPUT: list of polyominoes
 
         EXAMPLES::
 
@@ -1492,7 +1452,6 @@ class Polyomino(SageObject):
 
             sage: solution = H.self_surrounding(8, remove_incomplete_copies=False)
             sage: G = sum([p.show2d() for p in solution], Graphics())                   # needs sage.plot
-
         """
         # Define the box to tile
         minxyz, maxxyz = self.bounding_box()
@@ -1545,7 +1504,7 @@ class Polyomino(SageObject):
 #######################
 class TilingSolver(SageObject):
     r"""
-    Tiling solver
+    Tiling solver.
 
     Solve the problem of tiling a polyomino with a certain number
     of polyominoes.
@@ -1553,14 +1512,14 @@ class TilingSolver(SageObject):
     INPUT:
 
     - ``pieces`` -- iterable of Polyominoes
-    - ``box`` -- Polyomino or tuple of integers (size of a box)
-    - ``rotation`` -- bool (default: ``True``), whether to allow
+    - ``box`` -- polyomino or tuple of integers (size of a box)
+    - ``rotation`` -- boolean (default: ``True``); whether to allow
       rotations
-    - ``reflection`` -- bool (default: ``False``), whether to allow
+    - ``reflection`` -- boolean (default: ``False``); whether to allow
       reflections
-    - ``reusable`` -- bool (default: ``False``), whether to allow
+    - ``reusable`` -- boolean (default: ``False``); whether to allow
       the pieces to be reused
-    - ``outside`` -- bool (default: ``False``), whether to allow
+    - ``outside`` -- boolean (default: ``False``); whether to allow
       pieces to partially go outside of the box (all non-empty intersection
       of the pieces with the box are considered)
 
@@ -1645,7 +1604,7 @@ class TilingSolver(SageObject):
 
     def _repr_(self):
         r"""
-        String representation
+        String representation.
 
         EXAMPLES::
 
@@ -1658,7 +1617,6 @@ class TilingSolver(SageObject):
             Rotation allowed: True
             Reflection allowed: False
             Reusing pieces allowed: False
-
         """
         s = "Tiling solver of %s pieces " % len(self._pieces)
         s += "into a box of size %s\n" % len(self._box)
@@ -1699,9 +1657,7 @@ class TilingSolver(SageObject):
         r"""
         Return the list of pieces.
 
-        OUTPUT:
-
-        list of 3d polyominoes
+        OUTPUT: list of 3d polyominoes
 
         EXAMPLES::
 
@@ -1719,7 +1675,7 @@ class TilingSolver(SageObject):
 
     def space(self):
         r"""
-        Return an iterator over all the non negative integer coordinates
+        Return an iterator over all the nonnegative integer coordinates
         contained in the space to tile.
 
         EXAMPLES::
@@ -1739,9 +1695,7 @@ class TilingSolver(SageObject):
         r"""
         Return a dictionary mapping coordinates to integers.
 
-        OUTPUT:
-
-        dict
+        OUTPUT: dictionary
 
         EXAMPLES::
 
@@ -1822,9 +1776,9 @@ class TilingSolver(SageObject):
 
         INPUT:
 
-        - ``i`` -- integer, the `i`-th piece
+        - ``i`` -- integer; the `i`-th piece
 
-        - ``mod_box_isometries`` -- bool (default: ``False``), whether to
+        - ``mod_box_isometries`` -- boolean (default: ``False``); whether to
           consider only rows for positions up to the action of the
           quotient the group of isometries of the `n`-cube by the
           subgroup of isometries of the `a_1\times a_2\cdots \times a_n`
@@ -1896,7 +1850,7 @@ class TilingSolver(SageObject):
     @cached_method
     def rows(self):
         r"""
-        Creation of the rows
+        Creation of the rows.
 
         EXAMPLES::
 
@@ -1941,8 +1895,8 @@ class TilingSolver(SageObject):
 
         INPUT:
 
-        - ``i`` -- integer, the `i`-th piece to consider, that piece must not
-          be isometric to itself by a isometry that preserve the box.
+        - ``i`` -- integer; the `i`-th piece to consider, that piece must not
+          be isometric to itself by a isometry that preserve the box
 
         EXAMPLES::
 
@@ -1984,7 +1938,7 @@ class TilingSolver(SageObject):
             Dancing links solver for 96 columns and 5484 rows
 
         It is possible to avoid to compute 4 times each solution up to
-        rotations. This is done by choosing a piece (here the 0-th) and
+        rotations. This is done by choosing a piece (here the 0th) and
         considering 4 times less positions for that piece. To be precise,
         90 positions instead of 360, therefore the dancing links solver
         below has 270 less rows::
@@ -2008,9 +1962,7 @@ class TilingSolver(SageObject):
         r"""
         Return the number of rows necessary by each piece.
 
-        OUTPUT:
-
-        list
+        OUTPUT: list
 
         EXAMPLES::
 
@@ -2049,11 +2001,9 @@ class TilingSolver(SageObject):
 
         INPUT:
 
-        - ``row_number`` -- integer, the `i`-th row
+        - ``row_number`` -- integer; the `i`-th row
 
-        OUTPUT:
-
-        polyomino
+        OUTPUT: polyomino
 
         EXAMPLES::
 
@@ -2079,8 +2029,8 @@ class TilingSolver(SageObject):
         We check that issue :issue:`32252` is fixed and that colors of
         polyominoes are properly recovered::
 
-            sage: v = Polyomino([(0, 0), (0, 1)], color="blue")
-            sage: h = Polyomino([(0, 0), (1, 0)], color="red")
+            sage: v = Polyomino([(0, 0), (0, 1)], color='blue')
+            sage: h = Polyomino([(0, 0), (1, 0)], color='red')
             sage: T = TilingSolver(pieces=[v, h], box=(2, 2),
             ....:                  rotation=False, reflection=False, reusable=True)
             sage: for i in range(4): print(i,T.row_to_polyomino(i))
@@ -2088,7 +2038,6 @@ class TilingSolver(SageObject):
             1 Polyomino: [(1, 0), (1, 1)], Color: blue
             2 Polyomino: [(0, 0), (1, 0)], Color: red
             3 Polyomino: [(0, 1), (1, 1)], Color: red
-
         """
         rows = self.rows()
         row = rows[row_number]
@@ -2110,9 +2059,7 @@ class TilingSolver(SageObject):
         r"""
         Return the sage DLX solver of that tiling problem.
 
-        OUTPUT:
-
-        DLX Solver
+        OUTPUT: dLX Solver
 
         EXAMPLES::
 
@@ -2131,9 +2078,7 @@ class TilingSolver(SageObject):
         r"""
         Return an iterator over the row indices of the solutions.
 
-        OUTPUT:
-
-        iterator
+        OUTPUT: iterator
 
         EXAMPLES::
 
@@ -2160,9 +2105,7 @@ class TilingSolver(SageObject):
         The purpose is to illustrate the backtracking and construct an
         animation of the evolution of solutions.
 
-        OUTPUT:
-
-        iterator
+        OUTPUT: iterator
 
         EXAMPLES::
 
@@ -2229,9 +2172,7 @@ class TilingSolver(SageObject):
         The purpose is to illustrate the backtracking and construct an
         animation of the evolution of solutions.
 
-        OUTPUT:
-
-        iterator
+        OUTPUT: iterator
 
         EXAMPLES::
 
@@ -2289,7 +2230,7 @@ class TilingSolver(SageObject):
 
         INPUT:
 
-        - ``partial`` -- string (default: ``None``), whether to
+        - ``partial`` -- string (default: ``None``); whether to
           include partial (incomplete) solutions. It can be one of the
           following:
 
@@ -2297,9 +2238,7 @@ class TilingSolver(SageObject):
           - ``'common_prefix'`` -- common prefix between two consecutive solutions
           - ``'incremental'`` -- one piece change at a time
 
-        OUTPUT:
-
-        iterator of list of polyominoes
+        OUTPUT: iterator of list of polyominoes
 
         EXAMPLES::
 
@@ -2363,7 +2302,6 @@ class TilingSolver(SageObject):
             Traceback (most recent call last):
             ...
             StopIteration
-
         """
         if not self.is_suitable():
             return
@@ -2382,9 +2320,7 @@ class TilingSolver(SageObject):
         r"""
         Return the number of distinct solutions.
 
-        OUTPUT:
-
-        integer
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -2416,7 +2352,7 @@ class TilingSolver(SageObject):
 
         INPUT:
 
-        - ``partial`` -- string (default: ``None``), whether to
+        - ``partial`` -- string (default: ``None``); whether to
           include partial (incomplete) solutions. It can be one of the
           following:
 
@@ -2424,14 +2360,14 @@ class TilingSolver(SageObject):
           - ``'common_prefix'`` -- common prefix between two consecutive solutions
           - ``'incremental'`` -- one piece change at a time
 
-        - ``stop`` -- integer (default:``None``), number of frames
+        - ``stop`` -- integer (default: ``None``); number of frames
 
-        - ``size`` -- number (default: ``0.75``), the size of each
+        - ``size`` -- number (default: ``0.75``); the size of each
           ``1 \times 1`` square. This does a homothety with respect
           to the center of each polyomino.
 
-        - ``axes`` -- bool (default:``False``), whether the x and
-          y axes are shown.
+        - ``axes`` -- boolean (default: ``False``); whether the x and
+          y axes are shown
 
         EXAMPLES::
 
@@ -2461,7 +2397,7 @@ class TilingSolver(SageObject):
 
         The ``show`` function takes arguments to specify the delay between
         frames (measured in hundredths of a second, default value 20) and
-        the number of iterations (default value 0, which means to iterate
+        the number of iterations (default: 0, which means to iterate
         forever). To iterate 4 times with half a second between each frame::
 
             sage: a.show(delay=50, iterations=4)        # long time, optional - imagemagick, needs sage.plot
