@@ -256,7 +256,7 @@ def bin_to_ascii(B):
     return "".join(A)
 
 
-def has_blum_prime(lbound, ubound):
+def has_blum_prime(lbound, ubound) -> bool:
     r"""
     Determine whether or not there is a Blum prime within the specified closed
     interval.
@@ -342,10 +342,7 @@ def has_blum_prime(lbound, ubound):
     if lbound > ubound:
         raise ValueError("The lower bound must be less than the upper bound.")
     # now test for presence of a Blum prime
-    for p in primes(lbound, ubound + 1):
-        if mod(p, 4).lift() == 3:
-            return True
-    return False
+    return any(mod(p, 4).lift() == 3 for p in primes(lbound, ubound + 1))
 
 
 def is_blum_prime(n):
@@ -378,10 +375,7 @@ def is_blum_prime(n):
     if n < 0:
         return False
     if is_prime(n):
-        if mod(n, 4).lift() == 3:
-            return True
-        else:
-            return False
+        return mod(n, 4).lift() == 3
     else:
         return False
 
