@@ -70,8 +70,9 @@ from __future__ import annotations
 import os
 import shutil
 from pathlib import Path
+from tempfile import NamedTemporaryFile
 
-from sage.env import SAGE_SHARE, SAGE_LOCAL, SAGE_VENV
+from sage.env import SAGE_LOCAL, SAGE_SHARE, SAGE_VENV
 
 
 class TrivialClasscallMetaClass(type):
@@ -346,7 +347,7 @@ class Feature(TrivialUniqueRepresentation):
             return True
         return self._spkg_type() == 'standard'
 
-    def is_optional(self):
+    def is_optional(self) -> bool:
         r"""
         Return whether this feature corresponds to an optional SPKG.
 
@@ -358,7 +359,7 @@ class Feature(TrivialUniqueRepresentation):
         """
         return self._spkg_type() == 'optional'
 
-    def hide(self):
+    def hide(self) -> None:
         r"""
         Hide this feature. For example this is used when the doctest option
         ``--hide`` is set. Setting an installed feature as hidden pretends
@@ -384,7 +385,7 @@ class Feature(TrivialUniqueRepresentation):
         """
         self._hidden = True
 
-    def unhide(self):
+    def unhide(self) -> None:
         r"""
         Revert what :meth:`hide` did.
 
@@ -400,7 +401,7 @@ class Feature(TrivialUniqueRepresentation):
         """
         self._hidden = False
 
-    def is_hidden(self):
+    def is_hidden(self) -> bool:
         r"""
         Return whether ``self`` is present but currently hidden.
 
@@ -414,9 +415,8 @@ class Feature(TrivialUniqueRepresentation):
             sage: sage__plot().is_hidden()
             False
         """
-        if self._hidden and self._is_present():
-            return True
-        return False
+        return bool(self._hidden and self._is_present())
+
 
 class FeatureNotPresentError(RuntimeError):
     r"""
@@ -564,10 +564,14 @@ def package_systems():
         [Feature('homebrew'), Feature('sage_spkg'), Feature('pip')]
     """
     # The current implementation never returns more than one system.
-    from subprocess import run, CalledProcessError, PIPE
+    from subprocess import CalledProcessError, run
     global _cache_package_systems
     if _cache_package_systems is None:
-        from .pkg_systems import PackageSystem, SagePackageSystem, PipPackageSystem
+        from sage.features.pkg_systems import (
+            PackageSystem,
+            PipPackageSystem,
+            SagePackageSystem,
+        )
         _cache_package_systems = []
         # Try to use scripts from SAGE_ROOT (or an installation of sage_bootstrap)
         # to obtain system package advice.
@@ -819,9 +823,9 @@ class StaticFile(FileFeature):
         A :exc:`FeatureNotPresentError` is raised if the file cannot be found::
 
             sage: from sage.features import StaticFile
-            sage: StaticFile(name='no_such_file', filename='KaT1aihu',\
-                             search_path=(), spkg='some_spkg',\
-                             url='http://rand.om').absolute_filename()  # optional - sage_spkg
+            sage: StaticFile(name='no_such_file', filename='KaT1aihu',  # optional - sage_spkg
+            ....:            search_path=(), spkg='some_spkg',
+            ....:            url='http://rand.om').absolute_filename()
             Traceback (most recent call last):
             ...
             FeatureNotPresentError: no_such_file is not available.
@@ -911,7 +915,6 @@ class CythonFeature(Feature):
             sage: empty.is_present()                                                    # needs sage.misc.cython
             FeatureTestResult('empty', True)
         """
-        from sage.misc.temporary_file import tmp_filename
         try:
             # Available since https://setuptools.pypa.io/en/latest/history.html#v59-0-0
             from setuptools.errors import CCompilerError
@@ -920,14 +923,15 @@ class CythonFeature(Feature):
                 from distutils.errors import CCompilerError
             except ImportError:
                 CCompilerError = ()
-        with open(tmp_filename(ext='.pyx'), 'w') as pyx:
-            pyx.write(self.test_code)
         try:
             from sage.misc.cython import cython_import
         except ImportError:
             return FeatureTestResult(self, False, reason="sage.misc.cython is not available")
         try:
-            cython_import(pyx.name, verbose=-1)
+            with NamedTemporaryFile(mode='w', suffix='.pyx') as pyx:
+                pyx.write(self.test_code)
+                pyx.seek(0)
+                cython_import(pyx.name, verbose=-1)
         except CCompilerError:
             return FeatureTestResult(self, False, reason="Failed to compile test code.")
         except ImportError:
