@@ -34,8 +34,8 @@ class Ecm(Executable):
             sage: isinstance(Ecm(), Ecm)
             True
         """
-        Executable.__init__(self, name="ecm", executable=SAGE_ECMBIN,
-                            spkg="ecm", type="standard")
+        Executable.__init__(self, name='ecm', executable=SAGE_ECMBIN,
+                            spkg='ecm', type='standard')
 
 
 def all_features():
