@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-environment
 r"""
 Features for testing the presence of ``mcqd``
 """
@@ -35,10 +36,9 @@ class Mcqd(JoinFeature):
             sage: isinstance(Mcqd(), Mcqd)
             True
         """
-        # Currently part of sagemath_standard, conditionally built.
-        # Will be changed to spkg='sagemath_mcqd' later
         JoinFeature.__init__(self, 'mcqd',
-                             [PythonModule('sage.graphs.mcqd', spkg='mcqd')])
+                             [PythonModule('sage.graphs.mcqd',
+                                           spkg='sagemath_mcqd')])
 
 
 def all_features():
