@@ -36,16 +36,17 @@ class NewtonPolygon_element(Element):
 
         INPUT:
 
-        - polyhedron -- a polyhedron defining the Newton polygon
+        - ``polyhedron`` -- a polyhedron defining the Newton polygon
 
-        TESTS:
+        TESTS::
 
             sage: from sage.geometry.newton_polygon import NewtonPolygon
             sage: NewtonPolygon([ (0,0), (1,1), (3,5) ])
             Finite Newton polygon with 3 vertices: (0, 0), (1, 1), (3, 5)
 
             sage: NewtonPolygon([ (0,0), (1,1), (2,8), (3,5) ], last_slope=3)
-            Infinite Newton polygon with 3 vertices: (0, 0), (1, 1), (3, 5) ending by an infinite line of slope 3
+            Infinite Newton polygon with 3 vertices: (0, 0), (1, 1), (3, 5)
+            ending by an infinite line of slope 3
 
         ::
 
@@ -57,7 +58,7 @@ class NewtonPolygon_element(Element):
         if polyhedron.is_mutable():
             polyhedron._add_dependent_object(self)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
         Return a string representation of this Newton polygon.
 
@@ -75,28 +76,25 @@ class NewtonPolygon_element(Element):
         if self.last_slope() is Infinity:
             if length == 0:
                 return "Empty Newton polygon"
-            elif length == 1:
-                return "Finite Newton polygon with 1 vertex: %s" % str(vertices[0])
-            else:
-                return "Finite Newton polygon with %s vertices: %s" % (length, str(vertices)[1:-1])
-        else:
             if length == 1:
-                return "Newton Polygon consisting of a unique infinite line of slope %s starting at %s" % (self.last_slope(), str(vertices[0]))
-            else:
-                return "Infinite Newton polygon with %s vertices: %s ending by an infinite line of slope %s" % (length, str(vertices)[1:-1], self.last_slope())
+                return "Finite Newton polygon with 1 vertex: %s" % str(vertices[0])
+            return "Finite Newton polygon with %s vertices: %s" % (length, str(vertices)[1:-1])
 
-    def vertices(self, copy=True):
+        if length == 1:
+            return "Newton Polygon consisting of a unique infinite line of slope %s starting at %s" % (self.last_slope(), str(vertices[0]))
+        else:
+            return "Infinite Newton polygon with %s vertices: %s ending by an infinite line of slope %s" % (length, str(vertices)[1:-1], self.last_slope())
+
+    def vertices(self, copy=True) -> list:
         """
-        Returns the list of vertices of this Newton polygon
+        Return the list of vertices of this Newton polygon.
 
         INPUT:
 
-        - ``copy`` -- a boolean (default: ``True``)
+        - ``copy`` -- boolean (default: ``True``)
 
-        OUTPUT:
-
-        The list of vertices of this Newton polygon (or a copy of it
-        if ``copy`` is set to True)
+        OUTPUT: the list of vertices of this Newton polygon (or a copy of it
+        if ``copy`` is set to ``True``)
 
         EXAMPLES::
 
@@ -107,7 +105,7 @@ class NewtonPolygon_element(Element):
             sage: v = NP.vertices(); v
             [(0, 0), (1, 1), (2, 5)]
 
-        TESTS:
+        TESTS::
 
             sage: del v[0]
             sage: v
@@ -116,7 +114,7 @@ class NewtonPolygon_element(Element):
             [(0, 0), (1, 1), (2, 5)]
         """
         if self._vertices is None:
-            self._vertices = [ tuple(v) for v in self._polyhedron.vertices() ]
+            self._vertices = [tuple(v) for v in self._polyhedron.vertices()]
             self._vertices.sort()
         if copy:
             return list(self._vertices)
@@ -126,7 +124,7 @@ class NewtonPolygon_element(Element):
     @cached_method
     def last_slope(self):
         """
-        Returns the last (infinite) slope of this Newton polygon
+        Return the last (infinite) slope of this Newton polygon
         if it is infinite and ``+Infinity`` otherwise.
 
         EXAMPLES::
@@ -154,20 +152,20 @@ class NewtonPolygon_element(Element):
                 return r[1]/r[0]
         return Infinity
 
-    def slopes(self, repetition=True):
+    def slopes(self, repetition=True) -> list:
         """
-        Returns the slopes of this Newton polygon
+        Return the slopes of this Newton polygon.
 
         INPUT:
 
-        - ``repetition`` -- a boolean (default: ``True``)
+        - ``repetition`` -- boolean (default: ``True``)
 
         OUTPUT:
 
         The consecutive slopes (not including the last slope
         if the polygon is infinity) of this Newton polygon.
 
-        If ``repetition`` is True, each slope is repeated a number of
+        If ``repetition`` is ``True``, each slope is repeated a number of
         times equal to its length. Otherwise, it appears only one time.
 
         EXAMPLES::
@@ -182,9 +180,9 @@ class NewtonPolygon_element(Element):
             sage: NP.slopes(repetition=False)
             [1, 5/2]
         """
-        slopes = [ ]
+        slopes = []
         vertices = self.vertices(copy=False)
-        for i in range(1,len(vertices)):
+        for i in range(1, len(vertices)):
             dx = vertices[i][0] - vertices[i-1][0]
             dy = vertices[i][1] - vertices[i-1][1]
             slope = dy/dx
@@ -196,7 +194,7 @@ class NewtonPolygon_element(Element):
 
     def _add_(self, other):
         """
-        Returns the convex hull of ``self`` and ``other``
+        Return the convex hull of ``self`` and ``other``.
 
         INPUT:
 
@@ -204,7 +202,8 @@ class NewtonPolygon_element(Element):
 
         OUTPUT:
 
-        The Newton polygon, which is the convex hull of this Newton polygon and ``other``
+        the Newton polygon, which is the convex hull of this Newton polygon
+        and ``other``
 
         EXAMPLES::
 
@@ -212,17 +211,19 @@ class NewtonPolygon_element(Element):
             sage: NP1 = NewtonPolygon([ (0,0), (1,1), (2,6) ]); NP1
             Finite Newton polygon with 3 vertices: (0, 0), (1, 1), (2, 6)
             sage: NP2 = NewtonPolygon([ (0,0), (1,3/2) ], last_slope=2); NP2
-            Infinite Newton polygon with 2 vertices: (0, 0), (1, 3/2) ending by an infinite line of slope 2
+            Infinite Newton polygon with 2 vertices: (0, 0), (1, 3/2)
+            ending by an infinite line of slope 2
 
             sage: NP1 + NP2
-            Infinite Newton polygon with 2 vertices: (0, 0), (1, 1) ending by an infinite line of slope 2
+            Infinite Newton polygon with 2 vertices: (0, 0), (1, 1)
+            ending by an infinite line of slope 2
         """
         polyhedron = self._polyhedron.convex_hull(other._polyhedron)
         return self.parent()(polyhedron)
 
     def _mul_(self, other):
         """
-        Returns the Minkowski sum of ``self`` and ``other``
+        Return the Minkowski sum of ``self`` and ``other``.
 
         INPUT:
 
@@ -230,12 +231,14 @@ class NewtonPolygon_element(Element):
 
         OUTPUT:
 
-        The Newton polygon, which is the Minkowski sum of this Newton polygon and ``other``.
+        the Newton polygon, which is the Minkowski sum of this Newton polygon
+        and ``other``
 
         .. NOTE::
 
-            If ``self`` and ``other`` are respective Newton polygons of some polynomials
-            `f` and `g` the self*other is the Newton polygon of the product `fg`
+            If ``self`` and ``other`` are respective Newton polygons
+            of some polynomials `f` and `g` the self*other is the
+            Newton polygon of the product `fg`
 
         EXAMPLES::
 
@@ -243,13 +246,15 @@ class NewtonPolygon_element(Element):
             sage: NP1 = NewtonPolygon([ (0,0), (1,1), (2,6) ]); NP1
             Finite Newton polygon with 3 vertices: (0, 0), (1, 1), (2, 6)
             sage: NP2 = NewtonPolygon([ (0,0), (1,3/2) ], last_slope=2); NP2
-            Infinite Newton polygon with 2 vertices: (0, 0), (1, 3/2) ending by an infinite line of slope 2
+            Infinite Newton polygon with 2 vertices: (0, 0), (1, 3/2)
+            ending by an infinite line of slope 2
 
             sage: NP = NP1 * NP2; NP
-            Infinite Newton polygon with 3 vertices: (0, 0), (1, 1), (2, 5/2) ending by an infinite line of slope 2
+            Infinite Newton polygon with 3 vertices: (0, 0), (1, 1), (2, 5/2)
+            ending by an infinite line of slope 2
 
-        The slopes of ``NP`` is the union of those of ``NP1`` and those of ``NP2``
-        which are less than the last slope::
+        The slopes of ``NP`` is the union of those of ``NP1`` and
+        those of ``NP2`` which are less than the last slope::
 
             sage: NP1.slopes()
             [1, 5]
@@ -263,15 +268,13 @@ class NewtonPolygon_element(Element):
 
     def __pow__(self, exp, ignored=None):
         """
-        Returns ``self`` dilated by ``exp``
+        Return ``self`` dilated by ``exp``.
 
         INPUT:
 
-        - ``exp`` -- a positive integer
+        - ``exp`` -- positive integer
 
-        OUTPUT:
-
-        This Newton polygon scaled by a factor ``exp``.
+        OUTPUT: this Newton polygon scaled by a factor ``exp``
 
         .. NOTE::
 
@@ -292,15 +295,13 @@ class NewtonPolygon_element(Element):
 
     def __lshift__(self, i):
         """
-        Returns ``self`` shifted by `(0,i)`
+        Return ``self`` shifted by `(0,i)`.
 
         INPUT:
 
         - ``i`` -- a rational number
 
-        OUTPUT:
-
-        This Newton polygon shifted by the vector `(0,i)`
+        OUTPUT: this Newton polygon shifted by the vector `(0,i)`
 
         EXAMPLES::
 
@@ -311,20 +312,18 @@ class NewtonPolygon_element(Element):
             sage: NP << 2
             Finite Newton polygon with 3 vertices: (0, 2), (1, 3), (2, 8)
         """
-        polyhedron = self._polyhedron.translation((0,i))
+        polyhedron = self._polyhedron.translation((0, i))
         return self.parent()(polyhedron)
 
     def __rshift__(self, i):
         """
-        Returns ``self`` shifted by `(0,-i)`
+        Return ``self`` shifted by `(0,-i)`.
 
         INPUT:
 
         - ``i`` -- a rational number
 
-        OUTPUT:
-
-        This Newton polygon shifted by the vector `(0,-i)`
+        OUTPUT: this Newton polygon shifted by the vector `(0,-i)`
 
         EXAMPLES::
 
@@ -335,20 +334,18 @@ class NewtonPolygon_element(Element):
             sage: NP >> 2
             Finite Newton polygon with 3 vertices: (0, -2), (1, -1), (2, 4)
         """
-        polyhedron = self._polyhedron.translation((0,-i))
+        polyhedron = self._polyhedron.translation((0, -i))
         return self.parent()(polyhedron)
 
     def __call__(self, x):
         """
-        Returns `self(x)`
+        Return `self(x)`.
 
         INPUT:
 
         - ``x`` -- a real number
 
-        OUTPUT:
-
-        The value of this Newton polygon at abscissa `x`
+        OUTPUT: the value of this Newton polygon at abscissa `x`
 
         EXAMPLES::
 
@@ -382,7 +379,7 @@ class NewtonPolygon_element(Element):
         xd, yd = vertices[b]
         return ((x-xg)*yd + (xd-x)*yg) / (xd-xg)
 
-    def _richcmp_(self, other, op):
+    def _richcmp_(self, other, op) -> bool:
         r"""
         Comparisons of two Newton polygons.
 
@@ -471,32 +468,38 @@ class NewtonPolygon_element(Element):
         if len(vertices) == 0:
             from sage.plot.graphics import Graphics
             return Graphics()
+
+        from sage.plot.line import line
+        xstart, ystart = vertices[0]
+        xend, yend = vertices[-1]
+        if self.last_slope() is Infinity:
+            return line([(xstart, ystart+1), (xstart, ystart+0.5)],
+                        linestyle='--', **kwargs) \
+                 + line([(xstart, ystart+0.5)] + vertices
+                        + [(xend, yend+0.5)], **kwargs) \
+                 + line([(xend, yend+0.5), (xend, yend+1)],
+                        linestyle='--', **kwargs)
         else:
-            from sage.plot.line import line
-            (xstart,ystart) = vertices[0]
-            (xend,yend) = vertices[-1]
-            if self.last_slope() is Infinity:
-                return line([(xstart, ystart+1), (xstart,ystart+0.5)], linestyle="--", **kwargs) \
-                     + line([(xstart, ystart+0.5)] + vertices + [(xend, yend+0.5)], **kwargs) \
-                     + line([(xend, yend+0.5), (xend, yend+1)], linestyle="--", **kwargs)
-            else:
-                return line([(xstart, ystart+1), (xstart,ystart+0.5)], linestyle="--", **kwargs) \
-                     + line([(xstart, ystart+0.5)] + vertices + [(xend+0.5, yend + 0.5*self.last_slope())], **kwargs) \
-                     + line([(xend+0.5, yend + 0.5*self.last_slope()), (xend+1, yend+self.last_slope())], linestyle="--", **kwargs)
+            return line([(xstart, ystart+1), (xstart, ystart+0.5)],
+                        linestyle='--', **kwargs) \
+                 + line([(xstart, ystart+0.5)] + vertices
+                        + [(xend+0.5, yend + 0.5*self.last_slope())], **kwargs) \
+                 + line([(xend+0.5, yend + 0.5*self.last_slope()), (xend+1, yend+self.last_slope())],
+                        linestyle='--', **kwargs)
 
     def reverse(self, degree=None):
         r"""
-        Returns the symmetric of ``self``
+        Return the symmetric of ``self``.
 
         INPUT:
 
-        - ``degree`` -- an integer (default: the top right abscissa of
+        - ``degree`` -- integer (default: the top right abscissa of
           this Newton polygon)
 
         OUTPUT:
 
         The image this Newton polygon under the symmetry
-        '(x,y) \mapsto (degree-x, y)`
+        '(x,y) \mapsto (degree-x, y)`.
 
         EXAMPLES::
 
@@ -517,10 +520,11 @@ class NewtonPolygon_element(Element):
             raise ValueError("Can only reverse *finite* Newton polygons")
         if degree is None:
             degree = self.vertices()[-1][0]
-        vertices = [ (degree-x,y) for (x,y) in self.vertices() ]
+        vertices = [(degree - x, y) for x, y in self.vertices()]
         vertices.reverse()
         parent = self.parent()
-        polyhedron = Polyhedron(base_ring=parent.base_ring(), vertices=vertices, rays=[(0,1)])
+        polyhedron = Polyhedron(base_ring=parent.base_ring(),
+                                vertices=vertices, rays=[(0, 1)])
         return parent(polyhedron)
 
 
@@ -530,20 +534,18 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
 
     INPUT:
 
-    - ``arg`` -- a list/tuple/iterable of vertices or of
-      slopes. Currently, slopes must be rational numbers.
+    - ``arg`` -- list/tuple/iterable of vertices or of
+      slopes. Currently, slopes must be rational numbers
 
-    - ``sort_slopes`` -- boolean (default: ``True``). Specifying
-      whether slopes must be first sorted
+    - ``sort_slopes`` -- boolean (default: ``True``);  whether slopes must be
+      first sorted
 
     - ``last_slope`` -- rational or infinity (default:
-      ``Infinity``). The last slope of the Newton polygon
+      ``Infinity``); the last slope of the Newton polygon
 
-    OUTPUT:
+    OUTPUT: the corresponding Newton polygon
 
-    The corresponding Newton polygon.
-
-    .. note::
+    .. NOTE::
 
         By convention, a Newton polygon always contains the point
         at infinity `(0, \infty)`. These polygons are attached to
@@ -573,12 +575,14 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
     and ends with an infinite line having the specified slope::
 
         sage: NewtonPolygon([ (0,0), (1,1), (2,8), (3,5) ], last_slope=3)
-        Infinite Newton polygon with 3 vertices: (0, 0), (1, 1), (3, 5) ending by an infinite line of slope 3
+        Infinite Newton polygon with 3 vertices: (0, 0), (1, 1), (3, 5)
+        ending by an infinite line of slope 3
 
     Specifying a last slope may discard some vertices::
 
         sage: NewtonPolygon([ (0,0), (1,1), (2,8), (3,5) ], last_slope=3/2)
-        Infinite Newton polygon with 2 vertices: (0, 0), (1, 1) ending by an infinite line of slope 3/2
+        Infinite Newton polygon with 2 vertices: (0, 0), (1, 1)
+        ending by an infinite line of slope 3/2
 
     Next, we define a Newton polygon by its slopes::
 
@@ -605,7 +609,8 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
 
         sage: NP = NewtonPolygon([0, 1/2, 1/2, 2/3, 2/3, 2/3, 1, 1], last_slope=2/3)
         sage: NP
-        Infinite Newton polygon with 3 vertices: (0, 0), (1, 0), (3, 1) ending by an infinite line of slope 2/3
+        Infinite Newton polygon with 3 vertices: (0, 0), (1, 0), (3, 1)
+        ending by an infinite line of slope 2/3
         sage: NP.slopes()
         [0, 1/2, 1/2]
 
@@ -618,14 +623,15 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
         sage: x, y = polygen(QQ,'x, y')
         sage: p = 1 + x*y**45 + x**3*y**6
         sage: p.newton_polytope()
-        A 2-dimensional polyhedron in ZZ^2 defined as the convex hull of 3 vertices
+        A 2-dimensional polyhedron in ZZ^2 defined as the convex hull
+        of 3 vertices
         sage: p.newton_polytope().vertices()
         (A vertex at (0, 0), A vertex at (1, 45), A vertex at (3, 6))
     """
 
     Element = NewtonPolygon_element
 
-    def __init__(self):
+    def __init__(self) -> None:
         """
         Parent class for all Newton polygons.
 
@@ -650,12 +656,12 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
         from sage.rings.rational_field import QQ
         Parent.__init__(self, category=Semirings(), base=QQ)
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
-        Returns the string representation of this parent,
-        which is ``Parent for Newton polygons``
+        Return the string representation of this parent,
+        which is ``Parent for Newton polygons``.
 
-        TESTS:
+        TESTS::
 
             sage: from sage.geometry.newton_polygon import NewtonPolygon
             sage: NewtonPolygon
@@ -668,9 +674,9 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
 
     def _an_element_(self):
         """
-        Returns a Newton polygon (which is the empty one)
+        Return a Newton polygon (which is the empty one).
 
-        TESTS:
+        TESTS::
 
             sage: from sage.geometry.newton_polygon import NewtonPolygon
             sage: NewtonPolygon._an_element_()
@@ -678,14 +684,15 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
         """
         return self(Polyhedron(base_ring=self.base_ring(), ambient_dim=2))
 
-    def _element_constructor_(self, arg, sort_slopes=True, last_slope=Infinity):
+    def _element_constructor_(self, arg, sort_slopes=True,
+                              last_slope=Infinity):
         r"""
         INPUT:
 
         - ``arg`` -- an argument describing the Newton polygon
 
-        - ``sort_slopes`` -- boolean (default: ``True``). Specifying
-          whether slopes must be first sorted
+        - ``sort_slopes`` -- boolean (default: ``True``); whether
+          slopes must be first sorted
 
         - ``last_slope`` -- rational or infinity (default:
           ``Infinity``). The last slope of the Newton polygon
@@ -703,9 +710,7 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
 
         - a list/tuple/iterable of slopes
 
-        OUTPUT:
-
-        The corresponding Newton polygon.
+        OUTPUT: the corresponding Newton polygon
 
         For more informations, see :class:`ParentNewtonPolygon`.
 
@@ -730,7 +735,8 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
             try:
                 arg = list(arg)
             except TypeError:
-                raise TypeError("argument must be a list of coordinates or a list of (rational) slopes")
+                raise TypeError("argument must be a list of coordinates "
+                                "or a list of (rational) slopes")
         if arg and arg[0] in self.base_ring():
             if sort_slopes:
                 arg.sort()
@@ -738,7 +744,8 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
             vertices = [(x, y)]
             for slope in arg:
                 if slope not in self.base_ring():
-                    raise TypeError("argument must be a list of coordinates or a list of (rational) slopes")
+                    raise TypeError("argument must be a list of coordinates "
+                                    "or a list of (rational) slopes")
                 x += 1
                 y += slope
                 vertices.append((x, y))
@@ -751,7 +758,8 @@ class ParentNewtonPolygon(Parent, UniqueRepresentation):
             rays = [(0, 1)]
             if last_slope is not Infinity:
                 rays.append((1, last_slope))
-            polyhedron = Polyhedron(base_ring=self.base_ring(), vertices=vertices, rays=rays)
+            polyhedron = Polyhedron(base_ring=self.base_ring(),
+                                    vertices=vertices, rays=rays)
         return self.element_class(polyhedron, parent=self)
 
 
