@@ -85,13 +85,11 @@ def random_inequalities(d, n):
 
     INPUT:
 
-    - ``d`` -- integer. The dimension.
+    - ``d`` -- integer; the dimension
 
-    - ``n``  -- integer. The number of random inequalities to generate.
+    - ``n`` -- integer; the number of random inequalities to generate
 
-    OUTPUT:
-
-    A random set of inequalities as a :class:`StandardAlgorithm` instance.
+    OUTPUT: a random set of inequalities as a :class:`StandardAlgorithm` instance
 
     EXAMPLES::
 
@@ -111,7 +109,7 @@ class DoubleDescriptionPair:
 
     def __init__(self, problem, A_rows, R_cols):
         r"""
-        Base class for a double description pair `(A, R)`
+        Base class for a double description pair `(A, R)`.
 
         .. warning::
 
@@ -122,13 +120,13 @@ class DoubleDescriptionPair:
 
         INPUT:
 
-        - ``problem`` -- instance of :class:`Problem`.
+        - ``problem`` -- instance of :class:`Problem`
 
-        - ``A_rows`` -- list of row vectors of the matrix `A`. These
-          encode the inequalities.
+        - ``A_rows`` -- list of row vectors of the matrix `A`; these
+          encode the inequalities
 
         - ``R_cols`` -- list of column vectors of the matrix
-          `R`. These encode the rays.
+          `R`; these encode the rays
 
         TESTS::
 
@@ -159,11 +157,11 @@ class DoubleDescriptionPair:
 
         INPUT:
 
-        - ``A_rows`` -- list of row vectors of the matrix `A`. These
-          encode the inequalities.
+        - ``A_rows`` -- list of row vectors of the matrix `A`; these
+          encode the inequalities
 
         - ``R_cols`` -- list of column vectors of the matrix
-          `R`. These encode the rays.
+          `R`; these encode the rays
 
         OUTPUT:
 
@@ -192,9 +190,7 @@ class DoubleDescriptionPair:
         r"""
         Return string representation.
 
-        OUTPUT:
-
-        String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -316,7 +312,7 @@ class DoubleDescriptionPair:
 
         INPUT:
 
-        - ``a`` -- vector. Coefficient vector of a homogeneous inequality.
+        - ``a`` -- vector; coefficient vector of a homogeneous inequality
 
         OUTPUT:
 
@@ -352,11 +348,9 @@ class DoubleDescriptionPair:
 
         INPUT:
 
-        - ``ray`` -- a ray vector.
+        - ``ray`` -- a ray vector
 
-        OUTPUT:
-
-        A set containing the inequality vectors that are zero on ``ray``.
+        OUTPUT: a set containing the inequality vectors that are zero on ``ray``
 
         EXAMPLES::
 
@@ -427,11 +421,9 @@ class DoubleDescriptionPair:
 
         INPUT:
 
-        - ``r1``, ``r2`` -- two rays.
+        - ``r1``, ``r2`` -- two rays
 
-        OUTPUT:
-
-        Boolean. Whether the two rays are adjacent.
+        OUTPUT: boolean; whether the two rays are adjacent
 
         EXAMPLES::
 
@@ -523,14 +515,14 @@ class Problem:
 
     def __init__(self, A):
         r"""
-        Base class for implementations of the double description algorithm
+        Base class for implementations of the double description algorithm.
 
         It does not make sense to instantiate the base class directly,
         it just provides helpers for implementations.
 
         INPUT:
 
-        - ``A`` -- a matrix. The rows of the matrix are interpreted as
+        - ``A`` -- a matrix; the rows of the matrix are interpreted as
           homogeneous inequalities `A x \geq 0`. Must have maximal rank.
 
         TESTS::
@@ -554,9 +546,7 @@ class Problem:
         """
         Return the rows of the defining matrix `A`.
 
-        OUTPUT:
-
-        The matrix `A` whose rows are the inequalities.
+        OUTPUT: the matrix `A` whose rows are the inequalities
 
         EXAMPLES::
 
@@ -574,9 +564,7 @@ class Problem:
         """
         Return the defining matrix `A`.
 
-        OUTPUT:
-
-        Matrix whose rows are the inequalities.
+        OUTPUT: matrix whose rows are the inequalities
 
         EXAMPLES::
 
@@ -592,9 +580,7 @@ class Problem:
         """
         Return the base field.
 
-        OUTPUT:
-
-        A field.
+        OUTPUT: a field
 
         EXAMPLES::
 
@@ -610,9 +596,7 @@ class Problem:
         """
         Return the ambient space dimension.
 
-        OUTPUT:
-
-        Integer. The ambient space dimension of the cone.
+        OUTPUT: integer; the ambient space dimension of the cone
 
         EXAMPLES::
 
@@ -627,9 +611,7 @@ class Problem:
         r"""
         Return a string representation.
 
-        OUTPUT:
-
-        String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -650,7 +632,7 @@ class Problem:
         INPUT:
 
         - ``pair_class`` -- subclass of
-          :class:`DoubleDescriptionPair`.
+          :class:`DoubleDescriptionPair`
 
         OUTPUT:
 
@@ -694,7 +676,7 @@ class StandardDoubleDescriptionPair(DoubleDescriptionPair):
 
         INPUT:
 
-        - ``a`` -- vector. An inequality.
+        - ``a`` -- vector; an inequality
 
         EXAMPLES::
 
@@ -722,9 +704,10 @@ class StandardDoubleDescriptionPair(DoubleDescriptionPair):
         self.R = R_pos + R_nul + R_new
         self.A.append(a)
 
+
 class StandardAlgorithm(Problem):
     """
-    Standard implementation of the double description algorithm
+    Standard implementation of the double description algorithm.
 
     See [FP1996]_ for the definition of the "Standard
     Algorithm".
