@@ -91,7 +91,7 @@ def generating_function_of_integral_points(polyhedron, split=False,
       The variable names of the Laurent polynomial ring of the output
       are this string followed by an integer.
 
-    - ``names`` -- a list or tuple of names (strings), or a comma separated string
+    - ``names`` -- list or tuple of names (strings), or a comma separated string
 
       ``name`` is extracted from ``names``, therefore ``names`` has to contain
       exactly one variable name, and ``name`` and``names`` cannot be specified
@@ -535,7 +535,7 @@ def generating_function_of_integral_points(polyhedron, split=False,
 
             ieqs, repr_rhss = zip(*[(ieq(a, b), ieq_repr_rhs(a, b))
                                     for a, b in zip(pi[:-1], pi[1:])])
-            return Polyhedron(ieqs=ieqs),  ieqs_repr_lhs(pi) + ''.join(repr_rhss)
+            return Polyhedron(ieqs=ieqs), ieqs_repr_lhs(pi) + ''.join(repr_rhss)
 
         split = (polyhedron_from_permutation(pi) for pi in Permutations(d))
         parts = ZZ(d).factorial()
@@ -680,7 +680,7 @@ def __generating_function_of_integral_points__(
 
     if sort_factors:
         def key(t):
-            D = t.dict().popitem()[0]
+            D = t.monomial_coefficients().popitem()[0]
             return (-sum(abs(d) for d in D), D)
         terms = sorted(terms, key=key, reverse=True)
     return Factorization([(numerator, 1)] +
@@ -697,19 +697,17 @@ def _generating_function_via_Omega_(inequalities, B, skip_indices=()):
 
     INPUT:
 
-    - ``inequalities`` -- a list or other iterable of tuples
-      of numbers.
+    - ``inequalities`` -- list or other iterable of tuples
+      of numbers
 
     - ``B`` -- a Laurent polynomial ring
 
-    - ``skip_indices`` -- a list or tuple of indices
+    - ``skip_indices`` -- list or tuple of indices
 
       The variables corresponding to ``skip_indices`` are not handled
       (e.g. because they are determined by an equation).
 
-    OUTPUT:
-
-    A pair of
+    OUTPUT: a pair of
 
     - a Laurent polynomial specifying the numerator and
 
@@ -750,7 +748,7 @@ def _generating_function_via_Omega_(inequalities, B, skip_indices=()):
     logger.debug('terms denominator %s', terms)
 
     def decode_factor(factor):
-        D = factor.dict()
+        D = factor.monomial_coefficients()
         assert len(D) == 1
         exponent, coefficient = next(iter(D.items()))
         return coefficient, exponent
@@ -766,7 +764,7 @@ def _generating_function_via_Omega_(inequalities, B, skip_indices=()):
                       lambda factor: factor[1] == 0)
         other_factors = tuple(factor[0] for factor in other_factors)
         numerator, factors_denominator = \
-            _Omega_(numerator.dict(), tuple(decoded_factors))
+            _Omega_(numerator.monomial_coefficients(), tuple(decoded_factors))
         terms = other_factors + factors_denominator
 
     return _simplify_(numerator, terms)
@@ -780,9 +778,9 @@ class _TransformHrepresentation:
 
     INPUT:
 
-    - ``inequalities`` -- a list of tuples of numbers
+    - ``inequalities`` -- list of tuples of numbers
 
-    - ``equations`` -- a list of tuples of numbers
+    - ``equations`` -- list of tuples of numbers
 
     - ``B`` -- a Laurent polynomial ring
 
@@ -798,7 +796,7 @@ class _TransformHrepresentation:
       The numerator of the generating function has to be multiplied
       with ``factor`` *after* substituting ``rules``.
 
-    - ``rules`` -- a dictionary mapping Laurent polynomial variables to
+    - ``rules`` -- dictionary mapping Laurent polynomial variables to
       Laurent polynomials
 
       Substitute ``rules`` into the generating function.
@@ -854,7 +852,7 @@ class _TransformHrepresentation:
 
         - ``numerator`` -- a Laurent polynomial
 
-        - ``terms`` -- a tuple or other iterable of Laurent polynomials
+        - ``terms`` -- tuple or other iterable of Laurent polynomials
 
           The denominator is the product of factors `1 - t` for each
           `t` in ``terms``.
@@ -887,9 +885,9 @@ class _SplitOffSimpleInequalities(_TransformHrepresentation):
 
     INPUT:
 
-    - ``inequalities`` -- a list of tuples of numbers
+    - ``inequalities`` -- list of tuples of numbers
 
-    - ``equations`` -- a list of tuples of numbers
+    - ``equations`` -- list of tuples of numbers
 
     - ``B`` -- a Laurent polynomial ring
 
@@ -905,7 +903,7 @@ class _SplitOffSimpleInequalities(_TransformHrepresentation):
       The numerator of the generating function has to be multiplied
       with ``factor`` *after* substituting ``rules``.
 
-    - ``rules`` -- a dictionary mapping Laurent polynomial variables to
+    - ``rules`` -- dictionary mapping Laurent polynomial variables to
       Laurent polynomials
 
       Substitute ``rules`` into the generating function.
@@ -1197,9 +1195,9 @@ class _EliminateByEquations(_TransformHrepresentation):
 
     INPUT:
 
-    - ``inequalities`` -- a list of tuples of numbers
+    - ``inequalities`` -- list of tuples of numbers
 
-    - ``equations`` -- a list of tuples of numbers
+    - ``equations`` -- list of tuples of numbers
 
     - ``B`` -- a Laurent polynomial ring
 
@@ -1215,7 +1213,7 @@ class _EliminateByEquations(_TransformHrepresentation):
       The numerator of the generating function has to be multiplied
       with ``factor`` *after* substituting ``rules``.
 
-    - ``rules`` -- a dictionary mapping Laurent polynomial variables to
+    - ``rules`` -- dictionary mapping Laurent polynomial variables to
       Laurent polynomials
 
       Substitute ``rules`` into the generating function.
@@ -1325,7 +1323,7 @@ class _EliminateByEquations(_TransformHrepresentation):
         - ``indicesn`` -- a sorted tuple of integers representing column indices
 
           ``indicesn`` contains ``0`` and all indices of the columns of ``E``
-          which are non-zero.
+          which are nonzero.
 
         TESTS::
 
@@ -1365,13 +1363,13 @@ class _TransformMod(_TransformHrepresentation):
 
     INPUT:
 
-    - ``inequalities`` -- a list of tuples of numbers
+    - ``inequalities`` -- list of tuples of numbers
 
-    - ``equations`` -- a list of tuples of numbers
+    - ``equations`` -- list of tuples of numbers
 
     - ``B`` -- a Laurent polynomial ring
 
-    - ``mod`` -- a dictionary mapping an index ``i`` to ``(m, r)``
+    - ``mod`` -- dictionary mapping an index ``i`` to ``(m, r)``
 
       This is one entry of the output tuple of :meth:`generate_mods`.
 
@@ -1387,7 +1385,7 @@ class _TransformMod(_TransformHrepresentation):
       The numerator of the generating function has to be multiplied
       with ``factor`` *after* substituting ``rules``.
 
-    - ``rules`` -- a dictionary mapping Laurent polynomial variables to
+    - ``rules`` -- dictionary mapping Laurent polynomial variables to
       Laurent polynomials
 
       Substitute ``rules`` into the generating function.
@@ -1478,7 +1476,7 @@ class _TransformMod(_TransformHrepresentation):
 
         INPUT:
 
-        - ``equations`` -- a list of tuples
+        - ``equations`` -- list of tuples
 
         OUTPUT:
 
@@ -1531,7 +1529,7 @@ def _compositions_mod(u, m, r=0, multidimensional=False):
 
     - ``m`` -- the modulus as a positive integer
 
-    - ``multidimensional`` -- (default: ``False``) a boolean
+    - ``multidimensional`` -- boolean (default: ``False``)
 
     If ``multidimensional=False``:
 
