@@ -150,6 +150,21 @@ class DiGraphGenerators:
       dense data structure. See the documentation of
       :class:`~sage.graphs.graph.Graph`.
 
+    - ``copy`` -- boolean (default: ``True``); whether to make copies of the
+      digraphs before returning them. If set to ``False`` the method returns the
+      digraph it is working on. The second alternative is faster, but modifying
+      any of the digraph instances returned by the method may break the
+      function's behaviour, as it is using these digraphs to compute the next
+      ones: only use ``copy = False`` when you stick to *reading* the digraphs
+      returned.
+
+      This parameter is ignored when ``immutable`` is set to ``True``, in which
+      case returned graphs are always copies.
+
+    - ``immutable`` -- boolean (default: ``False``); whether to return immutable
+      or mutable digraphs. When set to ``True``, this parameter implies
+      ``copy=True``.
+
     EXAMPLES:
 
     Print digraphs on 2 or less vertices::
@@ -203,7 +218,7 @@ class DiGraphGenerators:
         218
     """
 
-    def ButterflyGraph(self, n, vertices='strings'):
+    def ButterflyGraph(self, n, vertices='strings', immutable=False):
         r"""
         Return a `n`-dimensional butterfly graph.
 
@@ -223,6 +238,9 @@ class DiGraphGenerators:
           vertices are zero-one strings (default) or tuples over GF(2)
           (``vertices='vectors'``)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES::
 
             sage: digraphs.ButterflyGraph(2).edges(sort=True, labels=False)
@@ -323,9 +341,10 @@ class DiGraphGenerators:
             for x in range(n + 1):
                 pos[v, x] = (dec * x, i)
         return DiGraph([pos.keys(), E], format='vertices_and_edges', pos=pos,
-                       name="{}-dimensional Butterfly".format(n))
+                       name="{}-dimensional Butterfly".format(n),
+                       immutable=immutable)
 
-    def Path(self, n):
+    def Path(self, n, immutable=False):
         r"""
         Return a directed path on `n` vertices.
 
@@ -333,6 +352,9 @@ class DiGraphGenerators:
 
         - ``n`` -- integer; number of vertices in the path
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES::
 
             sage: g = digraphs.Path(5)
@@ -343,15 +365,13 @@ class DiGraphGenerators:
             sage: g.automorphism_group().cardinality()                                  # needs sage.groups
             1
         """
-        g = DiGraph(n, name='Path')
-
-        if n:
-            g.add_path(list(range(n)))
-
+        g = DiGraph([range(n), zip(range(n - 1), range(1, n))],
+                    format='vertices_and_edges', name='Path',
+                    immutable=immutable)
         g.set_pos({i: (i, 0) for i in range(n)})
         return g
 
-    def StronglyRegular(self, n):
+    def StronglyRegular(self, n, immutable=False):
         r"""
         Return a Strongly Regular digraph with `n` vertices.
 
@@ -362,6 +382,9 @@ class DiGraphGenerators:
 
         - ``n`` -- integer; the number of vertices of the digraph
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         .. SEEALSO::
 
             - :func:`sage.combinat.matrices.hadamard_matrix.skew_hadamard_matrix`
@@ -397,15 +420,23 @@ class DiGraphGenerators:
         H = skew_hadamard_matrix(n + 1, skew_normalize=True)
         M = H[1:, 1:]
         M = (M + ones_matrix(n)) / 2 - identity_matrix(n)
-        return DiGraph(M, format='adjacency_matrix', name='Strongly regular digraph')
+        return DiGraph(M, format='adjacency_matrix', immutable=immutable,
+                       name='Strongly regular digraph')
 
-    def Paley(self, q):
+    def Paley(self, q, immutable=False):
         r"""
         Return a Paley digraph on `q` vertices.
 
         Parameter `q` must be the power of a prime number and congruent to 3 mod
         4.
 
+        INPUT:
+
+        - ``q`` -- integer; the number of vertices of the digraph
+
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         .. SEEALSO::
 
             - :wikipedia:`Paley_graph`
@@ -448,13 +479,12 @@ class DiGraphGenerators:
             raise ValueError("parameter q must be a prime power")
         if not mod(q, 4) == 3:
             raise ValueError("parameter q must be congruent to 3 mod 4")
-        g = DiGraph([FiniteField(q, 'a'),
-                     lambda i, j: (i != j) and (j - i).is_square()],
-                    loops=False,
-                    name="Paley digraph with parameter {}".format(q))
-        return g
+        return DiGraph([FiniteField(q, 'a'),
+                        lambda i, j: (i != j) and (j - i).is_square()],
+                       format='rule', loops=False, immutable=immutable,
+                       name="Paley digraph with parameter {}".format(q))
 
-    def TransitiveTournament(self, n):
+    def TransitiveTournament(self, n, immutable=False):
         r"""
         Return a transitive tournament on `n` vertices.
 
@@ -466,6 +496,9 @@ class DiGraphGenerators:
 
         - ``n`` -- integer; number of vertices in the tournament
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES::
 
             sage: g = digraphs.TransitiveTournament(5)
@@ -490,17 +523,17 @@ class DiGraphGenerators:
             ...
             ValueError: the number of vertices cannot be strictly negative
         """
-        g = DiGraph(n, name="Transitive Tournament")
-
-        for i in range(n - 1):
-            for j in range(i + 1, n):
-                g.add_edge(i, j)
+        if n < 0:
+            raise ValueError('the number of vertices cannot be strictly negative')
 
+        from itertools import combinations
+        g = DiGraph([range(n), combinations(range(n), 2)],
+                    format='vertices_and_edges', immutable=immutable,
+                    name="Transitive Tournament")
         g._circle_embedding(list(range(n)))
-
         return g
 
-    def RandomTournament(self, n):
+    def RandomTournament(self, n, immutable=False):
         r"""
         Return a random tournament on `n` vertices.
 
@@ -512,6 +545,9 @@ class DiGraphGenerators:
 
         - ``n`` -- integer; number of vertices
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES::
 
             sage: T = digraphs.RandomTournament(10); T
@@ -533,15 +569,17 @@ class DiGraphGenerators:
             - :meth:`~sage.graphs.digraph_generators.DiGraphGenerators.Complete`
             - :meth:`~sage.graphs.digraph_generators.DiGraphGenerators.RandomSemiComplete`
         """
-        from sage.misc.prandom import random
-        g = DiGraph(n, name="Random Tournament")
+        if n < 0:
+            raise ValueError('the number of vertices cannot be strictly negative')
 
-        for i in range(n - 1):
-            for j in range(i + 1, n):
-                if random() <= .5:
-                    g.add_edge(i, j)
-                else:
-                    g.add_edge(j, i)
+        from itertools import combinations
+        from sage.misc.prandom import getrandbits
+
+        bits = getrandbits(n * (n - 1) // 2)
+        edges = ((i, j) if (bits >> k) & 1 else (j, i)
+                 for k, (i, j) in enumerate(combinations(range(n), 2)))
+        g = DiGraph([range(n), edges], format='vertices_and_edges',
+                    immutable=immutable, name="Random Tournament")
 
         g._circle_embedding(list(range(n)))
 
@@ -549,7 +587,8 @@ class DiGraphGenerators:
 
     def tournaments_nauty(self, n,
                           min_out_degree=None, max_out_degree=None,
-                          strongly_connected=False, debug=False, options=""):
+                          strongly_connected=False, debug=False, options="",
+                          immutable=False):
         r"""
         Iterator over all tournaments on `n` vertices using Nauty.
 
@@ -571,6 +610,9 @@ class DiGraphGenerators:
           to Nauty's gentourng. See its documentation for more information :
           `<https://pallini.di.uniroma1.it>`_.
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          immutable or mutable digraphs
+
         EXAMPLES::
 
             sage: for g in digraphs.tournaments_nauty(4):
@@ -612,6 +654,18 @@ class DiGraphGenerators:
         if debug:
             yield sp.stderr.readline()
 
+        def edges(s):
+            i = 0
+            j = 1
+            for b in s[:-1]:
+                yield (i, j) if b == '0' else (j, i)
+
+                if j == n - 1:
+                    i += 1
+                    j = i + 1
+                else:
+                    j += 1
+
         gen = sp.stdout
         while True:
             try:
@@ -620,24 +674,10 @@ class DiGraphGenerators:
                 # Exhausted list of graphs from nauty geng
                 return
 
-            G = DiGraph(n)
-            i = 0
-            j = 1
-            for b in s[:-1]:
-                if b == '0':
-                    G.add_edge(i, j)
-                else:
-                    G.add_edge(j, i)
+            yield DiGraph([range(n), edges(s)], format='vertices_and_edges',
+                          immutable=immutable)
 
-                if j == n - 1:
-                    i += 1
-                    j = i + 1
-                else:
-                    j += 1
-
-            yield G
-
-    def nauty_directg(self, graphs, options='', debug=False):
+    def nauty_directg(self, graphs, options='', debug=False, immutable=False):
         r"""
         Return an iterator yielding digraphs using nauty's ``directg`` program.
 
@@ -669,6 +709,9 @@ class DiGraphGenerators:
         - ``debug`` -- boolean (default: ``False``); if ``True`` ``directg``
           standard error and standard output are displayed
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          immutable or mutable digraphs
+
         EXAMPLES::
 
             sage: gen = graphs.nauty_geng("-c 3")
@@ -759,9 +802,9 @@ class DiGraphGenerators:
             # digraph6 specifications:
             # http://users.cecs.anu.edu.au/~bdm/data/formats.txt
             if line and line[0] == '&':
-                yield DiGraph(line[1:], format='dig6')
+                yield DiGraph(line[1:], format='dig6', immutable=immutable)
 
-    def nauty_posetg(self, options='', debug=False):
+    def nauty_posetg(self, options='', debug=False, immutable=False):
         r"""
         Return a generator which creates all posets using ``nauty``.
 
@@ -782,6 +825,9 @@ class DiGraphGenerators:
           the program with some information on the arguments, while a line
           beginning with ">E" indicates an error with the input.
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          immutable or mutable posets
+
         The possible options, obtained as output of ``genposetg --help``::
 
             n: the number of vertices, between 0 and 16
@@ -815,10 +861,9 @@ class DiGraphGenerators:
             except StopIteration:
                 # Exhausted list of graphs from nauty genposetg
                 return
-            G = DiGraph(s[1:-1], format='dig6')
-            yield G
+            yield DiGraph(s[1:-1], format='dig6', immutable=immutable)
 
-    def Complete(self, n, loops=False):
+    def Complete(self, n, loops=False, immutable=False):
         r"""
         Return the complete digraph on `n` vertices.
 
@@ -829,6 +874,9 @@ class DiGraphGenerators:
         - ``loops`` -- boolean (default: ``False``); whether to add loops or
           not, i.e., edges from `u` to itself
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         .. SEEALSO::
 
             - :meth:`~sage.graphs.digraph_generators.DiGraphGenerators.RandomSemiComplete`
@@ -851,24 +899,32 @@ class DiGraphGenerators:
             ...
             ValueError: the number of vertices cannot be strictly negative
         """
-        G = DiGraph(n, name="Complete digraph" + (" with loops" if loops else ''), loops=loops)
+        if n < 0:
+            raise ValueError('the number of vertices cannot be strictly negative')
 
-        if loops:
-            G.add_edges((u, u) for u in range(n))
-
-        G.add_edges((u, v) for u in range(n) for v in range(n) if u != v)
+        edges = ((u, v) for u in range(n) for v in range(n) if u != v or loops)
+        G = DiGraph([range(n), edges], format='vertices_and_edges',
+                    loops=loops, immutable=immutable,
+                    name="Complete digraph" + (" with loops" if loops else ''))
 
         G._circle_embedding(list(range(n)))
 
         return G
 
-    def Circuit(self, n):
+    def Circuit(self, n, immutable=False):
         r"""
         Return the circuit on `n` vertices.
 
         The circuit is an oriented
         :meth:`~sage.graphs.graph_generators.GraphGenerators.CycleGraph`.
 
+        INPUT:
+
+        - ``n`` -- integer; number of vertices
+
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES:
 
         A circuit is the smallest strongly connected digraph::
@@ -877,19 +933,20 @@ class DiGraphGenerators:
             sage: len(circuit.strongly_connected_components()) == 1
             True
         """
-        g = DiGraph(n, name='Circuit')
-
+        if n < 0:
+            raise ValueError('the number of vertices cannot be strictly negative')
         if n == 1:
-            g.allow_loops(True)
-            g.add_edge(0, 0)
-            return g
-        elif n:
-            g.add_edges(zip(range(n - 1), range(1, n)))
-            g.add_edge(n - 1, 0)
-            g._circle_embedding(list(range(n)))
+            return DiGraph([(0, 0)], format='list_of_edges', loops=True,
+                           immutable=immutable, name='Circuit')
+
+        from itertools import chain
+        edges = zip(range(n), chain(range(1, n), [0]))
+        g = DiGraph([range(n), edges], format='vertices_and_edges',
+                    immutable=immutable, name='Circuit')
+        g._circle_embedding(list(range(n)))
         return g
 
-    def Circulant(self, n, integers):
+    def Circulant(self, n, integers, immutable=False):
         r"""
         Return a circulant digraph on `n` vertices from a set of integers.
 
@@ -904,6 +961,9 @@ class DiGraphGenerators:
           that there is an edge from `i` to `j` if and only if `(j-i) \pmod{n}`
           is an integer
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES:
 
         Construct and show the circulant graph [3, 5, 7], a digraph on 13
@@ -942,15 +1002,14 @@ class DiGraphGenerators:
             if not i % n:
                 loops = True
 
-        G = DiGraph(n, name="Circulant graph (" + str(integers) + ")", loops=loops)
-
+        edges = ((v, (v + j) % n) for j in integers for v in range(n))
+        G = DiGraph([range(n), edges], format='vertices_and_edges',
+                    loops=loops, immutable=immutable,
+                    name="Circulant graph (" + str(integers) + ")")
         G._circle_embedding(list(range(n)))
-        for v in range(n):
-            G.add_edges((v, (v + j) % n) for j in integers)
-
         return G
 
-    def DeBruijn(self, k, n, vertices='strings'):
+    def DeBruijn(self, k, n, vertices='strings', immutable=False):
         r"""
         Return the De Bruijn digraph with parameters `k,n`.
 
@@ -977,6 +1036,9 @@ class DiGraphGenerators:
           are words over an alphabet (default) or integers
           (``vertices='string'``)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES:
 
         de Bruijn digraph of degree 2 and diameter 2::
@@ -1030,40 +1092,48 @@ class DiGraphGenerators:
         """
         from sage.rings.integer import Integer
 
+        name = f"De Bruijn digraph (k={k}, n={n})"
         if vertices == 'strings':
             from sage.combinat.words.words import Words
 
             W = Words(list(range(k)) if isinstance(k, Integer) else k, n)
             A = Words(list(range(k)) if isinstance(k, Integer) else k, 1)
-            g = DiGraph(loops=True)
 
             if not n:
-                g.allow_multiple_edges(True)
-                v = W[0]
-                vs = v.string_rep()
-                for a in A:
-                    g.add_edge(vs, vs, a.string_rep())
+                multiedges = True
+
+                def edges():
+                    v = W[0]
+                    vs = v.string_rep()
+                    return ((vs, vs, a.string_rep()) for a in A)
+
             else:
-                for w in W:
-                    ww = w[1:]
-                    ws = w.string_rep()
-                    for a in A:
-                        g.add_edge(ws, (ww * a).string_rep(), a.string_rep())
+                multiedges = False
+
+                def edges():
+                    for w in W:
+                        ww = w[1:]
+                        ws = w.string_rep()
+                        yield from ((ws, (ww * a).string_rep(), a.string_rep())
+                                    for a in A)
+
+            return DiGraph(edges(), format='list_of_edges', name=name,
+                           loops=True, multiedges=multiedges,
+                           immutable=immutable)
 
         elif vertices == 'integers':
             d = k if isinstance(k, Integer) else len(list(k))
             if not d:
-                g = DiGraph(loops=True, multiedges=True)
-            else:
-                g = digraphs.GeneralizedDeBruijn(d ** n, d)
+                return DiGraph(loops=True, multiedges=True, name=name,
+                               immutable=immutable)
+
+            return digraphs.GeneralizedDeBruijn(d ** n, d, immutable=immutable,
+                                                name=name)
 
         else:
             raise ValueError('unknown type for vertices')
 
-        g.name("De Bruijn digraph (k={}, n={})".format(k, n))
-        return g
-
-    def GeneralizedDeBruijn(self, n, d):
+    def GeneralizedDeBruijn(self, n, d, immutable=False, name=None):
         r"""
         Return the generalized de Bruijn digraph of order `n` and degree `d`.
 
@@ -1082,6 +1152,12 @@ class DiGraphGenerators:
 
         - ``d`` -- integer; degree of the digraph (must be at least one)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
+        - ``name`` -- string (default: ``None``); when set, the specified name
+          is used instead of the default one
+
         .. SEEALSO::
 
             * :meth:`sage.graphs.generic_graph.GenericGraph.is_circulant` --
@@ -1115,15 +1191,15 @@ class DiGraphGenerators:
             raise ValueError("order must be greater than or equal to one")
         if d < 1:
             raise ValueError("degree must be greater than or equal to one")
+        if name is None:
+            name = f"Generalized de Bruijn digraph (n={n}, d={d})"
 
-        GB = DiGraph(n, loops=True, multiedges=True,
-                     name="Generalized de Bruijn digraph (n={}, d={})".format(n, d))
-        for u in range(n):
-            for a in range(u * d, u * d + d):
-                GB.add_edge(u, a % n)
-        return GB
+        edges = ((u, a % n) for u in range(n) for a in range(u * d, u * d + d))
+        return DiGraph([range(n), edges], format='vertices_and_edges',
+                       loops=True, multiedges=True, immutable=immutable,
+                       name=name)
 
-    def ImaseItoh(self, n, d):
+    def ImaseItoh(self, n, d, immutable=False, name=None):
         r"""
         Return the Imase-Itoh digraph of order `n` and degree `d`.
 
@@ -1145,6 +1221,12 @@ class DiGraphGenerators:
         - ``d`` -- integer; degree of the digraph (must be greater than or
           equal to one)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
+        - ``name`` -- string (default: ``None``); when set, the specified name
+          is used instead of the default one
+
         EXAMPLES::
 
             sage: II = digraphs.ImaseItoh(8, 2)
@@ -1181,15 +1263,15 @@ class DiGraphGenerators:
             raise ValueError("order must be greater than or equal to two")
         if d < 1:
             raise ValueError("degree must be greater than or equal to one")
+        if name is None:
+            name = f"Imase and Itoh digraph (n={n}, d={d})"
 
-        II = DiGraph(n, loops=True, multiedges=True,
-                     name="Imase and Itoh digraph (n={}, d={})".format(n, d))
-        for u in range(n):
-            for a in range(-u * d - d, -u * d):
-                II.add_edge(u, a % n)
-        return II
+        edges = ((u, a % n) for u in range(n) for a in range(-u * d - d, -u * d))
+        return DiGraph([range(n), edges], format='vertices_and_edges',
+                       loops=True, multiedges=True, immutable=immutable,
+                       name=name)
 
-    def Kautz(self, k, D, vertices='strings'):
+    def Kautz(self, k, D, vertices='strings', immutable=False):
         r"""
         Return the Kautz digraph of degree `d` and diameter `D`.
 
@@ -1224,6 +1306,9 @@ class DiGraphGenerators:
           are words over an alphabet (default) or integers
           (``vertices='strings'``)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          an immutable or mutable digraph
+
         EXAMPLES::
 
             sage: # needs sage.combinat
@@ -1298,6 +1383,8 @@ class DiGraphGenerators:
 
         from sage.rings.integer import Integer
 
+        name = f"Kautz digraph (k={k}, D={D})"
+
         if vertices == 'strings':
             from sage.combinat.words.words import Words
 
@@ -1315,27 +1402,26 @@ class DiGraphGenerators:
                 V = VV
 
             # We now build the set of arcs
-            G = DiGraph()
-            for u in V:
-                us = u.string_rep()
-                for a in my_alphabet:
-                    if not u.has_suffix(a):
-                        G.add_edge(us, (u[1:] * a).string_rep(),
-                                   a.string_rep())
+            def edges():
+                for u in V:
+                    us = u.string_rep()
+                    yield from ((us, (u[1:] * a).string_rep(), a.string_rep())
+                                for a in my_alphabet if not u.has_suffix(a))
+
+            return DiGraph(edges(), format='list_of_edges',
+                           name=name, immutable=immutable)
 
         elif vertices == 'integers':
             d = k if isinstance(k, Integer) else (len(list(k)) - 1)
             if d < 1:
                 raise ValueError("degree must be greater than or equal to one")
-            G = digraphs.ImaseItoh((d + 1) * (d ** (D - 1)), d)
+            return digraphs.ImaseItoh((d + 1) * (d ** (D - 1)), d,
+                                      name=name, immutable=immutable)
 
         else:
             raise ValueError('unknown type for vertices')
 
-        G.name("Kautz digraph (k={}, D={})".format(k, D))
-        return G
-
-    def RandomDirectedAcyclicGraph(self, n, p, weight_max=None):
+    def RandomDirectedAcyclicGraph(self, n, p, weight_max=None, immutable=False):
         r"""
         Return a random (weighted) directed acyclic graph of order `n`.
 
@@ -1355,6 +1441,9 @@ class DiGraphGenerators:
           unweighted. When ``weight_max`` is set to a positive integer, edges
           are assigned a random integer weight between ``1`` and ``weight_max``.
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return an
+          immutable or mutable digraph
+
         EXAMPLES::
 
             sage: D = digraphs.RandomDirectedAcyclicGraph(5, .5); D
@@ -1405,21 +1494,22 @@ class DiGraphGenerators:
         pp = int(round(float(p * RAND_MAX_f)))
 
         if weight_max is None:
-            D = DiGraph(n, name=f"RandomDAG({n}, {p})")
-            D.add_edges((i, j) for i in range(n) for j in range(i) if random() < pp)
+            name = f"RandomDAG({n}, {p})"
+            edges = ((i, j) for i in range(n) for j in range(i) if random() < pp)
 
         else:
             from sage.rings.integer_ring import ZZ
             if weight_max in ZZ and weight_max < 1:
                 raise ValueError("parameter weight_max must be a positive integer")
 
-            D = DiGraph(n, name=f"RandomWeightedDAG({n}, {p}, {weight_max})")
-            D.add_edges((i, j, randint(1, weight_max))
-                        for i in range(n) for j in range(i) if random() < pp)
+            name = f"RandomWeightedDAG({n}, {p}, {weight_max})"
+            edges = ((i, j, randint(1, weight_max))
+                     for i in range(n) for j in range(i) if random() < pp)
 
-        return D
+        return DiGraph([range(n), edges], format='vertices_and_edges',
+                       name=name, immutable=immutable)
 
-    def RandomDirectedGN(self, n, kernel=None, seed=None):
+    def RandomDirectedGN(self, n, kernel=None, seed=None, immutable=False):
         r"""
         Return a random growing network (GN) digraph with `n` vertices.
 
@@ -1439,6 +1529,9 @@ class DiGraphGenerators:
         - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the
           random number generator (default: ``None``)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return an
+          immutable or mutable digraph
+
         EXAMPLES::
 
             sage: # needs networkx
@@ -1458,9 +1551,10 @@ class DiGraphGenerators:
         if seed is None:
             seed = int(current_randstate().long_seed() % sys.maxsize)
         import networkx
-        return DiGraph(networkx.gn_graph(n, kernel, seed=seed))
+        return DiGraph(networkx.gn_graph(n, kernel, seed=seed),
+                       immutable=immutable)
 
-    def RandomDirectedGNC(self, n, seed=None):
+    def RandomDirectedGNC(self, n, seed=None, immutable=False):
         r"""
         Return a random growing network with copying (GNC) digraph with `n`
         vertices.
@@ -1478,6 +1572,9 @@ class DiGraphGenerators:
         - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the
           random number generator (default: ``None``)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return an
+          immutable or mutable digraph
+
         EXAMPLES::
 
             sage: # needs networkx
@@ -1491,9 +1588,9 @@ class DiGraphGenerators:
         if seed is None:
             seed = int(current_randstate().long_seed() % sys.maxsize)
         import networkx
-        return DiGraph(networkx.gnc_graph(n, seed=seed))
+        return DiGraph(networkx.gnc_graph(n, seed=seed), immutable=immutable)
 
-    def RandomDirectedGNP(self, n, p, loops=False, seed=None):
+    def RandomDirectedGNP(self, n, p, loops=False, seed=None, immutable=False):
         r"""
         Return a random digraph on `n` nodes.
 
@@ -1512,6 +1609,9 @@ class DiGraphGenerators:
         - ``seed`` -- integer (default: ``None``); seed for random number
           generator
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return an
+          immutable or mutable digraph
+
         PLOTTING: When plotting, this graph will use the default spring-layout
         algorithm, unless a position dictionary is specified.
 
@@ -1530,9 +1630,10 @@ class DiGraphGenerators:
         if seed is None:
             seed = current_randstate().long_seed()
 
-        return RandomGNP(n, p, directed=True, loops=loops, seed=seed)
+        return RandomGNP(n, p, directed=True, loops=loops, seed=seed,
+                         immutable=immutable)
 
-    def RandomDirectedGNM(self, n, m, loops=False):
+    def RandomDirectedGNM(self, n, m, loops=False, immutable=False):
         r"""
         Return a random labelled digraph on `n` nodes and `m` arcs.
 
@@ -1544,6 +1645,9 @@ class DiGraphGenerators:
 
         - ``loops`` -- boolean (default: ``False``); whether to allow loops
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return an
+          immutable or mutable digraph
+
         PLOTTING: When plotting, this graph will use the default spring-layout
         algorithm, unless a position dictionary is specified.
 
@@ -1586,10 +1690,6 @@ class DiGraphGenerators:
         # When the graph is dense, we actually compute its complement. This will
         # prevent us from drawing the same pair u,v too many times.
 
-        from sage.misc.prandom import _pyrand
-        rand = _pyrand()
-        D = DiGraph(n, loops=loops)
-
         # Ensuring the parameters n,m make sense.
         #
         # If the graph is dense, we actually want to build its complement. We
@@ -1630,9 +1730,10 @@ class DiGraphGenerators:
 
         adj = {i: dict() for i in range(n)}
 
-        # We fill the dictionary structure, but add the corresponding edge in
-        # the graph only if is_dense is False. If it is true, we will add the
-        # edges in a second phase.
+        # We fill the dictionary structure.
+
+        from sage.misc.prandom import _pyrand
+        rand = _pyrand()
 
         while m > 0:
 
@@ -1648,21 +1749,19 @@ class DiGraphGenerators:
             if (u != v or loops) and (v not in adj[u]):
                 adj[u][v] = 1
                 m -= 1
-                if not is_dense:
-                    D.add_edge(u, v)
 
-        # If is_dense is True, it means the graph has not been built. We fill D
-        # with the complement of the edges stored in the adj dictionary
+        # If is_dense is True, we fill the digraph with the complement of the
+        # edges stored in the adj dictionary
 
         if is_dense:
-            for u in range(n):
-                for v in range(n):
-                    if ((u != v) or loops) and (v not in adj[u]):
-                        D.add_edge(u, v)
+            edges = ((u, v) for u in range(n) for v in range(n)
+                     if (u != v or loops) and v not in adj[u])
+            return DiGraph([range(n), edges], format='vertices_and_edges',
+                           loops=loops, immutable=immutable)
 
-        return D
+        return DiGraph(adj, format='dict_of_lists', loops=loops)
 
-    def RandomDirectedGNR(self, n, p, seed=None):
+    def RandomDirectedGNR(self, n, p, seed=None, immutable=False):
         r"""
         Return a random growing network with redirection (GNR) digraph
         with `n` vertices and redirection probability `p`.
@@ -1682,6 +1781,9 @@ class DiGraphGenerators:
         - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the
           random number generator (default: ``None``)
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return an
+          immutable or mutable digraph
+
         EXAMPLES::
 
             sage: # needs networkx
@@ -1695,9 +1797,9 @@ class DiGraphGenerators:
         if seed is None:
             seed = int(current_randstate().long_seed() % sys.maxsize)
         import networkx
-        return DiGraph(networkx.gnr_graph(n, p, seed=seed))
+        return DiGraph(networkx.gnr_graph(n, p, seed=seed), immutable=immutable)
 
-    def RandomSemiComplete(self, n):
+    def RandomSemiComplete(self, n, immutable=False):
         r"""
         Return a random semi-complete digraph on `n` vertices.
 
@@ -1717,6 +1819,9 @@ class DiGraphGenerators:
 
         - ``n`` -- integer; the number of nodes
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return an
+          immutable or mutable digraph
+
         .. SEEALSO::
 
             - :meth:`~sage.graphs.digraph_generators.DiGraphGenerators.Complete`
@@ -1734,22 +1839,26 @@ class DiGraphGenerators:
             ...
             ValueError: the number of vertices cannot be strictly negative
         """
-        G = DiGraph(n, name="Random Semi-Complete digraph")
+        if n < 0:
+            raise ValueError('the number of vertices cannot be strictly negative')
 
         # For each pair u,v we choose a random number ``coin`` in [1,3].
         # We select edge `(u,v)` if `coin==1` or `coin==2`.
         # We select edge `(v,u)` if `coin==2` or `coin==3`.
         import itertools
         from sage.misc.prandom import randint
-        for u, v in itertools.combinations(range(n), 2):
-            coin = randint(1, 3)
-            if coin <= 2:
-                G.add_edge(u, v)
-            if coin >= 2:
-                G.add_edge(v, u)
 
+        def edges():
+            for u, v in itertools.combinations(range(n), 2):
+                coin = randint(1, 3)
+                if coin <= 2:
+                    yield (u, v)
+                if coin >= 2:
+                    yield (v, u)
+
+        G = DiGraph([range(n), edges()], format='vertices_and_edges',
+                    immutable=immutable, name="Random Semi-Complete digraph")
         G._circle_embedding(list(range(n)))
-
         return G
 
 # ##############################################################################
@@ -1757,7 +1866,7 @@ class DiGraphGenerators:
 # ##############################################################################
 
     def __call__(self, vertices=None, property=lambda x: True, augment='edges',
-                 size=None, sparse=True, copy=True):
+                 size=None, sparse=True, copy=True, immutable=False):
         """
         Access the generator of isomorphism class representatives [McK1998]_.
         Iterates over distinct, exhaustive representatives.
@@ -1801,6 +1910,13 @@ class DiGraphGenerators:
           compute the next ones: only use ``copy = False`` when you stick to
           *reading* the digraphs returned.
 
+          This parameter is ignored when ``immutable`` is set to ``True``, in
+          which case returned graphs are always copies.
+
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          immutable or mutable digraphs. When set to ``True``, this parameter
+          implies ``copy=True``.
+
         EXAMPLES:
 
         Print digraphs on 2 or less vertices::
@@ -1827,7 +1943,6 @@ class DiGraphGenerators:
 
             sage: digraphs?  # not tested
         """
-        from copy import copy as copyfun
         if size is not None:
             def extra_property(x):
                 return x.size() == size
@@ -1842,14 +1957,15 @@ class DiGraphGenerators:
             g = DiGraph(sparse=sparse)
             for gg in canaug_traverse_vert(g, [], vertices, property, dig=True, sparse=sparse):
                 if extra_property(gg):
-                    yield copyfun(gg) if copy else gg
+                    yield gg.copy(immutable=immutable) if copy or immutable else gg
 
         elif augment == 'edges':
 
             if vertices is None:
                 vertices = 0
                 while True:
-                    yield from self(vertices, sparse=sparse, copy=copy)
+                    yield from self(vertices, sparse=sparse, copy=copy,
+                                    immutable=immutable)
                     vertices += 1
 
             from sage.graphs.graph_generators import canaug_traverse_edge
@@ -1863,7 +1979,7 @@ class DiGraphGenerators:
                 gens.append(gen)
             for gg in canaug_traverse_edge(g, gens, property, dig=True, sparse=sparse):
                 if extra_property(gg):
-                    yield copyfun(gg) if copy else gg
+                    yield gg.copy(immutable=immutable) if copy or immutable else gg
         else:
             raise NotImplementedError()
 
