@@ -18,7 +18,6 @@ and more precisely:
     :meth:`~greedy_dominating_set` | Return a greedy distance-`k` dominating set of the graph.
     :meth:`~maximum_leaf_number` | Return the maximum leaf number of the graph.
 
-
 EXAMPLES:
 
 We compute the size of a minimum dominating set of the Petersen graph::
@@ -80,11 +79,11 @@ def is_dominating(G, dom, focus=None):
     INPUT:
 
     - ``dom`` -- iterable of vertices of ``G``; the vertices of the supposed
-      dominating set.
+      dominating set
 
     - ``focus`` -- iterable of vertices of ``G`` (default: ``None``); if
       specified, this method checks instead if ``dom`` dominates the vertices in
-      ``focus``.
+      ``focus``
 
     EXAMPLES::
 
@@ -117,11 +116,11 @@ def is_redundant(G, dom, focus=None):
     INPUT:
 
     - ``dom`` -- iterable of vertices of ``G``; where we look for redundant
-      vertices.
+      vertices
 
     - ``focus`` -- iterable of vertices of ``G`` (default: ``None``); if
       specified, this method checks instead whether ``dom`` has a redundant
-      vertex in ``focus``.
+      vertex in ``focus``
 
     .. WARNING::
 
@@ -181,10 +180,10 @@ def private_neighbors(G, vertex, dom):
 
     INPUT:
 
-    - ``vertex`` -- a vertex of ``G``.
+    - ``vertex`` -- a vertex of ``G``
 
     - ``dom`` -- iterable of vertices of ``G``; the vertices possibly stealing
-      private neighbors from ``vertex``.
+      private neighbors from ``vertex``
 
     OUTPUT:
 
@@ -251,7 +250,7 @@ def dominating_sets(g, k=1, independent=False, total=False, connected=False,
 
     INPUT:
 
-    - ``k`` -- a non-negative integer (default: ``1``); the domination distance
+    - ``k`` -- nonnegative integer (default: `1`); the domination distance
 
     - ``independent`` -- boolean (default: ``False``); when ``True``, computes
       minimum independent dominating sets, that is minimum dominating sets that
@@ -264,7 +263,7 @@ def dominating_sets(g, k=1, independent=False, total=False, connected=False,
     - ``connected`` -- boolean (default: ``False``); when ``True``, computes
       connected dominating sets (see :wikipedia:`Connected_dominating_set`)
 
-    - ``solver`` -- string (default: ``None``); specify a Mixed Integer Linear
+    - ``solver`` -- string (default: ``None``); specifies a Mixed Integer Linear
       Programming (MILP) solver to be used. If set to ``None``, the default one
       is used. For more information on MILP solvers and which default solver is
       used, see the method :meth:`solve
@@ -272,7 +271,7 @@ def dominating_sets(g, k=1, independent=False, total=False, connected=False,
       :class:`MixedIntegerLinearProgram
       <sage.numerical.mip.MixedIntegerLinearProgram>`.
 
-    - ``verbose`` -- integer (default: ``0``); sets the level of verbosity. Set
+    - ``verbose`` -- integer (default: 0); sets the level of verbosity. Set
       to 0 by default, which means quiet.
 
     - ``integrality_tolerance`` -- float; parameter for use with MILP solvers
@@ -379,7 +378,7 @@ def dominating_sets(g, k=1, independent=False, total=False, connected=False,
         sage: next(g.dominating_sets(k=-1))
         Traceback (most recent call last):
         ...
-        ValueError: the domination distance must be a non-negative integer
+        ValueError: the domination distance must be a nonnegative integer
 
     The method is robust to vertices with incomparable labels::
 
@@ -394,7 +393,7 @@ def dominating_sets(g, k=1, independent=False, total=False, connected=False,
         yield list(g)
         return
     if k < 0:
-        raise ValueError("the domination distance must be a non-negative integer")
+        raise ValueError("the domination distance must be a nonnegative integer")
 
     from sage.numerical.mip import MixedIntegerLinearProgram
     from sage.numerical.mip import MIPSolverException
@@ -476,6 +475,7 @@ def dominating_sets(g, k=1, independent=False, total=False, connected=False,
         # Prevent finding twice a solution
         p.add_constraint(p.sum(b[u] for u in dom) <= best - 1)
 
+
 def dominating_set(g, k=1, independent=False, total=False, connected=False, value_only=False,
                    solver=None, verbose=0, *, integrality_tolerance=1e-3):
     r"""
@@ -503,7 +503,7 @@ def dominating_set(g, k=1, independent=False, total=False, connected=False, valu
 
     INPUT:
 
-    - ``k`` -- a non-negative integer (default: ``1``); the domination distance
+    - ``k`` -- nonnegative integer (default: `1`); the domination distance
 
     - ``independent`` -- boolean (default: ``False``); when ``True``, computes a
       minimum independent dominating set, that is a minimum dominating set that
@@ -520,7 +520,7 @@ def dominating_set(g, k=1, independent=False, total=False, connected=False, valu
       cardinality of the computed dominating set, or to return its list of
       vertices (default)
 
-    - ``solver`` -- string (default: ``None``); specify a Mixed Integer Linear
+    - ``solver`` -- string (default: ``None``); specifies a Mixed Integer Linear
       Programming (MILP) solver to be used. If set to ``None``, the default one
       is used. For more information on MILP solvers and which default solver is
       used, see the method :meth:`solve
@@ -528,7 +528,7 @@ def dominating_set(g, k=1, independent=False, total=False, connected=False, valu
       :class:`MixedIntegerLinearProgram
       <sage.numerical.mip.MixedIntegerLinearProgram>`.
 
-    - ``verbose`` -- integer (default: ``0``); sets the level of verbosity. Set
+    - ``verbose`` -- integer (default: 0); sets the level of verbosity. Set
       to 0 by default, which means quiet.
 
     - ``integrality_tolerance`` -- float; parameter for use with MILP solvers
@@ -588,6 +588,7 @@ def dominating_set(g, k=1, independent=False, total=False, connected=False, valu
 # Enumeration of minimal dominating set as described in [BDHPR2019]_
 # ==============================================================================
 
+
 def _parent(G, dom, V_prev):
     r"""
     Return a subset of dom that is irredundant in ``V_prev``.
@@ -655,7 +656,7 @@ def _peel(G, A):
 
     - ``G`` -- a graph
 
-    - ``A`` -- a set of vertices of `G`
+    - ``A`` -- set of vertices of `G`
 
     OUTPUT:
 
@@ -681,7 +682,6 @@ def _peel(G, A):
         (4, {4, 6, 8}),
         (2, {2, 4, 6, 8}),
         (0, {0, 2, 4, 6, 8})]
-
     """
     Acomp = set(G)
     Acomp.difference_update(A)  # Acomp  = V - A
@@ -716,9 +716,7 @@ def _cand_ext_enum(G, to_dom, u_next):
 
     - ``u_next`` -- a vertex of ``G`` that dominates ``to_dom``
 
-    OUTPUT:
-
-    An iterator over the minimal dominating sets of ``to_dom``.
+    OUTPUT: an iterator over the minimal dominating sets of ``to_dom``
 
     TESTS::
 
@@ -808,16 +806,16 @@ def minimal_dominating_sets(G, to_dominate=None, work_on_copy=True, k=1):
 
     INPUT:
 
-    - ``G`` -- a graph.
+    - ``G`` -- a graph
 
     - ``to_dominate`` -- vertex iterable or ``None`` (default: ``None``);
-      the set of vertices to be dominated.
+      the set of vertices to be dominated
 
     - ``work_on_copy`` -- boolean (default: ``True``); whether or not to work on
       a copy of the input graph; if set to ``False``, the input graph will be
-      modified (relabeled).
+      modified (relabeled)
 
-    - ``k`` -- a non-negative integer (default: ``1``); the domination distance
+    - ``k`` -- nonnegative integer (default: `1`); the domination distance
 
     OUTPUT:
 
@@ -966,7 +964,7 @@ def minimal_dominating_sets(G, to_dominate=None, work_on_copy=True, k=1):
         sage: next(Graph(1).minimal_dominating_sets(k=-1))
         Traceback (most recent call last):
         ...
-        ValueError: the domination distance must be a non-negative integer
+        ValueError: the domination distance must be a nonnegative integer
 
     Trying to dominate vertices that are not part of the graph::
 
@@ -996,7 +994,7 @@ def minimal_dominating_sets(G, to_dominate=None, work_on_copy=True, k=1):
 
         - ``dom`` -- a minimal dominating set of ``plng[i][1]``
 
-        - ``i`` -- an integer, the current position in ``plng``
+        - ``i`` -- integer; the current position in ``plng``
 
         OUTPUT:
 
@@ -1048,7 +1046,7 @@ def minimal_dominating_sets(G, to_dominate=None, work_on_copy=True, k=1):
     # end of tree-search routine
 
     if k < 0:
-        raise ValueError("the domination distance must be a non-negative integer")
+        raise ValueError("the domination distance must be a nonnegative integer")
     if not k:
         yield set(G) if to_dominate is None else set(to_dominate)
         return
@@ -1110,7 +1108,7 @@ def greedy_dominating_set(G, k=1, vertices=None, ordering=None, return_sets=Fals
 
     - ``G`` -- a Graph
 
-    - ``k`` -- integer (default: ``1``); the domination distance to consider
+    - ``k`` -- integer (default: `1`); the domination distance to consider
 
     - ``vertices`` -- iterable container of vertices (default: ``None``); when
       specified, return a dominating set of the specified vertices only
@@ -1122,9 +1120,9 @@ def greedy_dominating_set(G, k=1, vertices=None, ordering=None, return_sets=Fals
         the order given by ``list(G)``. Otherwise, consider the vertices in the
         order of iteration of ``vertices``.
 
-      - ``"degree_min"`` -- consider the vertices by increasing degree
+      - ``'degree_min'`` -- consider the vertices by increasing degree
 
-      - ``"degree_max"`` -- consider the vertices by decreasing degree
+      - ``'degree_max'`` -- consider the vertices by decreasing degree
 
     - ``return_sets`` -- boolean (default: ``False``); whether to return the
       vertices of the dominating set only (default), or a dictionary mapping
@@ -1142,19 +1140,19 @@ def greedy_dominating_set(G, k=1, vertices=None, ordering=None, return_sets=Fals
         sage: G = graphs.PathGraph(5)
         sage: sorted(greedy_dominating_set(G, ordering=None))
         [0, 2, 4]
-        sage: sorted(greedy_dominating_set(G, ordering="degree_min"))
+        sage: sorted(greedy_dominating_set(G, ordering='degree_min'))
         [0, 2, 4]
-        sage: sorted(greedy_dominating_set(G, ordering="degree_max"))
+        sage: sorted(greedy_dominating_set(G, ordering='degree_max'))
         [1, 3]
         sage: sorted(greedy_dominating_set(G, k=2, ordering=None))
         [0, 3]
-        sage: sorted(greedy_dominating_set(G, k=2, ordering="degree_min"))
+        sage: sorted(greedy_dominating_set(G, k=2, ordering='degree_min'))
         [0, 4]
-        sage: sorted(greedy_dominating_set(G, k=2, ordering="degree_max"))
+        sage: sorted(greedy_dominating_set(G, k=2, ordering='degree_max'))
         [1, 4]
-        sage: greedy_dominating_set(G, k=3, ordering="degree_min", return_sets=True, closest=False)
+        sage: greedy_dominating_set(G, k=3, ordering='degree_min', return_sets=True, closest=False)
         {0: {0, 1, 2, 3}, 4: {4}}
-        sage: greedy_dominating_set(G, k=3, ordering="degree_min", return_sets=True, closest=True)
+        sage: greedy_dominating_set(G, k=3, ordering='degree_min', return_sets=True, closest=True)
         {0: {0, 2, 3}, 4: {1, 4}}
 
     Asking for a dominating set of a subset of vertices::
@@ -1222,7 +1220,7 @@ def greedy_dominating_set(G, k=1, vertices=None, ordering=None, return_sets=Fals
 
     Check parameters::
 
-        sage: greedy_dominating_set(G, ordering="foo")
+        sage: greedy_dominating_set(G, ordering='foo')
         Traceback (most recent call last):
         ...
         ValueError: ordering must be None, "degree_min" or "degree_max"
@@ -1302,7 +1300,7 @@ def maximum_leaf_number(G, solver=None, verbose=0, integrality_tolerance=1e-3):
 
     - ``G`` -- a Graph
 
-    - ``solver`` -- string (default: ``None``); specify a Mixed Integer Linear
+    - ``solver`` -- string (default: ``None``); specifies a Mixed Integer Linear
       Programming (MILP) solver to be used. If set to ``None``, the default one
       is used. For more information on MILP solvers and which default solver is
       used, see the method :meth:`solve
@@ -1310,7 +1308,7 @@ def maximum_leaf_number(G, solver=None, verbose=0, integrality_tolerance=1e-3):
       :class:`MixedIntegerLinearProgram
       <sage.numerical.mip.MixedIntegerLinearProgram>`.
 
-    - ``verbose`` -- integer (default: ``0``); sets the level of verbosity. Set
+    - ``verbose`` -- integer (default: 0); sets the level of verbosity. Set
       to 0 by default, which means quiet.
 
     - ``integrality_tolerance`` -- float; parameter for use with MILP solvers
