@@ -109,12 +109,12 @@ class DualAbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
     EXAMPLES::
 
-        sage: F = AbelianGroup(5,[3,5,7,8,9], names="abcde")
+        sage: F = AbelianGroup(5,[3,5,7,8,9], names='abcde')
         sage: F.dual_group()
         Dual of Abelian Group isomorphic to Z/3Z x Z/5Z x Z/7Z x Z/8Z x Z/9Z
         over Cyclotomic Field of order 2520 and degree 576
 
-        sage: F = AbelianGroup(4,[15,7,8,9], names="abcd")
+        sage: F = AbelianGroup(4,[15,7,8,9], names='abcd')
         sage: F.dual_group(base_ring=CC)                                                # needs sage.rings.real_mpfr
         Dual of Abelian Group isomorphic to Z/15Z x Z/7Z x Z/8Z x Z/9Z
         over Complex Field with 53 bits of precision
@@ -127,7 +127,7 @@ class DualAbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
         EXAMPLES::
 
-            sage: F = AbelianGroup(5,[3,5,7,8,9], names="abcde")
+            sage: F = AbelianGroup(5,[3,5,7,8,9], names='abcde')
             sage: F.dual_group()
             Dual of Abelian Group isomorphic to Z/3Z x Z/5Z x Z/7Z x Z/8Z x Z/9Z
             over Cyclotomic Field of order 2520 and degree 576
@@ -233,8 +233,8 @@ class DualAbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
             sage: # needs sage.rings.real_mpfr
             sage: N = 43^2 - 1
-            sage: G = AbelianGroup([N], names="a")
-            sage: Gd = G.dual_group(names="A", base_ring=CC)
+            sage: G = AbelianGroup([N], names='a')
+            sage: Gd = G.dual_group(names='A', base_ring=CC)
             sage: a, = G.gens()
             sage: A, = Gd.gens()
             sage: x = a^(N/4); y = a^(N/3); z = a^(N/14)
@@ -257,7 +257,7 @@ class DualAbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
         EXAMPLES::
 
             sage: F = AbelianGroup(3, [1,2,3], names='a')
-            sage: Fd = F.dual_group(names="A")
+            sage: Fd = F.dual_group(names='A')
             sage: Fd.0
             1
             sage: Fd.1
@@ -338,9 +338,9 @@ class DualAbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
         EXAMPLES::
 
-            sage: F = AbelianGroup(5,[2, 3, 5, 7, 8], names="abcde")
+            sage: F = AbelianGroup(5,[2, 3, 5, 7, 8], names='abcde')
             sage: a,b,c,d,e = F.gens()
-            sage: Fd = F.dual_group(names="ABCDE")
+            sage: Fd = F.dual_group(names='ABCDE')
             sage: A,B,C,D,E = Fd.gens()
             sage: A*B^2*D^7 in Fd
             True
@@ -383,8 +383,8 @@ class DualAbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
         EXAMPLES::
 
-            sage: G = AbelianGroup([2,3], names="ab")
-            sage: Gd = G.dual_group(names="AB")
+            sage: G = AbelianGroup([2,3], names='ab')
+            sage: Gd = G.dual_group(names='AB')
             sage: Gd.list()
             (1, B, B^2, A, A*B, A*B^2)
         """
@@ -399,15 +399,15 @@ class DualAbelianGroup_class(UniqueRepresentation, AbelianGroupBase):
 
         EXAMPLES::
 
-            sage: G = AbelianGroup([2,3], names="ab")
-            sage: Gd = G.dual_group(names="AB")
+            sage: G = AbelianGroup([2,3], names='ab')
+            sage: Gd = G.dual_group(names='AB')
             sage: [X for X in Gd]
             [1, B, B^2, A, A*B, A*B^2]
 
             sage: # needs sage.rings.real_mpfr
             sage: N = 43^2 - 1
-            sage: G = AbelianGroup([N], names="a")
-            sage: Gd = G.dual_group(names="A", base_ring=CC)
+            sage: G = AbelianGroup([N], names='a')
+            sage: Gd = G.dual_group(names='A', base_ring=CC)
             sage: a, = G.gens()
             sage: A, = Gd.gens()
             sage: x = a^(N/4)
