@@ -30,7 +30,7 @@ from sage.structure.richcmp import richcmp
 
 class AbelianGroupElementBase(MultiplicativeGroupElement):
     """
-    Base class for abelian group elements
+    Base class for abelian group elements.
 
     The group element is defined by a tuple whose ``i``-th entry is an
     integer in the range from 0 (inclusively) to ``G.gen(i).order()``
@@ -39,16 +39,16 @@ class AbelianGroupElementBase(MultiplicativeGroupElement):
 
     INPUT:
 
-    - ``exponents`` -- ``1`` or a list/tuple/iterable of integers. The
+    - ``exponents`` -- ``1`` or a list/tuple/iterable of integers; the
       exponent vector (with respect to the parent generators) defining
-      the group element.
+      the group element
 
-    - ``parent`` -- Abelian group. The parent of the group element.
+    - ``parent`` -- abelian group; the parent of the group element
 
     EXAMPLES::
 
         sage: F = AbelianGroup(3,[7,8,9])
-        sage: Fd = F.dual_group(names="ABC")                                            # needs sage.rings.number_field
+        sage: Fd = F.dual_group(names='ABC')                                            # needs sage.rings.number_field
         sage: A,B,C = Fd.gens()                                                         # needs sage.rings.number_field
         sage: A*B^-1 in Fd                                                              # needs sage.rings.number_field
         True
@@ -61,7 +61,7 @@ class AbelianGroupElementBase(MultiplicativeGroupElement):
         EXAMPLES::
 
             sage: F = AbelianGroup(3,[7,8,9])
-            sage: Fd = F.dual_group(names="ABC")                                        # needs sage.rings.number_field
+            sage: Fd = F.dual_group(names='ABC')                                        # needs sage.rings.number_field
             sage: A,B,C = Fd.gens()                                                     # needs sage.rings.number_field
             sage: A*B^-1 in Fd                                                          # needs sage.rings.number_field
             True
@@ -148,9 +148,9 @@ class AbelianGroupElementBase(MultiplicativeGroupElement):
         EXAMPLES::
 
             sage: # needs sage.rings.number_field
-            sage: F = AbelianGroup(5,[2, 3, 5, 7, 8], names="abcde")
+            sage: F = AbelianGroup(5,[2, 3, 5, 7, 8], names='abcde')
             sage: a,b,c,d,e = F.gens()
-            sage: Ad = F.dual_group(names="ABCDE")
+            sage: Ad = F.dual_group(names='ABCDE')
             sage: A,B,C,D,E = Ad.gens()
             sage: (A*B*C^2*D^20*E^65).exponents()
             (1, 1, 2, 6, 1)
