@@ -31,10 +31,10 @@ class GroupSemidirectProductElement(CartesianProduct.Element):
 
         EXAMPLES::
 
-            sage: def twist(x,y):
+            sage: def twist(x, y):
             ....:     return y
-            sage: GroupSemidirectProduct(WeylGroup(['A',2],prefix="s"),         # indirect doctest
-            ....:                        WeylGroup(['A',3],prefix="t"), twist)
+            sage: GroupSemidirectProduct(WeylGroup(['A',2],prefix='s'),         # indirect doctest
+            ....:                        WeylGroup(['A',3],prefix='t'), twist)
             Semidirect product of Weyl Group of type ['A', 2]
             (as a matrix group acting on the ambient space) acting on
             Weyl Group of type ['A', 3]
@@ -72,8 +72,8 @@ class GroupSemidirectProductElement(CartesianProduct.Element):
             sage: L = RootSystem(['A',2]).root_lattice()
             sage: from sage.groups.group_exp import GroupExp
             sage: EL = GroupExp()(L)
-            sage: W = L.weyl_group(prefix="s")
-            sage: def twist(w,v):
+            sage: W = L.weyl_group(prefix='s')
+            sage: def twist(w, v):
             ....:     return EL(w.action(v.value))
             sage: G = GroupSemidirectProduct(W, EL, twist, prefix1='t')
             sage: g = G.an_element(); g
@@ -102,10 +102,10 @@ class GroupSemidirectProductElement(CartesianProduct.Element):
             Root lattice of the Root system of type ['A', 2]
             sage: from sage.groups.group_exp import GroupExp
             sage: EL = GroupExp()(L)
-            sage: W = L.weyl_group(prefix="s"); W
+            sage: W = L.weyl_group(prefix='s'); W
             Weyl Group of type ['A', 2]
             (as a matrix group acting on the root lattice)
-            sage: def twist(w,v):
+            sage: def twist(w, v):
             ....:     return EL(w.action(v.value))
             sage: G = GroupSemidirectProduct(W, EL, twist, prefix1='t'); G
             Semidirect product of Weyl Group of type ['A', 2] (as a matrix
@@ -141,14 +141,14 @@ class GroupSemidirectProduct(CartesianProduct):
 
     INPUT:
 
-    - ``G`` and ``H`` -- multiplicative groups
+    - ``G``, ``H`` -- multiplicative groups
     - ``twist`` -- (default: ``None``) a function defining
       a homomorphism (see below)
-    - ``act_to_right`` -- ``True`` or ``False`` (default: ``True``)
-    - ``prefix0`` -- (default: ``None``) optional string
-    - ``prefix1`` -- (default: ``None``) optional string
-    - ``print_tuple`` -- ``True`` or ``False`` (default: ``False``)
-    - ``category`` -- A category (default: ``Groups()``)
+    - ``act_to_right`` -- boolean (default: ``True``)
+    - ``prefix0`` -- string (default: ``None``)
+    - ``prefix1`` -- string (default: ``None``)
+    - ``print_tuple`` -- boolean (default: ``False``)
+    - ``category`` -- a category (default: ``Groups()``)
 
     A semidirect product of groups `G` and `H` is a group structure on
     the Cartesian product `G \times H` whose product agrees with that
@@ -215,7 +215,7 @@ class GroupSemidirectProduct(CartesianProduct):
         sage: G = GL(2,QQ)
         sage: V = QQ^2
         sage: EV = GroupExp()(V)  # make a multiplicative version of V
-        sage: def twist(g,v):
+        sage: def twist(g, v):
         ....:     return EV(g*v.value)
         sage: H = GroupSemidirectProduct(G, EV, twist=twist, prefix1='t'); H
         Semidirect product of General Linear Group of degree 2
@@ -228,8 +228,8 @@ class GroupSemidirectProduct(CartesianProduct):
 
         sage: # needs sage.rings.number_field
         sage: cartan_type = CartanType(['A',2])
-        sage: W = WeylGroup(cartan_type, prefix="s")
-        sage: def twist(w,v):
+        sage: W = WeylGroup(cartan_type, prefix='s')
+        sage: def twist(w, v):
         ....:     return w*v*(~w)
         sage: WW = GroupSemidirectProduct(W, W, twist=twist, print_tuple=True)
         sage: s = Family(cartan_type.index_set(), lambda i: W.simple_reflection(i))
@@ -252,12 +252,12 @@ class GroupSemidirectProduct(CartesianProduct):
 
         EXAMPLES::
 
-            sage: def twist(x,y):
+            sage: def twist(x, y):
             ....:     return y
             sage: import __main__
             sage: __main__.twist = twist
-            sage: G = GroupSemidirectProduct(WeylGroup(['A',2],prefix="s"),
-            ....:                            WeylGroup(['A',3],prefix="t"), twist)
+            sage: G = GroupSemidirectProduct(WeylGroup(['A',2],prefix='s'),
+            ....:                            WeylGroup(['A',3],prefix='t'), twist)
             sage: TestSuite(G).run()
 
         The ``__main__`` business is a trick to pass the pickling test.
@@ -297,10 +297,10 @@ class GroupSemidirectProduct(CartesianProduct):
 
         EXAMPLES::
 
-            sage: def twist(x,y):
+            sage: def twist(x, y):
             ....:     return y
-            sage: GroupSemidirectProduct(WeylGroup(['A',2],prefix="s"),
-            ....:                        WeylGroup(['A',3],prefix="t"), twist).act_to_right()
+            sage: GroupSemidirectProduct(WeylGroup(['A',2],prefix='s'),
+            ....:                        WeylGroup(['A',3],prefix='t'), twist).act_to_right()
             True
         """
         return self._act_to_right
@@ -311,10 +311,10 @@ class GroupSemidirectProduct(CartesianProduct):
 
         EXAMPLES::
 
-            sage: def twist(x,y):
+            sage: def twist(x, y):
             ....:     return y
-            sage: GroupSemidirectProduct(WeylGroup(['A',2],prefix="s"),         # indirect doctest
-            ....:                        WeylGroup(['A',3],prefix="t"), twist)
+            sage: GroupSemidirectProduct(WeylGroup(['A',2],prefix='s'),         # indirect doctest
+            ....:                        WeylGroup(['A',3],prefix='t'), twist)
             Semidirect product of Weyl Group of type ['A', 2] (as a matrix
             group acting on the ambient space) acting on Weyl Group
             of type ['A', 3] (as a matrix group acting on the ambient space)
@@ -332,12 +332,12 @@ class GroupSemidirectProduct(CartesianProduct):
         r"""
         EXAMPLES::
 
-            sage: def twist(x,y):
+            sage: def twist(x, y):
             ....:     return y
             sage: import __main__
             sage: __main__.twist = twist
-            sage: g = GroupSemidirectProduct(WeylGroup(['A',2],prefix="s"),
-            ....:                            WeylGroup(['A',3],prefix="t"), twist).an_element()
+            sage: g = GroupSemidirectProduct(WeylGroup(['A',2],prefix='s'),
+            ....:                            WeylGroup(['A',3],prefix='t'), twist).an_element()
             sage: TestSuite(g).run()
         """
         def type_error():
@@ -368,7 +368,7 @@ class GroupSemidirectProduct(CartesianProduct):
             sage: G = GL(2,QQ)
             sage: V = QQ^2
             sage: EV = GroupExp()(V)  # make a multiplicative version of V
-            sage: def twist(g,v):
+            sage: def twist(g, v):
             ....:     return EV(g*v.value)
             sage: one = GroupSemidirectProduct(G, EV, twist=twist, prefix1='t').one(); one
             1
@@ -418,7 +418,7 @@ class GroupSemidirectProduct(CartesianProduct):
             sage: G = GL(2,QQ)
             sage: V = QQ^2
             sage: EV = GroupExp()(V)  # make a multiplicative version of V
-            sage: def twist(g,v):
+            sage: def twist(g, v):
             ....:     return EV(g*v.value)
             sage: S = GroupSemidirectProduct(G, EV, twist=twist, prefix1='t')
             sage: g = G([[2,1],[3,1]]); g
@@ -491,10 +491,10 @@ class GroupSemidirectProduct(CartesianProduct):
 
         EXAMPLES::
 
-            sage: def twist(x,y):
+            sage: def twist(x, y):
             ....:     return y
-            sage: H = GroupSemidirectProduct(WeylGroup(['A',2],prefix="s"),
-            ....:                            WeylGroup(['A',3],prefix="t"), twist)
+            sage: H = GroupSemidirectProduct(WeylGroup(['A',2],prefix='s'),
+            ....:                            WeylGroup(['A',3],prefix='t'), twist)
             sage: H.construction()
         """
         return None
