@@ -14,7 +14,7 @@ EXAMPLES::
 AUTHORS:
 
 - Simon Brandhorst (2018-02-08): initial version
-- Sebastian Oehms  (2018-11-15): have this functionality work for permutation groups (:trac:`26750`)
+- Sebastian Oehms  (2018-11-15): have this functionality work for permutation groups (:issue:`26750`)
   and implement :meth:`section` and :meth:`natural_map`
 """
 
@@ -46,9 +46,10 @@ class GroupMorphism_libgap(Morphism):
     INPUT:
 
     - ``homset`` -- the parent
-    - ``gap_hom`` -- a :class:`sage.libs.gap.element.GapElement` consisting of a group homomorphism
-    - ``check`` -- (default: ``True``) check if the ``gap_hom`` is a group
-      homomorphism; this can be expensive
+    - ``gap_hom`` -- a :class:`sage.libs.gap.element.GapElement` consisting of
+      a group homomorphism
+    - ``check`` -- boolean (default: ``True``); check if the ``gap_hom`` is a group
+      homomorphism (this can be expensive)
 
     EXAMPLES::
 
@@ -108,13 +109,13 @@ class GroupMorphism_libgap(Morphism):
         [1 0]
         [1 1]
         sage: F = GF(7); MS = MatrixSpace(F,2,2)
-        sage: F.multiplicative_generator()
+        sage: F.multiplicative_generator()                                              # needs sage.libs.pari
         3
         sage: G = MatrixGroup([MS([3,0,0,1])])
         sage: a = G.gens()[0]^2
         sage: phi = G.hom([a])
 
-    Check that :trac:`19406` is fixed::
+    Check that :issue:`19406` is fixed::
 
         sage: G = GL(2, GF(3))
         sage: H = GL(3, GF(2))
@@ -136,7 +137,7 @@ class GroupMorphism_libgap(Morphism):
         <class 'sage.libs.gap.element.GapElement'>
 
         sage: F = GF(7); MS = MatrixSpace(F,2,2)
-        sage: F.multiplicative_generator()
+        sage: F.multiplicative_generator()                                              # needs sage.libs.pari
         3
         sage: G = MatrixGroup([MS([3,0,0,1])])
         sage: a = G.gens()[0]^2
@@ -151,7 +152,7 @@ class GroupMorphism_libgap(Morphism):
         )
 
         sage: F = GF(7); MS = MatrixSpace(F,2,2)
-        sage: F.multiplicative_generator()
+        sage: F.multiplicative_generator()                                              # needs sage.libs.pari
         3
         sage: G = MatrixGroup([MS([3,0,0,1])])
         sage: a = G.gens()[0]^2
@@ -172,7 +173,7 @@ class GroupMorphism_libgap(Morphism):
         [0 1]
         )
 
-    The following tests against :trac:`10659`::
+    The following tests against :issue:`10659`::
 
         sage: phi(H)   # indirect doctest
         Subgroup with 1 generators (
@@ -204,7 +205,7 @@ class GroupMorphism_libgap(Morphism):
         [1 1]
         [0 1]
 
-    We check that :trac:`19780` is fixed::
+    We check that :issue:`19780` is fixed::
 
         sage: G = groups.matrix.SO(3, 3)
         sage: H = groups.matrix.GL(3, 3)
@@ -212,6 +213,7 @@ class GroupMorphism_libgap(Morphism):
         sage: phi(G.one()).parent()
         General Linear Group of degree 3 over Finite Field of size 3
 
+        sage: # needs sage.symbolic
         sage: MS = MatrixSpace(SR, 2, 2)
         sage: G = MatrixGroup([MS(1), MS([1,2,3,4])])
         sage: G.Hom(G)
@@ -244,7 +246,7 @@ class GroupMorphism_libgap(Morphism):
         From: General Orthogonal Group of degree 2 and form parameter 1 over Finite Field of size 2
         To:   Abelian group with gap, generator orders (2,)
 
-    Check that :trac:`19407` is fixed::
+    Check that :issue:`19407` is fixed::
 
         sage: G = GL(2, GF(2))
         sage: H = GL(3, ZZ)
@@ -282,7 +284,7 @@ class GroupMorphism_libgap(Morphism):
 
     def __reduce__(self):
         r"""
-        Implements pickling.
+        Implement pickling.
 
         We have to work around the fact that GAP does not provide pickling.
 
@@ -377,9 +379,7 @@ class GroupMorphism_libgap(Morphism):
 
         - ``J`` -- a subgroup or an element of the domain of ``self``
 
-        OUTPUT:
-
-        The image of ``J`` under ``self``.
+        OUTPUT: the image of ``J`` under ``self``
 
         .. NOTE::
 
@@ -400,12 +400,15 @@ class GroupMorphism_libgap(Morphism):
             a
             sage: x.parent()
             Finitely presented group < a, b | a, b^3 >
+
+            sage: # needs sage.rings.finite_rings
             sage: G = GU(3,2)
             sage: P = PGU(3,2)
             sage: pr = Hom(G, P).natural_map()
             sage: GS = G.subgroup([G.gen(0)])
             sage: pr.pushforward(GS)
-            Subgroup generated by [(3,4,5)(10,18,14)(11,19,15)(12,20,16)(13,21,17)] of (The projective general unitary group of degree 3 over Finite Field of size 2)
+            Subgroup generated by [(3,4,5)(10,18,14)(11,19,15)(12,20,16)(13,21,17)] of
+            (The projective general unitary group of degree 3 over Finite Field of size 2)
         """
         dom = self.domain()
         codom = self.codomain()
@@ -441,7 +444,7 @@ class GroupMorphism_libgap(Morphism):
 
         TESTS:
 
-        The following tests we do fall back behind :trac:`10659`::
+        The following tests we do fall back behind :issue:`10659`::
 
             sage: O = WeylGroup(['D',6])
             sage: r = prod(O.gens())
@@ -546,24 +549,24 @@ class GroupMorphism_libgap(Morphism):
         phi = self.gap()
         from sage.groups.perm_gps.permgroup import PermutationGroup_generic
         if not isinstance(S, (ParentLibGAP, PermutationGroup_generic)):
-            raise TypeError("%s must be a GAP or permutation group of %s"%(S, self))
+            raise TypeError("%s must be a GAP or permutation group of %s" % (S, self))
         if not self.codomain().gap().IsSubgroup(S.gap()).sage():
-            raise ValueError("%s must be a subgroup of %s"%(S, self))
+            raise ValueError("%s must be a subgroup of %s" % (S, self))
         preimage = phi.PreImage(S.gap())
         return self.domain()._subgroup_constructor(preimage)
 
     def section(self):
         r"""
-        This method returns a section map of self by use of :meth:`lift`.
+        Return a section map of ``self`` by use of :meth:`lift`.
+
         See :meth:`section` of :class:`sage.categories.map.Map`, as well.
 
-        OUTPUT:
-
-        an instance of :class:`sage.categories.morphism.SetMorphism`
-        mapping an element of the codomain of self to one of its preimages
+        OUTPUT: an instance of :class:`sage.categories.morphism.SetMorphism`
+        mapping an element of the codomain of ``self`` to one of its preimages
 
         EXAMPLES::
 
+            sage: # needs sage.rings.finite_rings
             sage: G = GU(3,2)
             sage: P = PGU(3,2)
             sage: pr = Hom(G, P).natural_map()
@@ -591,9 +594,7 @@ class GroupHomset_libgap(HomsetWithBase):
     - ``H`` -- a libgap group
     - ``category`` -- a category
 
-    OUTPUT:
-
-    The homset of two libgap groups.
+    OUTPUT: the homset of two libgap groups
 
     EXAMPLES::
 
@@ -644,6 +645,7 @@ class GroupHomset_libgap(HomsetWithBase):
 
         A group homomorphism between a finitely presented group and a subgroup of a permutation group::
 
+            sage: # needs sage.rings.finite_rings
             sage: PG = PGU(6,2)
             sage: g, h = PG.gens()
             sage: p1 = h^-3*(h^-1*g^-1)^2*h*g*h^2*g^-1*h^2*g*h^-5*g^-1
@@ -724,9 +726,10 @@ class GroupHomset_libgap(HomsetWithBase):
 
         OUTPUT:
 
-        an instance of the element class of self if there exists a group homomorphism
-        mapping the generators of the domain of self to the according generators of
-        the codomain. Else the method falls back to the default.
+        An instance of the element class of ``self`` if there exists a group
+        homomorphism mapping the generators of the domain of ``self`` to the
+        according generators of the codomain. Otherwise, the method falls back
+        to the default.
 
         EXAMPLES::
 
