@@ -444,7 +444,7 @@ class HomologyVectorSpaceWithBasis(CombinatorialFreeModule):
         tester = self._tester(**options)
         dual = self.dual()
         dims = [a[0] for a in self._indices]
-        for dim in range(max(max(dims), tester._max_runs) + 1):
+        for dim in range(max(*dims, tester._max_runs) + 1):
             n = len(self.basis(dim))
             m = matrix(n, n, [a.eval(b) for a in self.basis(dim) for b in dual.basis(dim)])
             tester.assertEqual(m, 1, f"error in dimension {dim}")
@@ -1253,7 +1253,7 @@ class CohomologyRing_mod2(CohomologyRing):
             ret = CombinatorialFreeModule.Element._acted_upon_(self, a, self_on_left)
             if ret is not None:  # did the scalar action
                 return ret
-            if self_on_left: # i.e., module element on left
+            if self_on_left:  # i.e., module element on left
                 a = a.antipode()
             b = a.change_basis('adem')
             ans = self.parent().zero()
@@ -1283,7 +1283,7 @@ class CohomologyRing_mod2(CohomologyRing):
           the action as a left module action or a right module
 
         We will write this with respect to the left action;
-        for the right action, just switch all of the the tensors.
+        for the right action, just switch all of the tensors.
         Writing `m` for ``deg_domain`` and `n` for ``deg_codomain``, this
         returns `A^{n-m} \otimes H^{m} \to H^{n}`, one single
         component of the map making `H` into an `A`-module.
@@ -1434,6 +1434,7 @@ def sum_indices(k, i_k_plus_one, S_k_plus_one):
     return [[i_k] + l for i_k in range(S_k, i_k_plus_one)
             for l in sum_indices(k-1, i_k, S_k)]
 
+
 def is_GF2(R):
     r"""
     Return ``True`` iff ``R`` is isomorphic to the field `\GF{2}`.
