@@ -237,17 +237,21 @@ Test that conversion of symbolic functions with latex names works (:issue:`31047
 
 import os
 
-from sage.interfaces.expect import Expect, ExpectElement, ExpectFunction, FunctionElement, gc_disabled
-
 import pexpect
 
 from sage.cpython.string import bytes_to_str
 from sage.env import DOT_SAGE
-from sage.misc.pager import pager
+from sage.interfaces.expect import (
+    Expect,
+    ExpectElement,
+    ExpectFunction,
+    FunctionElement,
+    gc_disabled,
+)
 from sage.misc.instancedoc import instancedoc
+from sage.misc.pager import pager
 from sage.structure.richcmp import rich_to_bool
 
-
 COMMANDS_CACHE = '%s/giac_commandlist_cache.sobj' % DOT_SAGE
 
 
@@ -326,6 +330,7 @@ class Giac(Expect):
 
         EXAMPLES::
 
+            sage: from sage.interfaces.giac import giac
             sage: giac == loads(dumps(giac))
             True
         """
@@ -359,7 +364,7 @@ class Giac(Expect):
 
     def _keyboard_interrupt(self):
         """
-        The pexepect interface for giac has a very poor support of keyboard interruptions.
+        The pexpect interface for giac has a very poor support of keyboard interruptions.
         """
         print("Interrupting %s..." % self)
         self._expect.sendline(chr(3))  # send ctrl-c
@@ -1115,8 +1120,11 @@ class GiacElement(ExpectElement):
             sage: giac(e * i * pi).sage().variables()
             ()
         """
+        from sage.calculus.calculus import (
+            SR_parser_giac,
+            symbolic_expression_from_string,
+        )
         from sage.symbolic.expression import symbol_table
-        from sage.calculus.calculus import symbolic_expression_from_string, SR_parser_giac
 
         if locals is None:
             locals = {}
