@@ -42,12 +42,14 @@ REFERENCES:
 #                  http://www.gnu.org/licenses/
 #******************************************************************************
 
-from sage.manifolds.manifold_homset import TopologicalManifoldHomset
-from sage.manifolds.differentiable.diff_map import DiffMap
 from sage.manifolds.differentiable.curve import DifferentiableCurve
-from sage.manifolds.differentiable.integrated_curve import IntegratedCurve
-from sage.manifolds.differentiable.integrated_curve import IntegratedAutoparallelCurve
-from sage.manifolds.differentiable.integrated_curve import IntegratedGeodesic
+from sage.manifolds.differentiable.diff_map import DiffMap
+from sage.manifolds.differentiable.integrated_curve import (
+    IntegratedAutoparallelCurve,
+    IntegratedCurve,
+    IntegratedGeodesic,
+)
+from sage.manifolds.manifold_homset import TopologicalManifoldHomset
 
 
 class DifferentiableManifoldHomset(TopologicalManifoldHomset):
@@ -180,8 +182,7 @@ class DifferentiableManifoldHomset(TopologicalManifoldHomset):
              manifolds over Real Field with 53 bits of precision
             sage: TestSuite(E).run()
         """
-        from sage.manifolds.differentiable.manifold import \
-                                                         DifferentiableManifold
+        from sage.manifolds.differentiable.manifold import DifferentiableManifold
         if not isinstance(domain, DifferentiableManifold):
             raise TypeError("domain = {} is not an ".format(domain) +
                             "instance of DifferentiableManifold")
@@ -891,9 +892,10 @@ class IntegratedCurveSet(DifferentiableCurveSet):
         # chart used on the codomain.
         if dom == codom:
             param = var('s')
-            if t == param: # the canonical coordinate of the domain
-            # might be the expression 's' even though it was affected
-            # above to the variable 't'
+            if t == param:
+                # the canonical coordinate of the domain
+                # might be the expression 's' even though it was affected
+                # above to the variable 't'
                 param = var('u')
         else:
             param = t
@@ -902,8 +904,8 @@ class IntegratedCurveSet(DifferentiableCurveSet):
         # where a certain integrated curve may be defined:
         H = Hom(dom, codom)
         c = H.an_element()
-        x0_A = c.expr()[0].substitute({t:1})
-        x0_B = c.expr()[0].substitute({t:0}) # necessarily, x0_A < x0_B
+        x0_A = c.expr()[0].substitute({t: 1})
+        x0_B = c.expr()[0].substitute({t: 0})  # necessarily, x0_A < x0_B
         p_coords = [x0_A] + list(c.expr()[1:dim])
         p = codom.point(p_coords)
 
@@ -1305,11 +1307,11 @@ class IntegratedAutoparallelCurveSet(IntegratedCurveSet):
             (1.0565635217644918,)
         """
 
+        from sage.categories.homset import Hom
+        from sage.functions.log import exp
         from sage.rings.infinity import Infinity
         from sage.rings.rational_field import QQ
-        from sage.categories.homset import Hom
         from sage.symbolic.ring import var
-        from sage.functions.log import exp
 
         dom = self.domain()
         t = dom.canonical_coordinate()
@@ -1754,8 +1756,8 @@ class IntegratedGeodesicSet(IntegratedAutoparallelCurveSet):
         """
 
         from sage.categories.homset import Hom
-        from sage.symbolic.ring import var
         from sage.functions.log import exp
+        from sage.symbolic.ring import var
 
         dom = self.domain()
         t = dom.canonical_coordinate()
