@@ -17,9 +17,9 @@ def p_saturation(A, p, proof=True):
     """
     INPUT:
 
-    - A -- a matrix over ZZ
-    - p -- a prime
-    - proof -- bool (default: ``True``)
+    - ``A`` -- a matrix over ZZ
+    - ``p`` -- a prime
+    - ``proof`` -- boolean (default: ``True``)
 
     OUTPUT:
 
@@ -68,16 +68,15 @@ def p_saturation(A, p, proof=True):
         H = H.stack(C).hermite_form(include_zero_rows=False, proof=proof)
     verbose("done saturating", tm)
 
+
 def random_sublist_of_size(k, n):
     """
     INPUT:
 
-    - k -- an integer
-    - n -- an integer
+    - ``k`` -- integer
+    - ``n`` -- integer
 
-    OUTPUT:
-
-    a randomly chosen sublist of range(k) of size n.
+    OUTPUT: a randomly chosen sublist of ``range(k)`` of size `n`
 
     EXAMPLES::
 
@@ -119,17 +118,15 @@ def random_sublist_of_size(k, n):
 
 def solve_system_with_difficult_last_row(B, A):
     """
-    Solve the matrix equation B*Z = A when the last row of `B`
+    Solve the matrix equation ``B*Z = A`` when the last row of `B`
     contains huge entries.
 
     INPUT:
 
-    - B -- a square n x n nonsingular matrix with painful big bottom row.
-    - A -- an n x k matrix.
+    - ``B`` -- a square n x n nonsingular matrix with painful big bottom row
+    - ``A`` -- an n x k matrix
 
-    OUTPUT:
-
-    the unique solution to B*Z = A.
+    OUTPUT: the unique solution to ``B*Z = As``
 
     EXAMPLES::
 
@@ -185,22 +182,21 @@ def solve_system_with_difficult_last_row(B, A):
     verbose("Done getting linear combinations.", tm)
     return X
 
+
 def saturation(A, proof=True, p=0, max_dets=5):
-    """
-    Compute a saturation matrix of A.
+    r"""
+    Compute a saturation matrix of `A`.
 
     INPUT:
 
-    - A     -- a matrix over ZZ
-    - proof -- bool (default: ``True``)
-    - p     -- int (default: 0); if not 0 only guarantees that output is
-      p-saturated
-    - max_dets -- int (default: 4) max number of dets of submatrices to
-      compute.
+    - ``A`` -- a matrix over `\ZZ`
+    - ``proof`` -- boolean (default: ``True``)
+    - ``p`` -- integer (default: 0); if not 0 only guarantees that output is
+      `p`-saturated
+    - ``max_dets`` -- integer (default: 4); max number of dets of submatrices to
+      compute
 
-    OUTPUT:
-
-    matrix -- saturation of the matrix A.
+    OUTPUT: matrix; saturation of the matrix `A`
 
     EXAMPLES::
 
@@ -289,6 +285,7 @@ def saturation(A, proof=True, p=0, max_dets=5):
     C = solve_system_with_difficult_last_row(B, A)
     return C.change_ring(ZZ)._insert_zero_columns(zero_cols)
 
+
 def index_in_saturation(A, proof=True):
     r"""
     The index of A in its saturation.
@@ -299,9 +296,7 @@ def index_in_saturation(A, proof=True):
 
     - ``proof`` -- boolean (``True`` or ``False``)
 
-    OUTPUT:
-
-    An integer
+    OUTPUT: integer
 
     EXAMPLES::
 
