@@ -48,11 +48,9 @@ def setprint(X):
 
     INPUT:
 
-    - ``X`` -- Any Python object
+    - ``X`` -- any Python object
 
-    OUTPUT:
-
-    ``None``. However, the function prints a nice representation of ``X``.
+    OUTPUT: none; however, the function prints a nice representation of ``X``
 
     EXAMPLES:
 
@@ -93,8 +91,8 @@ def setprint_s(X, toplevel=False):
     INPUT:
 
     - ``X`` -- any Python object
-    - ``toplevel`` -- (default: ``False``) indicates whether this is a
-      recursion or not.
+    - ``toplevel`` -- boolean (default: ``False``); indicates whether this is a
+      recursion or not
 
     OUTPUT:
 
@@ -139,11 +137,9 @@ def newlabel(groundset):
 
     INPUT:
 
-    - ``groundset`` -- A set of objects.
+    - ``groundset`` -- set of objects
 
-    OUTPUT:
-
-    A string not in the set ``groundset``.
+    OUTPUT: string not in the set ``groundset``
 
     For direct access to ``newlabel``, run::
 
@@ -188,13 +184,11 @@ def sanitize_contractions_deletions(matroid, contractions, deletions):
     INPUT:
 
     - ``matroid`` -- a :class:`Matroid <sage.matroids.matroid.Matroid>`
-      instance.
-    - ``contractions`` -- a subset of the groundset.
-    - ``deletions`` -- a subset of the groundset.
+      instance
+    - ``contractions`` -- a subset of the groundset
+    - ``deletions`` -- a subset of the groundset
 
-    OUTPUT:
-
-    An independent set ``C`` and a coindependent set ``D`` such that
+    OUTPUT: an independent set ``C`` and a coindependent set ``D`` such that
 
         ``matroid / contractions \ deletions == matroid / C \ D``
 
@@ -251,7 +245,7 @@ def make_regular_matroid_from_matroid(matroid):
 
     INPUT:
 
-    - ``matroid`` -- a matroid.
+    - ``matroid`` -- matroid
 
     OUTPUT:
 
@@ -328,7 +322,7 @@ def get_nonisomorphic_matroids(MSet):
 
     INPUT:
 
-    - ``MSet`` -- an iterable whose members are matroids.
+    - ``MSet`` -- an iterable whose members are matroids
 
     OUTPUT:
 
@@ -364,12 +358,13 @@ def spanning_forest(M):
     INPUT:
 
     - ``M`` -- a matrix defining a bipartite graph G. The vertices are the
-      rows and columns, if `M[i,j]` is non-zero, then there is an edge
+      rows and columns, if `M[i,j]` is nonzero, then there is an edge
       between row `i` and column `j`.
 
     OUTPUT:
 
-    A list of tuples `(r_i,c_i)` representing edges between row `r_i` and column `c_i`.
+    A list of tuples `(r_i,c_i)` representing edges between row `r_i` and
+    column `c_i`.
 
     EXAMPLES::
 
@@ -408,12 +403,13 @@ def spanning_stars(M):
     INPUT:
 
     - ``M`` -- a matrix defining a bipartite graph G. The vertices are the
-      rows and columns, if `M[i,j]` is non-zero, then there is an edge
+      rows and columns, if `M[i,j]` is nonzero, then there is an edge
       between row i and column 0.
 
     OUTPUT:
 
-    A list of tuples `(row,column)` in a spanning forest of the bipartite graph defined by ``M``
+    A list of tuples `(row,column)` in a spanning forest of the bipartite graph
+    defined by ``M``.
 
     EXAMPLES::
 
@@ -433,7 +429,7 @@ def spanning_stars(M):
     # remove low degree vertices
     H = []
     # candidate vertices
-    V_0 = set([])
+    V_0 = set()
     d = 0
     while G.order():
         x, d = min(G.degree_iterator(labels=True), key=itemgetter(1))
@@ -448,7 +444,7 @@ def spanning_stars(M):
     # greedily remove vertices
     G2 = G.copy()
     # set of picked vertices
-    V_1 = set([])
+    V_1 = set()
     while G2.order():
         # choose vertex with maximum degree in G2
         x, d = max(G2.degree_iterator(labels=True), key=itemgetter(1))
@@ -492,13 +488,12 @@ def lift_cross_ratios(A, lift_map=None):
 
     INPUT:
 
-    - ``A`` -- a matrix over a ring ``source_ring``.
-    - ``lift_map`` -- a Python dictionary, mapping each cross ratio of ``A`` to some element
-      of a target ring, and such that ``lift_map[source_ring(1)] = target_ring(1)``.
+    - ``A`` -- a matrix over a ring ``source_ring``
+    - ``lift_map`` -- a Python dictionary, mapping each cross ratio of ``A`` to
+      some element of a target ring, and such that
+      ``lift_map[source_ring(1)] = target_ring(1)``
 
-    OUTPUT:
-
-    - ``Z`` -- a matrix over the ring ``target_ring``.
+    OUTPUT: ``Z`` -- a matrix over the ring ``target_ring``
 
     The intended use of this method is to create a (reduced) matrix representation of a
     matroid ``M`` over a ring ``target_ring``, given a (reduced) matrix representation of
@@ -670,11 +665,9 @@ def lift_map(target):
 
     INPUT:
 
-    - ``target`` -- a string describing the target (partial) field.
+    - ``target`` -- string describing the target (partial) field
 
-    OUTPUT:
-
-    - a dictionary
+    OUTPUT: dictionary
 
     Depending on the value of ``target``, the following lift maps will be created:
 
@@ -750,11 +743,11 @@ def split_vertex(G, u, v=None, edges=None):
 
     INPUT:
 
-    - ``G`` -- A SageMath :class:`Graph`.
-    - ``u`` -- A vertex in ``G``.
-    - ``v`` -- (optional) The name of the new vertex after the splitting. If
+    - ``G`` -- a SageMath :class:`Graph`
+    - ``u`` -- a vertex in ``G``
+    - ``v`` -- (optional) the name of the new vertex after the splitting. If
       ``v`` is specified and already in the graph, it must be an isolated vertex.
-    - ``edges`` -- (optional) An iterable container of edges on ``u`` that
+    - ``edges`` -- (optional) iterable container of edges on ``u`` that
       move to ``v`` after the splitting. If ``None``, ``v`` will be an isolated
       vertex. The edge labels must be specified.
 
@@ -799,7 +792,6 @@ def split_vertex(G, u, v=None, edges=None):
         G.delete_edge(e)
 
     # This modifies the graph without needing to return anything
-    return
 
 
 def cmp_elements_key(x):
