@@ -17,9 +17,10 @@ AUTHORS:
 import os
 import re
 import sys
-
 from collections import defaultdict
 
+from sage.misc.sageinspect import find_object_modules
+
 
 def runsnake(command):
     """
@@ -33,6 +34,7 @@ def runsnake(command):
 
         sage: from sage.misc.dev_tools import runsnake
         sage: runsnake("list(SymmetricGroup(3))")        # optional - runsnake
+        ...
 
     ``command`` is first preparsed (see :func:`preparse`)::
 
@@ -65,6 +67,10 @@ def runsnake(command):
     from sage.misc.temporary_file import tmp_filename
     from sage.misc.misc import get_main_globals
     from sage.repl.preparse import preparse
+    from sage.misc.superseded import deprecation
+
+    deprecation(39274, "just use the runsnake program directly")
+
     tmpfile = tmp_filename()
     cProfile.runctx(preparse(command.lstrip().rstrip()), get_main_globals(),
                     locals(), filename=tmpfile)
@@ -171,7 +177,7 @@ def load_submodules(module=None, exclude_pattern=None):
         load sage.geometry.polyhedron.ppl_lattice_polygon... succeeded
     """
     from .package_dir import walk_packages
-    import importlib.util
+    import importlib
 
     if module is None:
         import sage
@@ -195,12 +201,8 @@ def load_submodules(module=None, exclude_pattern=None):
         try:
             sys.stdout.write("load %s..." % module_name)
             sys.stdout.flush()
-            # see
-            # https://docs.python.org/3/library/importlib.html#importing-a-source-file-directly
-            spec = importer.find_spec(module_name)
-            module = importlib.util.module_from_spec(spec)
-            sys.modules[module_name] = module
-            spec.loader.exec_module(module)
+            module = importlib.import_module(module_name)
+            assert sys.modules[module_name] is module
             sys.stdout.write(" succeeded\n")
         except (ValueError, AttributeError, TypeError, ImportError):
             # we might get error because of cython code that has been
@@ -285,82 +287,6 @@ def find_objects_from_name(name, module_name=None, include_lazy_imports=False):
     return obj
 
 
-def find_object_modules(obj):
-    r"""
-    Return a dictionary whose keys are the names of the modules where ``obj``
-    appear and the value at a given module name is the list of names that
-    ``obj`` have in that module.
-
-    It is very unlikely that the output dictionary has several keys except when
-    ``obj`` is an instance of a class.
-
-    EXAMPLES::
-
-        sage: from sage.misc.dev_tools import find_object_modules
-        sage: find_object_modules(RR)                                                   # needs sage.rings.real_mpfr
-        {'sage.rings.real_mpfr': ['RR']}
-        sage: find_object_modules(ZZ)
-        {'sage.rings.integer_ring': ['Z', 'ZZ']}
-
-    .. NOTE::
-
-        It might be a good idea to move this function in
-        :mod:`sage.misc.sageinspect`.
-    """
-    from sage.misc import sageinspect
-
-    # see if the object is defined in its own module
-    # might be wrong for class instances as the instantiation might appear
-    # outside of the module !!
-    module_name = None
-    if sageinspect.isclassinstance(obj):
-        module_name = obj.__class__.__module__
-    elif hasattr(obj, '__module__') and obj.__module__:
-        module_name = obj.__module__
-
-    if module_name:
-        if module_name not in sys.modules:
-            raise ValueError("this should never happen")
-        d = sys.modules[module_name].__dict__
-        matching = sorted(key for key in d if d[key] is obj)
-        if matching:
-            return {module_name: matching}
-
-    # otherwise, we parse all (already loaded) modules and hope to find
-    # something
-    module_to_obj = {}
-    for module_name, module in sys.modules.items():
-        if module_name != '__main__' and hasattr(module, '__dict__'):
-            d = module.__dict__
-            names = [key for key in d if d[key] is obj]
-            if names:
-                module_to_obj[module_name] = names
-
-    # if the object is an instance, we try to guess where it is defined
-    if sageinspect.isclassinstance(obj):
-        dec_pattern = re.compile(r"^(\w[\w0-9\_]*)\s*=", re.MULTILINE)
-        module_to_obj2 = {}
-        for module_name, obj_names in module_to_obj.items():
-            module_to_obj2[module_name] = []
-            try:
-                src = sageinspect.sage_getsource(sys.modules[module_name])
-            except TypeError:
-                pass
-            else:
-                m = dec_pattern.search(src)
-                while m:
-                    if m.group(1) in obj_names:
-                        module_to_obj2[module_name].append(m.group(1))
-                    m = dec_pattern.search(src, m.end())
-            if not module_to_obj2[module_name]:
-                del module_to_obj2[module_name]
-
-        if module_to_obj2:
-            return module_to_obj2
-
-    return module_to_obj
-
-
 def import_statements(*objects, **kwds):
     r"""
     Print import statements for the given objects.
