@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-objects
 r"""
 Random Numbers with Python API
 
@@ -57,6 +58,7 @@ Python Software Foundation License Version 2.
 
 from sage.misc.randstate import current_randstate
 
+
 def _pyrand():
     r"""
     A tiny private helper function to return an instance of
@@ -75,6 +77,7 @@ def _pyrand():
     """
     return current_randstate().python_random()
 
+
 def getrandbits(k):
     r"""
     getrandbits(k) -> x.  Generates a long int with k random bits.
@@ -90,6 +93,7 @@ def getrandbits(k):
     """
     return _pyrand().getrandbits(k)
 
+
 def randrange(start, stop=None, step=1):
     r"""
     Choose a random item from range(start, stop[, step]).
@@ -121,6 +125,7 @@ def randrange(start, stop=None, step=1):
     """
     return _pyrand().randrange(start, stop, step)
 
+
 def randint(a, b):
     r"""
     Return random integer in range [a, b], including both end points.
@@ -136,19 +141,21 @@ def randint(a, b):
     """
     return _pyrand().randint(a, b)
 
+
 def choice(seq):
     r"""
     Choose a random element from a non-empty sequence.
 
     EXAMPLES::
 
-        sage: s = [choice(list(primes(10, 100))) for i in range(5)]; s  # random        # optional - sage.libs.pari
+        sage: s = [choice(list(primes(10, 100))) for i in range(5)]; s  # random        # needs sage.libs.pari
         [17, 47, 11, 31, 47]
-        sage: all(t in primes(10, 100) for t in s)                                      # optional - sage.libs.pari
+        sage: all(t in primes(10, 100) for t in s)                                      # needs sage.libs.pari
         True
     """
     return _pyrand().choice(seq)
 
+
 def shuffle(x):
     r"""
     x, random=random.random -> shuffle list x in place; return None.
@@ -162,6 +169,7 @@ def shuffle(x):
     """
     return _pyrand().shuffle(x)
 
+
 def sample(population, k):
     r"""
     Choose k unique random elements from a population sequence.
@@ -201,6 +209,7 @@ def sample(population, k):
     """
     return _pyrand().sample(population, k)
 
+
 def random():
     r"""
     Get the next random number in the range [0.0, 1.0).
@@ -214,6 +223,7 @@ def random():
     """
     return _pyrand().random()
 
+
 def uniform(a, b):
     r"""
     Get a random number in the range [a, b).
@@ -227,13 +237,14 @@ def uniform(a, b):
         sage: 0.0 <= s <= 1.0
         True
 
-        sage: s = uniform(e, pi); s  # random                                           # optional - sage.symbolic
+        sage: s = uniform(e, pi); s  # random                                           # needs sage.symbolic
         0.5143475134191677*pi + 0.48565248658083227*e
-        sage: bool(e <= s <= pi)                                                        # optional - sage.symbolic
+        sage: bool(e <= s <= pi)                                                        # needs sage.symbolic
         True
     """
     return _pyrand().uniform(a, b)
 
+
 def betavariate(alpha, beta):
     r"""
     Beta distribution.
@@ -255,6 +266,7 @@ def betavariate(alpha, beta):
     """
     return _pyrand().betavariate(alpha, beta)
 
+
 def expovariate(lambd):
     r"""
     Exponential distribution.
@@ -282,9 +294,10 @@ def expovariate(lambd):
     """
     return _pyrand().expovariate(lambd)
 
+
 def gammavariate(alpha, beta):
     r"""
-    Gamma distribution.  Not the gamma function!
+    Gamma distribution.  (Not the gamma function.)
 
     Conditions on the parameters are alpha > 0 and beta > 0.
 
@@ -301,6 +314,7 @@ def gammavariate(alpha, beta):
     """
     return _pyrand().gammavariate(alpha, beta)
 
+
 def gauss(mu, sigma):
     r"""
     Gaussian distribution.
@@ -320,6 +334,7 @@ def gauss(mu, sigma):
     """
     return _pyrand().gauss(mu, sigma)
 
+
 def lognormvariate(mu, sigma):
     r"""
     Log normal distribution.
@@ -335,6 +350,7 @@ def lognormvariate(mu, sigma):
     """
     return _pyrand().lognormvariate(mu, sigma)
 
+
 def normalvariate(mu, sigma):
     r"""
     Normal distribution.
@@ -352,6 +368,7 @@ def normalvariate(mu, sigma):
     """
     return _pyrand().normalvariate(mu, sigma)
 
+
 def vonmisesvariate(mu, kappa):
     r"""
     Circular data distribution.
@@ -370,6 +387,7 @@ def vonmisesvariate(mu, kappa):
     """
     return _pyrand().vonmisesvariate(mu, kappa)
 
+
 def paretovariate(alpha):
     r"""
     Pareto distribution.  alpha is the shape parameter.
@@ -383,6 +401,7 @@ def paretovariate(alpha):
     """
     return _pyrand().paretovariate(alpha)
 
+
 def weibullvariate(alpha, beta):
     r"""
     Weibull distribution.
