@@ -102,7 +102,7 @@ class DrinfeldModularForms(Parent, UniqueRepresentation):
 
       If this parameter is a single character, for example ``f``, and a
       rank is specified, then the names will be of the form
-      ``f1, f2, ..., fr``. Finally, if this parameter is a list, a tupe
+      ``f1, f2, ..., fr``. Finally, if this parameter is a list, a tuple
       or a string of comma separated characters, then each character
       will corresponds to a generator. Note that in this case, it not
       necessary to specify the rank.
@@ -152,7 +152,7 @@ class DrinfeldModularForms(Parent, UniqueRepresentation):
         1
 
     To obtain a generating set of the subspace of forms of a fixed
-    weight, use the methode :meth:`basis_of_weight`::
+    weight, use the method :meth:`basis_of_weight`::
 
         sage: M = DrinfeldModularForms(K, 2)
         sage: M.basis_of_weight(q^3 - 1)
