@@ -205,12 +205,10 @@ class AnalyticTypeElement(LatticePosetElement):
 
         INPUT:
 
-        - ``reduce_type``  -- an analytic type or something which is
+        - ``reduce_type`` -- an analytic type or something which is
           convertible to an analytic type
 
-        OUTPUT:
-
-        The new reduced analytic type.
+        OUTPUT: the new reduced analytic type
 
         EXAMPLES::
 
@@ -235,12 +233,10 @@ class AnalyticTypeElement(LatticePosetElement):
 
         INPUT:
 
-        - ``extend_type``  -- an analytic type or something which is
+        - ``extend_type`` -- an analytic type or something which is
           convertible to an analytic type
 
-        OUTPUT:
-
-        The new extended analytic type.
+        OUTPUT: the new extended analytic type
 
         EXAMPLES::
 
@@ -293,16 +289,16 @@ class AnalyticType(FiniteLatticePoset):
 
     The basic ``analytic properties`` are:
 
-    - ``quasi`` -- Whether the element is quasi modular (and not modular)
-                   or modular.
-    - ``mero``  -- ``meromorphic``: If the element is meromorphic
-                   and meromorphic at infinity.
-    - ``weak``  -- ``weakly holomorphic``: If the element is holomorphic
-                   and meromorphic at infinity.
-    - ``holo``  -- ``holomorphic``: If the element is holomorphic and
-                   holomorphic at infinity.
-    - ``cusp``  -- ``cuspidal``: If the element additionally has a positive
-                   order at infinity.
+    - ``quasi`` -- whether the element is quasi modular (and not modular)
+      or modular.
+    - ``mero`` -- ``meromorphic`` -- if the element is meromorphic
+      and meromorphic at infinity
+    - ``weak`` -- ``weakly holomorphic`` -- if the element is holomorphic
+      and meromorphic at infinity
+    - ``holo`` -- ``holomorphic`` -- if the element is holomorphic and
+      holomorphic at infinity
+    - ``cusp`` -- ``cuspidal`` -- if the element additionally has a positive
+      order at infinity
 
     The ``zero`` elements/property have no analytic properties (or only ``quasi``).
 
@@ -494,12 +490,9 @@ class AnalyticType(FiniteLatticePoset):
 
         INPUT:
 
-        - ``element``  -- Either something which coerces in the
-                          ``FiniteLatticePoset`` of ``self`` or
-                          a string or a list of strings of basic
-                          properties that should be contained in
-                          the new element.
-
+        - ``element`` -- either something which coerces in the
+          ``FiniteLatticePoset`` of ``self`` or a string or a list of strings
+          of basic properties that should be contained in the new element
 
         OUTPUT:
 
