@@ -76,7 +76,7 @@ def IntegralLattice(data, basis=None):
 
     A lattice is a finitely generated free abelian group `L \cong \ZZ^r`
     equipped with a non-degenerate, symmetric bilinear form
-    `L \times L \colon \rightarrow \ZZ`. Here, lattices have an
+    `L \times L \to \ZZ`. Here, lattices have an
     ambient quadratic space `\QQ^n` and a distinguished basis.
 
     INPUT:
@@ -93,7 +93,7 @@ def IntegralLattice(data, basis=None):
       * the string ``'U'`` or ``'H'`` -- for hyperbolic lattices
 
     - ``basis`` -- (optional) a matrix whose rows form a basis of the
-      lattice,  or a list of module elements forming a basis
+      lattice, or a list of module elements forming a basis
 
     OUTPUT:
 
@@ -304,7 +304,7 @@ def IntegralLatticeDirectSum(Lattices, return_embeddings=False):
         [ 0  0  0  0  0  0  0 -1  2 -1  0]
         [ 0  0  0  0  0  0  0  0 -1  2 -1]
         [ 0  0  0  0  0  0  0  0  0 -1  2]
-        sage: [L, phi] = IntegralLatticeDirectSum([L1, L2, L3], True)
+        sage: L, phi = IntegralLatticeDirectSum([L1, L2, L3], True)
         sage: LL3 = L.sublattice(phi[2].image().basis_matrix())
         sage: L3.discriminant() == LL3.discriminant()
         True
@@ -325,7 +325,7 @@ def IntegralLatticeDirectSum(Lattices, return_embeddings=False):
 
         sage: L1 = IntegralLattice(2 * matrix.identity(2), [[1/2, 1/2]])
         sage: L2 = IntegralLattice("A3", [[1, 1, 2]])                                   # needs sage.graphs
-        sage: [L, phi] = IntegralLatticeDirectSum([L1, L2], True)                       # needs sage.graphs
+        sage: L, phi = IntegralLatticeDirectSum([L1, L2], True)                         # needs sage.graphs
         sage: L                                                                         # needs sage.graphs
         Lattice of degree 5 and rank 2 over Integer Ring
         Basis matrix:
@@ -345,7 +345,7 @@ def IntegralLatticeDirectSum(Lattices, return_embeddings=False):
     dims = [L_i.dimension() for L_i in Lattices]
     degrees = [L_i.degree() for L_i in Lattices]
     degree_tot = sum(degrees)
-    sum_degree = [sum(degrees[:i]) for i in range(N+1)]
+    sum_degree = [sum(degrees[:i]) for i in range(N + 1)]
     inner_product_list = [copy(L_i.inner_product_matrix()) for L_i in Lattices]
     IM = matrix.block_diagonal(inner_product_list)
     ambient = FreeQuadraticModule(ZZ,
@@ -448,7 +448,7 @@ def IntegralLatticeGluing(Lattices, glue, return_embeddings=False):
         sage: g1 = L1.discriminant_group().gens()[0]
         sage: g2 = L2.discriminant_group().gens()[0]
         sage: glue = [[g1, 2 * g2]]
-        sage: [V, phi] = IntegralLatticeGluing([L1, L2], glue, True)
+        sage: V, phi = IntegralLatticeGluing([L1, L2], glue, True)
         sage: V
         Lattice of degree 8 and rank 8 over Integer Ring
         Basis matrix:
@@ -541,7 +541,7 @@ def IntegralLatticeGluing(Lattices, glue, return_embeddings=False):
         sage: D5 = IntegralLattice("D5")
         sage: gA7 = A7.discriminant_group().gens()[0]
         sage: gD5 = D5.discriminant_group().gens()[0]
-        sage: [L, phi] = IntegralLatticeGluing([A7, A7, D5, D5],
+        sage: L, phi = IntegralLatticeGluing([A7, A7, D5, D5],
         ....:                          [[gA7, gA7, gD5, 2 * gD5],
         ....:                          [gA7, 7 * gA7, 2 * gD5, gD5]], True)
         sage: L.determinant()
@@ -555,9 +555,9 @@ def IntegralLatticeGluing(Lattices, glue, return_embeddings=False):
         sage: # needs sage.graphs
         sage: L1 = IntegralLattice("D4", [[1, 1, 0, 0], [0, 1, 1, 0]])
         sage: L2 = IntegralLattice("E6", [[0, 2, 0, 0, 0, 0], [0, 0, 0, 0, 1, 1]])
-        sage: [f1, f2] = L1.discriminant_group().gens()
-        sage: [g1, g2] = L2.discriminant_group().gens()
-        sage: [L, phi] = IntegralLatticeGluing([L1, L2],
+        sage: f1, f2 = L1.discriminant_group().gens()
+        sage: g1, g2 = L2.discriminant_group().gens()
+        sage: L, phi = IntegralLatticeGluing([L1, L2],
         ....:                                  [[f1, g1], [f2, 2 * g2]], True)
         sage: phi[0]
         Free module morphism defined by the matrix
@@ -593,7 +593,7 @@ def IntegralLatticeGluing(Lattices, glue, return_embeddings=False):
         sage: B * L.gram_matrix() * B.transpose() == L1.gram_matrix()
         True
     """
-    [direct_sum, phi] = IntegralLatticeDirectSum(Lattices, return_embeddings=True)
+    direct_sum, phi = IntegralLatticeDirectSum(Lattices, return_embeddings=True)
     N = len(Lattices)
     for g in glue:
         if not len(g) == N:
@@ -733,7 +733,7 @@ class FreeQuadraticModule_integer_symmetric(FreeQuadraticModule_submodule_with_b
         return s
 
     @cached_method
-    def is_even(self):
+    def is_even(self) -> bool:
         r"""
         Return whether the diagonal entries of the Gram matrix are even.
 
@@ -1516,6 +1516,15 @@ class FreeQuadraticModule_integer_symmetric(FreeQuadraticModule_submodule_with_b
             [[(0, 0)], [], [(1, 1), (-1, -1), (0, 1), (0, -1), (1, 0), (-1, 0)]]
             sage: A2.short_vectors(3, up_to_sign_flag=True)                             # needs sage.graphs sage.libs.pari
             [[(0, 0)], [], [(1, 1), (0, 1), (1, 0)]]
+
+        TESTS:
+
+        Check that keyword arguments are passed to :meth:`sage.quadratic_forms.short_vector_list_up_to_length`
+        (:issue:`39848`)::
+
+            sage: A2 = IntegralLattice('A2')                                            # needs sage.graphs
+            sage: A2.short_vectors(3, up_to_sign_flag=False)                            # needs sage.graphs sage.libs.pari
+            [[(0, 0)], [], [(1, 1), (-1, -1), (0, 1), (0, -1), (1, 0), (-1, 0)]]
         """
         p, m = self.signature_pair()
         if p * m != 0:
@@ -1525,8 +1534,9 @@ class FreeQuadraticModule_integer_symmetric(FreeQuadraticModule_submodule_with_b
             e = -2
         from sage.quadratic_forms.quadratic_form import QuadraticForm
         q = QuadraticForm(e * self.gram_matrix())
-        short = q.short_vector_list_up_to_length(n, *kwargs)
-        return [[self(v * self.basis_matrix()) for v in L] for L in short]
+        short = q.short_vector_list_up_to_length(n, **kwargs)
+        # (matrix(L)* B ).rows() is faster than [v * B for v in L]
+        return [[self(r, check=False) for r in matrix(L) * self.basis_matrix()] if L else [] for L in short]
 
     def _fplll_enumerate(self, target=None):
         r"""
@@ -1549,14 +1559,10 @@ class FreeQuadraticModule_integer_symmetric(FreeQuadraticModule_submodule_with_b
         """
         L = self.LLL()
         dim = L.dimension()
-        gram = L.gram_matrix()
         basis = L.basis_matrix()
 
         import fpylll
-        gmat = fpylll.IntegerMatrix(dim, dim)
-        for i in range(dim):
-            for j in range(dim):
-                gmat[i, j] = gram[i, j]
+        gmat = fpylll.IntegerMatrix.from_matrix(L.gram_matrix())
         gso = fpylll.GSO.Mat(gmat, gram=True)
         ok = gso.update_gso()
         assert ok
