@@ -59,7 +59,7 @@ from sage.symbolic.expression import Expression
 
 def apply_map(phi):
     """
-    Returns a function that applies phi to its argument.
+    Return a function that applies ``phi`` to its argument.
 
     EXAMPLES::
 
@@ -68,7 +68,6 @@ def apply_map(phi):
         sage: f = apply_map(lambda x: x+1)
         sage: f(v)
         (2, 3, 4)
-
     """
     def apply(self, *args, **kwds):
         """
