@@ -35,10 +35,10 @@ class StringMonoid_class(FreeMonoid):
 
         INPUT:
 
-        - ``n`` -- Integer
+        - ``n`` -- integer
 
-        - ``alphabet`` -- String or tuple whose characters or elements denote
-          the generators.
+        - ``alphabet`` -- string or tuple whose characters or elements denote
+          the generators
 
         EXAMPLES::
 
@@ -168,7 +168,7 @@ class BinaryStringMonoid(StringMonoid_class):
         Return ``x`` coerced into this free monoid.
 
         One can create a free binary string monoid element from a
-        Python string of 0's and 1's or list of integers.
+        Python string of 0s and 1s or list of integers.
 
         NOTE: Due to the ambiguity of the second generator '1' with
         the identity element '' of the monoid, the syntax S(1) is not
@@ -288,7 +288,7 @@ class OctalStringMonoid(StringMonoid_class):
         Return ``x`` coerced into this free monoid.
 
         One can create a free octal string monoid element from a
-        Python string of 0's to 7's or list of integers.
+        Python string of 0s to 7s or list of integers.
 
         EXAMPLES::
 
@@ -596,7 +596,7 @@ class AlphabeticStringMonoid(StringMonoid_class):
         else:
             raise TypeError("Argument x (= %s) is of the wrong type." % x)
 
-    def characteristic_frequency(self, table_name="beker_piper"):
+    def characteristic_frequency(self, table_name='beker_piper'):
         r"""
         Return a table of the characteristic frequency probability
         distribution of the English alphabet. In written English, various
@@ -630,15 +630,15 @@ class AlphabeticStringMonoid(StringMonoid_class):
 
         INPUT:
 
-        - ``table_name`` -- (default ``"beker_piper"``) the table of
+        - ``table_name`` -- (default: ``'beker_piper'``) the table of
           characteristic frequency probability distribution to use. The
           following tables are supported:
 
-          - ``"beker_piper"`` -- the table of characteristic frequency
+          - ``'beker_piper'`` -- the table of characteristic frequency
             probability distribution by Beker and Piper [BP1982]_. This is
             the default table to use.
 
-          - ``"lewand"`` -- the table of characteristic frequency
+          - ``'lewand'`` -- the table of characteristic frequency
             probability distribution by Lewand as described on page 36
             of [Lew2000]_.
 
@@ -654,7 +654,7 @@ class AlphabeticStringMonoid(StringMonoid_class):
         Beker and Piper [BP1982]_::
 
             sage: A = AlphabeticStrings()
-            sage: table = A.characteristic_frequency(table_name="beker_piper")
+            sage: table = A.characteristic_frequency(table_name='beker_piper')
             sage: sorted(table.items())
             <BLANKLINE>
             [('A', 0.0820000000000000),
@@ -687,7 +687,7 @@ class AlphabeticStringMonoid(StringMonoid_class):
         The characteristic frequency probability distribution table
         of Lewand [Lew2000]_::
 
-            sage: table = A.characteristic_frequency(table_name="lewand")
+            sage: table = A.characteristic_frequency(table_name='lewand')
             sage: sorted(table.items())
             <BLANKLINE>
             [('A', 0.0816700000000000),
@@ -767,7 +767,7 @@ class AlphabeticStringMonoid(StringMonoid_class):
             Traceback (most recent call last):
             ...
             ValueError: Table name must be either 'beker_piper' or 'lewand'.
-            sage: table = A.characteristic_frequency(table_name="none")
+            sage: table = A.characteristic_frequency(table_name='none')
             Traceback (most recent call last):
             ...
             ValueError: Table name must be either 'beker_piper' or 'lewand'.
