@@ -40,7 +40,7 @@ class DensityPlot(GraphicPrimitive):
 
     - ``yrange`` -- tuple of 2 floats indicating range for vertical direction
 
-    - ``options`` -- dict of valid plot options to pass to constructor
+    - ``options`` -- dictionary of valid plot options to pass to constructor
 
     EXAMPLES:
 
@@ -65,7 +65,7 @@ class DensityPlot(GraphicPrimitive):
     """
     def __init__(self, xy_data_array, xrange, yrange, options):
         """
-        Initializes base class DensityPlot.
+        Initialize base class ``DensityPlot``.
 
         EXAMPLES::
 
@@ -85,7 +85,7 @@ class DensityPlot(GraphicPrimitive):
 
     def get_minmax_data(self):
         """
-        Returns a dictionary with the bounding box data.
+        Return a dictionary with the bounding box data.
 
         EXAMPLES::
 
@@ -179,13 +179,12 @@ def density_plot(f, xrange, yrange, **options):
       Colormap. Type: ``import matplotlib.cm; matplotlib.cm.datad.keys()``
       for available colormap names.
 
-    - ``interpolation`` -- string (default: ``'catrom'``), the interpolation
+    - ``interpolation`` -- string (default: ``'catrom'``); the interpolation
       method to use: ``'bilinear'``, ``'bicubic'``, ``'spline16'``,
       ``'spline36'``, ``'quadric'``, ``'gaussian'``, ``'sinc'``,
       ``'bessel'``, ``'mitchell'``, ``'lanczos'``, ``'catrom'``,
       ``'hermite'``, ``'hanning'``, ``'hamming'``, ``'kaiser'``
 
-
     EXAMPLES:
 
     Here we plot a simple function of two variables.  Note that
@@ -213,7 +212,7 @@ def density_plot(f, xrange, yrange, **options):
     .. PLOT::
 
         x,y = var('x,y')
-        def f(x,y): return x**2 * cos(x*y)
+        def f(x, y): return x**2 * cos(x*y)
         g = density_plot(f, (x,-10,5), (y,-5,5), interpolation='sinc', plot_points=100)
         sphinx_plot(g)
 
@@ -290,14 +289,14 @@ def density_plot(f, xrange, yrange, **options):
         sage: density_plot((x*y)^(1/2), (x,0,3), (y,0,500), aspect_ratio=.01)
         Graphics object consisting of 1 graphics primitive
 
-    Default ``aspect_ratio`` is ``"automatic"``, and that should work too::
+    Default ``aspect_ratio`` is ``'automatic'``, and that should work too::
 
         sage: density_plot((x*y)^(1/2), (x,0,3), (y,0,500))
         Graphics object consisting of 1 graphics primitive
 
     Check that :issue:`17684` is fixed, i.e., symbolic values can be plotted::
 
-        sage: def f(x,y):
+        sage: def f(x, y):
         ....:     return SR(x)
         sage: density_plot(f, (0,1), (0,1))
         Graphics object consisting of 1 graphics primitive
