@@ -6,13 +6,17 @@ from sage.quadratic_forms.ternary_qf import TernaryQF, find_all_ternary_qf_by_le
 
 from sage.quadratic_forms.quadratic_form import QuadraticForm, DiagonalQuadraticForm, quadratic_form_from_invariants
 
-from sage.quadratic_forms.random_quadraticform import (random_quadraticform, random_quadraticform_with_conditions,
-                                   random_ternaryqf, random_ternaryqf_with_conditions)
+from sage.quadratic_forms.random_quadraticform import (random_quadraticform,
+                                                       random_quadraticform_with_conditions,
+                                                       random_ternaryqf,
+                                                       random_ternaryqf_with_conditions)
 
 from sage.quadratic_forms.extras import least_quadratic_nonresidue, extend_to_primitive, is_triangular_number
 
-from sage.quadratic_forms.special_values import (gamma__exact, zeta__exact, QuadraticBernoulliNumber,
-                             quadratic_L_function__exact, quadratic_L_function__numerical)
+from sage.quadratic_forms.special_values import (gamma__exact, zeta__exact,
+                                                 QuadraticBernoulliNumber,
+                                                 quadratic_L_function__exact,
+                                                 quadratic_L_function__numerical)
 
 from sage.quadratic_forms.genera.genus import Genus
 
