@@ -38,8 +38,8 @@ def count_congruence_solutions_as_vector(self, p, k, m, zvec, nzvec):
     INPUT:
 
     - ``p`` -- prime number > 0
-    - ``k`` -- an integer > 0
-    - ``m`` -- an integer (depending only on mod `p^k`)
+    - ``k`` -- integer > 0
+    - ``m`` -- integer (depending only on mod `p^k`)
     - ``zvec``, ``nzvec`` -- lists of integers in ``range(self.dim())``, or ``None``
 
     OUTPUT:
@@ -47,7 +47,6 @@ def count_congruence_solutions_as_vector(self, p, k, m, zvec, nzvec):
     a list of six integers `\geq 0` representing the solution types:
     [All, Good, Zero, Bad, BadI, BadII]
 
-
     EXAMPLES::
 
         sage: Q = DiagonalQuadraticForm(ZZ, [1,2,3])
@@ -63,14 +62,13 @@ def count_congruence_solutions_as_vector(self, p, k, m, zvec, nzvec):
         [6, 6, 0, 0, 0, 0]
         sage: Q.count_congruence_solutions_as_vector(3, 1, 0, None, None)
         [15, 12, 1, 2, 0, 2]
-
     """
     return CountAllLocalTypesNaive(self, p, k, m, zvec, nzvec)
 
 
-##///////////////////////////////////////////
-##/// Front-ends for our counting routines //
-##///////////////////////////////////////////
+# //////////////////////////////////////////
+# // Front-ends for our counting routines //
+# //////////////////////////////////////////
 
 def count_congruence_solutions(self, p, k, m, zvec, nzvec):
     r"""
@@ -82,9 +80,9 @@ def count_congruence_solutions(self, p, k, m, zvec, nzvec):
 
     - ``p`` -- prime number > 0
 
-    - ``k`` -- an integer > 0
+    - ``k`` -- integer > 0
 
-    - ``m`` -- an integer (depending only on mod `p^k`)
+    - ``m`` -- integer (depending only on mod `p^k`)
 
     - ``zvec``, ``nzvec`` -- lists of integers in ``range(self.dim())``, or ``None``
 
@@ -107,9 +105,9 @@ def count_congruence_solutions__good_type(self, p, k, m, zvec, nzvec):
 
     - ``p`` -- prime number > 0
 
-    - ``k`` -- an integer > 0
+    - ``k`` -- integer > 0
 
-    - ``m`` -- an integer (depending only on mod `p^k`)
+    - ``m`` -- integer (depending only on mod `p^k`)
 
     - ``zvec``, ``nzvec`` -- lists of integers up to dim(`Q`)
 
@@ -132,9 +130,9 @@ def count_congruence_solutions__zero_type(self, p, k, m, zvec, nzvec):
 
     - ``p`` -- prime number > 0
 
-    - ``k`` -- an integer > 0
+    - ``k`` -- integer > 0
 
-    - ``m`` -- an integer (depending only on mod `p^k`)
+    - ``m`` -- integer (depending only on mod `p^k`)
 
     - ``zvec``, ``nzvec`` -- lists of integers up to dim(`Q`)
 
@@ -157,9 +155,9 @@ def count_congruence_solutions__bad_type(self, p, k, m, zvec, nzvec):
 
     - ``p`` -- prime number > 0
 
-    - ``k`` -- an integer > 0
+    - ``k`` -- integer > 0
 
-    - ``m`` -- an integer (depending only on mod `p^k`)
+    - ``m`` -- integer (depending only on mod `p^k`)
 
     - ``zvec``, ``nzvec`` -- lists of integers up to dim(`Q`)
 
@@ -182,9 +180,9 @@ def count_congruence_solutions__bad_type_I(self, p, k, m, zvec, nzvec):
 
     - ``p`` -- prime number > 0
 
-    - ``k`` -- an integer > 0
+    - ``k`` -- integer > 0
 
-    - ``m`` -- an integer (depending only on mod `p^k`)
+    - ``m`` -- integer (depending only on mod `p^k`)
 
     - ``zvec``, ``nzvec`` -- lists of integers up to dim(`Q`)
 
@@ -207,9 +205,9 @@ def count_congruence_solutions__bad_type_II(self, p, k, m, zvec, nzvec):
 
     - ``p`` -- prime number > 0
 
-    - ``k`` -- an integer > 0
+    - ``k`` -- integer > 0
 
-    - ``m`` -- an integer (depending only on mod `p^k`)
+    - ``m`` -- integer (depending only on mod `p^k`)
 
     - ``zvec``, ``nzvec`` -- lists of integers up to dim(`Q`)
 
