@@ -18,16 +18,17 @@ Path Semigroups
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
+from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
+from sage.categories.infinite_enumerated_sets import InfiniteEnumeratedSets
+from sage.categories.monoids import Monoids
+from sage.categories.semigroups import Semigroups
+from sage.misc.cachefunc import cached_method
+from sage.misc.lazy_attribute import lazy_attribute
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.structure.parent import Parent
 from sage.structure.unique_representation import UniqueRepresentation
-from sage.categories.semigroups import Semigroups
-from sage.categories.monoids import Monoids
-from sage.categories.infinite_enumerated_sets import InfiniteEnumeratedSets
-from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
-from sage.misc.cachefunc import cached_method
-from sage.misc.lazy_attribute import lazy_attribute
+
 from .paths import QuiverPath
 from .representation import QuiverRep
 
@@ -95,7 +96,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - a :class:`~sage.graphs.digraph.DiGraph`.
+        - ``Q`` -- a :class:`~sage.graphs.digraph.DiGraph`
 
         TESTS::
 
@@ -121,7 +122,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - a :class:`~sage.graphs.digraph.DiGraph`.
+        - ``Q`` -- a :class:`~sage.graphs.digraph.DiGraph`
 
         EXAMPLES:
 
@@ -268,7 +269,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
     def _element_constructor_(self, data, check=True):
         """
-        The accepted data are
+        The accepted data are:
 
         - the integer ``1``, which returns the first idempotent,
         - a list, whose only item is a tuple ``(v,v)`` for a vertex ``v``,
@@ -294,7 +295,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
             sage: Q(P(['c','d']))
             c*d
 
-        A :class:`TypeError` or a :class:`ValueError` is raised appropriately
+        A :exc:`TypeError` or a :exc:`ValueError` is raised appropriately
         if the input is wrong::
 
             sage: G = DiGraph([(0,0,'a'), (0,1,'b'), (1,0,'c')], loops=True)
@@ -362,7 +363,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
             path = []
         else:  # a list of edges
             if any(len(x) != 3 for x in data):
-                x = next((x for x in data if len(x) != 3))
+                x = next(x for x in data if len(x) != 3)
                 raise ValueError("each edge must be a triple, got {}".format(x))
             start = data[0][0]
             end = data[-1][1]
@@ -599,7 +600,6 @@ class PathSemigroup(UniqueRepresentation, Parent):
             c*b*d
             a*d*c*a
             a*d*c*b
-
         """
         d = 0
         length_d_available = True
@@ -617,8 +617,8 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``d`` -- an integer, the path length
-        - ``v`` -- a vertex, start point of the paths
+        - ``d`` -- integer; the path length
+        - ``v`` -- a vertex; start point of the paths
 
         EXAMPLES::
 
@@ -659,7 +659,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
         """
         # iterate over length d paths starting at vertex v
         if not d >= 0:
-            raise ValueError("path length must be a non-negative integer")
+            raise ValueError("path length must be a nonnegative integer")
         if v not in self._quiver:
             raise ValueError("the starting point {} is not a vertex of the underlying quiver".format(v))
         if not d:
@@ -675,8 +675,8 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``d`` -- an integer, the path length
-        - ``v`` -- a vertex, end point of the paths
+        - ``d`` -- integer; the path length
+        - ``v`` -- a vertex; end point of the paths
 
         EXAMPLES::
 
@@ -693,7 +693,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
         """
         # iterate over length d paths ending at vertex v
         if not d >= 0:
-            raise ValueError("path length must be a non-negative integer")
+            raise ValueError("path length must be a nonnegative integer")
         if v not in self._quiver:
             raise ValueError("the starting point {} is not a vertex of the underlying quiver".format(v))
         if not d:
@@ -739,7 +739,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
         """
         return self._quiver.reverse().path_semigroup()
 
-    def algebra(self, k, order="negdegrevlex"):
+    def algebra(self, k, order='negdegrevlex'):
         """
         Return the path algebra of the underlying quiver.
 
@@ -747,9 +747,9 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         - ``k`` -- a commutative ring
 
-        - ``order`` -- optional string, one of "negdegrevlex" (default),
-          "degrevlex", "negdeglex" or "deglex", defining the monomial order to
-          be used.
+        - ``order`` -- (optional) string, one of ``'negdegrevlex'`` (default),
+          ``'degrevlex'``, ``'negdeglex'`` or ``'deglex'``, defining the
+          monomial order to be used
 
         .. NOTE::
 
@@ -765,9 +765,9 @@ class PathSemigroup(UniqueRepresentation, Parent):
         Now some example with different monomial orderings::
 
             sage: P1 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'))
-            sage: P2 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order="degrevlex")
-            sage: P3 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order="negdeglex")
-            sage: P4 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order="deglex")
+            sage: P2 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order='degrevlex')
+            sage: P3 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order='negdeglex')
+            sage: P4 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order='deglex')
             sage: P1.order_string()
             'negdegrevlex'
             sage: sage_eval('(x+2*z+1)^3', P1.gens_dict())
@@ -778,7 +778,6 @@ class PathSemigroup(UniqueRepresentation, Parent):
             e_1 + z + 3*x + 2*z*z + z*x + x*z + 3*x*x + 3*z*z*z + 4*z*z*x + 4*z*x*z + 2*z*x*x + 4*x*z*z + 2*x*z*x + 2*x*x*z + x*x*x
             sage: sage_eval('(x+2*z+1)^3', P4.gens_dict())
             3*z*z*z + 4*z*z*x + 4*z*x*z + 2*z*x*x + 4*x*z*z + 2*x*z*x + 2*x*x*z + x*x*x + 2*z*z + z*x + x*z + 3*x*x + z + 3*x + e_1
-
         """
         from sage.quivers.algebra import PathAlgebra
         return PathAlgebra(k, self, order)
@@ -817,14 +816,12 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - `k` -- ring, the base ring of the representation
+        - ``k`` -- the base ring of the representation
 
-        - ``vertex`` -- integer, a vertex of the quiver
+        - ``vertex`` -- integer; a vertex of the quiver
 
-        OUTPUT:
-
-        - :class:`~sage.quivers.representation.QuiverRep`, the simple module
-          at ``vertex`` with base ring `k`
+        OUTPUT: :class:`~sage.quivers.representation.QuiverRep`; the simple
+        module at ``vertex`` with base ring `k`
 
         EXAMPLES::
 
@@ -861,14 +858,12 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - `k` -- ring, the base ring of the representation
+        - ``k`` -- the base ring of the representation
 
-        - ``vertex`` -- integer, a vertex of the quiver
+        - ``vertex`` -- integer; a vertex of the quiver
 
-        OUTPUT:
-
-        - :class:`~sage.quivers.representation.QuiverRep`, the indecomposable
-          projective module at ``vertex`` with base ring `k`
+        OUTPUT: :class:`~sage.quivers.representation.QuiverRep`, the
+        indecomposable projective module at ``vertex`` with base ring `k`
 
         EXAMPLES::
 
@@ -901,9 +896,9 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - `k` -- ring, the base ring of the representation
+        - ``k`` -- the base ring of the representation
 
-        - ``vertex`` -- integer, a vertex of the quiver
+        - ``vertex`` -- integer; a vertex of the quiver
 
         OUTPUT:
 
@@ -939,7 +934,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``k`` -- ring, the base ring of the representation.
+        - ``k`` -- ring; the base ring of the representation
 
         OUTPUT:
 
@@ -1016,9 +1011,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
           vertex of the paths in the output; if ``None`` is given then
           the terminal vertex is arbitrary
 
-        OUTPUT:
-
-        - list of paths, excluding the invalid path
+        OUTPUT: list of paths, excluding the invalid path
 
         .. TODO::
 
@@ -1078,7 +1071,7 @@ class PathSemigroup(UniqueRepresentation, Parent):
             ...
             ValueError: the end vertex 4 is not a vertex of the quiver
 
-        If the underlying quiver is cyclic, a :class:`ValueError`
+        If the underlying quiver is cyclic, a :exc:`ValueError`
         is raised::
 
             sage: Q = DiGraph({1:{2:['a','b'], 3:['c']}, 3:{1:['d']}})
@@ -1139,14 +1132,16 @@ class PathSemigroup(UniqueRepresentation, Parent):
             if len(path) == 1:
                 return [self.element_class(self, path[0], path[0], [])]
             paths = []
-            l = Q.edge_label(path[0], path[1])
-            if isinstance(l, str):
+            ell = Q.edge_label(path[0], path[1])
+            if isinstance(ell, str):
                 for b in _v_to_e(path[1:]):
-                    paths.append(self([(path[0], path[1], l)] + list(b), check=False))
+                    paths.append(self([(path[0], path[1], ell)]
+                                      + list(b), check=False))
             else:
-                for a in l:
+                for a in ell:
                     for b in _v_to_e(path[1:]):
-                        paths.append(self([(path[0], path[1], a)] + list(b), check=False))
+                        paths.append(self([(path[0], path[1], a)]
+                                          + list(b), check=False))
             return paths
 
         # For each vertex path we append the resulting edge paths
