@@ -1124,8 +1124,9 @@ def preparse_numeric_literals(code, extract=False, quotes="'"):
       name-construction pairs
 
     - ``quotes`` -- string (default: ``"'"``); used to surround string
-      arguments to RealNumber and ComplexNumber. If ``None``, will rebuild
-      the string using a list of its Unicode code-points.
+      arguments to RealNumber and ComplexNumber, and Integer when the
+      number is longer than 4300 digits. If ``None``, will rebuild the
+      string using a list of its Unicode code-points.
 
     OUTPUT:
 
@@ -1189,6 +1190,15 @@ def preparse_numeric_literals(code, extract=False, quotes="'"):
         sage: preparse_numeric_literals('000042')
         'Integer(42)'
 
+    Check that :issue:`40179` is fixed::
+
+        sage: preparse_numeric_literals("1" * 4300) == f"Integer({'1' * 4300})"
+        True
+        sage: preparse_numeric_literals("1" * 4301) == f"Integer('{'1' * 4301}')"
+        True
+        sage: preparse_numeric_literals("1" * 4301, quotes=None) == f'Integer(str().join(map(chr, {[49] * 4301})))'
+        True
+
     Test underscores as digit separators (PEP 515,
     https://www.python.org/dev/peps/pep-0515/)::
 
@@ -1324,7 +1334,13 @@ def preparse_numeric_literals(code, extract=False, quotes="'"):
                 # Python 3 does not allow leading zeroes. Sage does, so just strip them out.
                 # The number is still interpreted as decimal, not octal!
                 num = re.sub(r'^0+', '', num)
-                num_make = "Integer(%s)" % num
+                if len(num) <= 4300:
+                    num_make = "Integer(%s)" % num
+                elif quotes:
+                    num_make = "Integer(%s%s%s)" % (quotes, num, quotes)
+                else:
+                    code_points = list(map(ord, list(num)))
+                    num_make = "Integer(str().join(map(chr, %s)))" % code_points
 
             literals[num_name] = num_make
 
