@@ -24,7 +24,7 @@ def conway_polynomial(p, n):
     Return the Conway polynomial of degree `n` over ``GF(p)``.
 
     If the requested polynomial is not known, this function raises a
-    ``RuntimeError`` exception.
+    :exc:`RuntimeError` exception.
 
     INPUT:
 
@@ -64,6 +64,7 @@ def conway_polynomial(p, n):
     except KeyError:
         raise RuntimeError("requested Conway polynomial not in database.")
 
+
 def exists_conway_polynomial(p, n):
     """
     Check whether the Conway polynomial of degree `n` over ``GF(p)``
@@ -99,6 +100,7 @@ def exists_conway_polynomial(p, n):
     except ImportError:
         return False
 
+
 class PseudoConwayLattice(WithEqualityById, SageObject):
     r"""
     A pseudo-Conway lattice over a given finite prime field.
@@ -199,9 +201,7 @@ class PseudoConwayLattice(WithEqualityById, SageObject):
 
         - ``n`` -- positive integer
 
-        OUTPUT:
-
-        - a pseudo-Conway polynomial of degree `n` for the prime `p`.
+        OUTPUT: a pseudo-Conway polynomial of degree `n` for the prime `p`
 
         ALGORITHM:
 
@@ -305,14 +305,11 @@ def _find_pow_of_frobenius(p, n, x, y):
     - ``n`` -- positive integer
 
     - ``x`` -- an element of a field `K` of `p^n` elements so that
-      the multiplicative order of `x` is `p^n - 1`.
+      the multiplicative order of `x` is `p^n - 1`
 
-    - ``y`` -- an element of `K` with the same minimal polynomial as
-      `x`.
+    - ``y`` -- an element of `K` with the same minimal polynomial as `x`
 
-    OUTPUT:
-
-    - an element `i` of the integers modulo `n` such that `x = y^{p^i}`.
+    OUTPUT: an element `i` of the integers modulo `n` such that `x = y^{p^i}`
 
     EXAMPLES::
 
@@ -323,7 +320,6 @@ def _find_pow_of_frobenius(p, n, x, y):
         sage: y = x^27
         sage: _find_pow_of_frobenius(3, 14, x, y)
         11
-
     """
     from .integer_mod import mod
     for i in range(n):
@@ -334,6 +330,7 @@ def _find_pow_of_frobenius(p, n, x, y):
         raise RuntimeError("No appropriate power of Frobenius found")
     return mod(i, n)
 
+
 def _crt_non_coprime(running, a):
     """
     Extension of the ``crt`` method of ``IntegerMod`` to the case of
@@ -350,7 +347,6 @@ def _crt_non_coprime(running, a):
         Traceback (most recent call last):
         ...
         AssertionError
-
     """
     g = running.modulus().gcd(a.modulus())
     if g == 1:
@@ -368,6 +364,7 @@ def _crt_non_coprime(running, a):
                 a_modulus = a_val_unit[1]
         return (running % running_modulus).crt(a % a_modulus)
 
+
 def _frobenius_shift(K, generators, check_only=False):
     """
     Given a field `K` of degree `n` over ``GF(p)`` and a dictionary
@@ -387,12 +384,12 @@ def _frobenius_shift(K, generators, check_only=False):
 
     - ``K`` -- a finite field of degree `n` over its prime field
 
-    - ``generators`` -- a dictionary, indexed by prime divisors `q` of
+    - ``generators`` -- dictionary, indexed by prime divisors `q` of
       `n`, whose entries are elements of `K` satisfying the `n/q`
-      pseudo-Conway polynomial.
+      pseudo-Conway polynomial
 
     - ``check_only`` -- if ``True``, just check that the given
-      generators form a compatible system.
+      generators form a compatible system
 
     EXAMPLES::
 
@@ -414,7 +411,6 @@ def _frobenius_shift(K, generators, check_only=False):
         13
         sage: _find_pow_of_frobenius(2, 12, x12, generators[5])
         8
-
     """
     if len(generators) == 1:
         return generators
@@ -433,7 +429,7 @@ def _frobenius_shift(K, generators, check_only=False):
                 q, x = compatible[m].popitem()
             except KeyError:
                 break
-            for qq, xx in compatible[m].items():
+            for xx in compatible[m].values():
                 assert x == xx
         return
     crt = {}
