@@ -1,4 +1,4 @@
-# sage.doctest: optional - sage.modules
+# sage.doctest: needs sage.modules
 """
 Differentials of function fields
 
@@ -46,7 +46,6 @@ Cartier operation::
 AUTHORS:
 
 - Kwankyu Lee (2017-04-30): initial version
-
 """
 
 # ****************************************************************************
@@ -152,8 +151,8 @@ class FunctionFieldDifferential(ModuleElement):
             sage: # needs sage.rings.finite_rings
             sage: K.<x> = FunctionField(GF(4)); _.<Y> = K[]
             sage: L.<y> = K.extension(Y^3 + x + x^3*Y)                                  # needs sage.rings.function_field
-            sage: w = y.differential()
-            sage: latex(w)
+            sage: w = y.differential()                                                  # needs sage.rings.function_field
+            sage: latex(w)                                                              # needs sage.rings.function_field
             \left( x y^{2} + \frac{1}{x} y \right)\, dx
         """
         if self._f.is_zero(): # zero differential
@@ -248,7 +247,7 @@ class FunctionFieldDifferential(ModuleElement):
 
     def _div_(self, other):
         """
-        Return the quotient of ``self`` and ``other``
+        Return the quotient of ``self`` and ``other``.
 
         INPUT:
 
@@ -428,9 +427,7 @@ class FunctionFieldDifferential(ModuleElement):
 
         - ``place`` -- a place of the function field
 
-        OUTPUT:
-
-        - an element of the residue field of the place
+        OUTPUT: an element of the residue field of the place
 
         EXAMPLES:
 
@@ -473,7 +470,6 @@ class FunctionFieldDifferential(ModuleElement):
             sage: d = w.divisor()
             sage: sum([QQ(w.residue(p)) for p in d.support()])
             0
-
         """
         R,fr_R,to_R = place._residue_field()
 
