@@ -123,7 +123,6 @@ class RationalFunctionField(FunctionField):
          + Place (x, y - 1)
          + Place (x, y + 1)
          - Place (x + i, y)
-
     """
     Element = FunctionFieldElement_rational
 
@@ -204,7 +203,6 @@ class RationalFunctionField(FunctionField):
             sage: K.<t> = FunctionField(QQ)
             sage: hash(K) == hash((K.constant_base_field(), K.variable_names()))
             True
-
         """
         return self._hash
 
@@ -253,7 +251,6 @@ class RationalFunctionField(FunctionField):
             sage: I = S * [x^2 - y^2, y - t]
             sage: I.groebner_basis()                                                    # needs sage.rings.function_field
             [x^2 - t^2, y - t]
-
         """
         if isinstance(x, FunctionFieldElement):
             return self.element_class(self, self._field(x._x))
@@ -275,7 +272,7 @@ class RationalFunctionField(FunctionField):
         INPUT:
 
         - ``f`` -- element of the rational function field which is a
-          constant of the underlying rational function field.
+          constant of the underlying rational function field
 
         EXAMPLES::
 
@@ -295,7 +292,6 @@ class RationalFunctionField(FunctionField):
             True
             sage: x in QQ
             False
-
         """
         K = self.constant_base_field()
         if f.denominator() in K and f.numerator() in K:
@@ -310,7 +306,8 @@ class RationalFunctionField(FunctionField):
 
         INPUT:
 
-        - ``f`` -- an element of this rational function field whose denominator is a constant.
+        - ``f`` -- an element of this rational function field whose denominator
+          is a constant
 
         EXAMPLES::
 
@@ -332,9 +329,7 @@ class RationalFunctionField(FunctionField):
 
         - ``f`` -- univariate polynomial over the function field
 
-        OUTPUT:
-
-        - bivariate polynomial, denominator
+        OUTPUT: bivariate polynomial, denominator
 
         EXAMPLES::
 
@@ -405,7 +400,6 @@ class RationalFunctionField(FunctionField):
             sage: F = t*x
             sage: F.factor(proof=False)
             (x) * t
-
         """
         old_variable_name = f.variable_name()
         # the variables of the bivariate polynomial must be distinct
@@ -445,9 +439,7 @@ class RationalFunctionField(FunctionField):
 
         - ``names`` -- string or length-1 tuple
 
-        OUTPUT:
-
-        - a function field
+        OUTPUT: a function field
 
         EXAMPLES::
 
@@ -506,7 +498,8 @@ class RationalFunctionField(FunctionField):
 
         - ``basis`` -- (ignored) a basis for the vector space
 
-        - ``map`` -- (default ``True``), whether to return maps to and from the vector space
+        - ``map`` -- (default: ``True``) whether to return maps to and from the
+          vector space
 
         OUTPUT:
 
@@ -538,7 +531,6 @@ class RationalFunctionField(FunctionField):
              Isomorphism:
               From: Rational function field in x over Rational Field
               To:   Vector space of dimension 1 over Rational function field in x over Rational Field)
-
         """
         if basis is not None:
             raise NotImplementedError
@@ -648,11 +640,9 @@ class RationalFunctionField(FunctionField):
           ``base_morphism``; this is not checked.
 
         - ``base_morphism`` -- a homomorphism from the base field into the
-          other ring.  If ``None``, try to use a coercion map.
+          other ring; if ``None``, try to use a coercion map
 
-        OUTPUT:
-
-        - a map between function fields
+        OUTPUT: a map between function fields
 
         EXAMPLES:
 
@@ -706,7 +696,6 @@ class RationalFunctionField(FunctionField):
         .. SEEALSO::
 
             :meth:`sage.rings.fraction_field.FractionField_1poly_field.function_field`
-
         """
         return self._field
 
@@ -800,7 +789,7 @@ class RationalFunctionField(FunctionField):
 
         INPUT:
 
-        - ``name`` -- a string or a tuple consisting of a single string, the
+        - ``name`` -- string or tuple consisting of a single string; the
           name of the new variable
 
         OUTPUT:
@@ -825,7 +814,6 @@ class RationalFunctionField(FunctionField):
               Defn: x |--> y)
             sage: L.change_variable_name('x')[0] is K
             True
-
         """
         if isinstance(name, tuple):
             if len(name) != 1:
@@ -974,7 +962,7 @@ class RationalFunctionField_global(RationalFunctionField):
 
         INPUT:
 
-        - ``degree`` -- a positive integer
+        - ``degree`` -- positive integer
 
         EXAMPLES::
 
@@ -990,7 +978,6 @@ class RationalFunctionField_global(RationalFunctionField):
             Place (x^4 + x + 1)
             sage: K.get_place(5)                                                        # needs sage.libs.pari
             Place (x^5 + x^2 + 1)
-
         """
         for p in self._places_finite(degree):
             return p
