@@ -29,9 +29,9 @@ class FunctionFieldIdeal_rational(FunctionFieldIdeal):
 
     INPUT:
 
-    - ``ring`` -- the maximal order of the rational function field.
+    - ``ring`` -- the maximal order of the rational function field
 
-    - ``gen`` -- generator of the ideal, an element of the function field.
+    - ``gen`` -- generator of the ideal, an element of the function field
 
     EXAMPLES::
 
@@ -252,7 +252,7 @@ class FunctionFieldIdeal_rational(FunctionFieldIdeal):
         """
         return self._gen
 
-    def gens(self):
+    def gens(self) -> tuple:
         """
         Return the tuple of the unique generator of this ideal.
 
@@ -267,7 +267,7 @@ class FunctionFieldIdeal_rational(FunctionFieldIdeal):
         """
         return (self._gen,)
 
-    def gens_over_base(self):
+    def gens_over_base(self) -> tuple:
         """
         Return the generator of this ideal as a rank one module over the maximal
         order.
@@ -358,7 +358,7 @@ class FunctionFieldIdealInfinite_rational(FunctionFieldIdealInfinite):
 
     - ``ring`` -- infinite maximal order
 
-    - ``gen``-- generator
+    - ``gen`` -- generator
 
     Note that the infinite maximal order is a principal ideal domain.
 
@@ -548,7 +548,7 @@ class FunctionFieldIdealInfinite_rational(FunctionFieldIdealInfinite):
         """
         return self._gen
 
-    def gens(self):
+    def gens(self) -> tuple:
         """
         Return the generator of this principal ideal.
 
@@ -563,7 +563,7 @@ class FunctionFieldIdealInfinite_rational(FunctionFieldIdealInfinite):
         """
         return (self._gen,)
 
-    def gens_over_base(self):
+    def gens_over_base(self) -> tuple:
         """
         Return the generator of this ideal as a rank one module
         over the infinite maximal order.
