@@ -489,9 +489,9 @@ def pSelmerGroup(K, S, p, proof=None, debug=False):
 
         sage: [K.ideal(g).factor() for g in gens]
         [(Fractional ideal (2, a + 1)) * (Fractional ideal (3, a + 1)),
-        Fractional ideal (a),
-        (Fractional ideal (2, a + 1))^2,
-        1]
+         Fractional ideal (-a),
+         (Fractional ideal (2, a + 1))^2,
+         1]
 
         sage: toKS2(10)
         (0, 0, 1, 1)
