@@ -7,6 +7,30 @@ This module provides the
 which constructs a general dense univariate Ore polynomial ring over a
 commutative base with equipped with an endomorphism and/or a derivation.
 
+TESTS:
+
+The Ore polynomial ring is commutative if the twisting morphism is the
+identity and the twisting derivation vanishes. ::
+
+    sage: # needs sage.rings.finite_rings
+    sage: k.<a> = GF(5^3)
+    sage: Frob = k.frobenius_endomorphism()
+    sage: S.<x> = k['x', Frob]
+    sage: S.is_commutative()
+    False
+    sage: T.<y> = k['y', Frob^3]
+    sage: T.is_commutative()
+    True
+
+    sage: R.<t> = GF(5)[]
+    sage: der = R.derivation()
+    sage: A.<d> = R['d', der]
+    sage: A.is_commutative()
+    False
+    sage: B.<b> = R['b', 5*der]
+    sage: B.is_commutative()
+    True
+
 AUTHOR:
 
 - Xavier Caruso (2020-04)
@@ -21,25 +45,22 @@ AUTHOR:
 #                  https://www.gnu.org/licenses/
 # ***************************************************************************
 
-from sage.misc.prandom import randint
+import operator
+from sage.categories.algebras import Algebras
+from sage.categories.commutative_rings import CommutativeRings
+from sage.categories.morphism import Morphism
 from sage.misc.cachefunc import cached_method
 from sage.misc.lazy_import import lazy_import
+from sage.misc.prandom import randint
 from sage.rings.infinity import Infinity
-from sage.structure.category_object import normalize_names
-from sage.structure.parent import Parent
-
-from sage.structure.unique_representation import UniqueRepresentation
 from sage.rings.integer import Integer
-from sage.structure.element import Element
-
-from sage.categories.commutative_rings import CommutativeRings
-from sage.categories.algebras import Algebras
-from sage.rings.ring import _Fields
-
-from sage.categories.morphism import Morphism
-
-from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.polynomial.ore_polynomial_element import OrePolynomialBaseringInjection
+from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+from sage.rings.ring import _Fields
+from sage.structure.category_object import normalize_names
+from sage.structure.element import Element
+from sage.structure.parent import Parent
+from sage.structure.unique_representation import UniqueRepresentation
 
 lazy_import('sage.rings.derivation', 'RingDerivation')
 
@@ -317,15 +338,17 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
             Univariate Polynomial Ring in x over Finite Field in a of size 5^2
             sage: S.<x> = OrePolynomialRing(k, Frob, polcast=False)
             sage: S
-            Ore Polynomial Ring in x over Finite Field in a of size 5^2 twisted by Identity
+            Ore Polynomial Ring in x over Finite Field in a of size 5^2 untwisted
         """
         if base_ring not in CommutativeRings():
             raise TypeError('base_ring must be a commutative ring')
-        if isinstance(twist, Morphism):
+        if twist is None:
+            morphism = derivation = None
+        elif isinstance(twist, Morphism):
             if (twist.domain() is not base_ring
              or twist.codomain() is not base_ring):
                 raise TypeError("the twisting morphism must be an endomorphism of base_ring (=%s)" % base_ring)
-            if twist.is_identity() and polcast:
+            if twist.is_identity():
                 morphism = None
             else:
                 morphism = twist
@@ -339,6 +362,8 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
                 derivation = twist
             else:
                 derivation = None
+        elif twist is None:
+            morphism = derivation = None
         else:
             raise TypeError("the twisting map must be a ring morphism or a derivation")
         if names is None:
@@ -421,7 +446,11 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
         self._morphism = morphism
         self._derivation = derivation
         self._fraction_field = None
-        category = Algebras(base_ring).or_subcategory(category)
+        if morphism is None and derivation is None:
+            cat = Algebras(base_ring).Commutative()
+        else:
+            cat = Algebras(base_ring)
+        category = cat.or_subcategory(category)
         Parent.__init__(self, base_ring, names=name,
                         normalize=True, category=category)
 
@@ -506,7 +535,7 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
             pass
         if isinstance(a, str):
             try:
-                from sage.misc.parser import Parser, LookupNameMaker
+                from sage.misc.parser import LookupNameMaker, Parser
                 R = self.base_ring()
                 p = Parser(Integer, R, LookupNameMaker({self.variable_name(): self.gen()}, R))
                 return self(p.parse(a))
@@ -596,6 +625,67 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
             if P.variable_name() == self.variable_name():
                 return base_ring.has_coerce_map_from(P.base_ring())
 
+    def _repr_twist(self):
+        r"""
+        Return a string representation of the twisting morphisms.
+
+        This is a helper method.
+
+        TESTS::
+
+            sage: F.<z> = GF(5^3)
+            sage: Frob = F.frobenius_endomorphism()
+
+            sage: S.<x> = OrePolynomialRing(F, Frob)
+            sage: S._repr_twist()
+            'twisted by z |--> z^5'
+
+            sage: T.<y> = OrePolynomialRing(F, Frob^3, polcast=False)
+            sage: T._repr_twist()
+            'untwisted'
+        """
+        s = ""
+        if self._morphism is not None:
+            s += self._morphism._repr_short()
+        if self._derivation is not None:
+            if s != "":
+                s += " and "
+            s += self._derivation._repr_()
+        if s == "":
+            return "untwisted"
+        else:
+            return "twisted by " + s
+
+    def _latex_twist(self):
+        r"""
+        Return a LaTeX representation of the twisting morphisms.
+
+        This is a helper method.
+
+        TESTS::
+
+            sage: F.<z> = GF(5^3)
+            sage: Frob = F.frobenius_endomorphism()
+
+            sage: S.<x> = OrePolynomialRing(F, Frob)
+            sage: S._latex_twist()
+            z \mapsto z^{5}
+
+            sage: T.<y> = OrePolynomialRing(F, Frob^3, polcast=False)
+            sage: T._latex_twist()
+            ''
+
+        """
+        from sage.misc.latex import latex
+        s = ""
+        if self._morphism is not None:
+            s += latex(self._morphism)
+        if self._derivation is not None:
+            if s != "":
+                s += ","
+            s += latex(self._derivation)
+        return s
+
     def _repr_(self) -> str:
         r"""
         Return a string representation of ``self``.
@@ -613,13 +703,7 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
             sage: T
             Ore Polynomial Ring in d over Univariate Polynomial Ring in t over Rational Field twisted by d/dt
         """
-        s = "Ore Polynomial Ring in %s over %s twisted by " % (self.variable_name(), self.base_ring())
-        if self._derivation is None:
-            s += self._morphism._repr_short()
-        else:
-            if self._morphism is not None:
-                s += "%s and " % self._morphism._repr_short()
-            s += self._derivation._repr_()
+        s = "Ore Polynomial Ring in %s over %s %s" % (self.variable_name(), self.base_ring(), self._repr_twist())
         if self.is_sparse():
             s = "Sparse " + s
         return s
@@ -645,12 +729,9 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
         """
         from sage.misc.latex import latex
         s = "%s\\left[%s" % (latex(self.base_ring()), self.latex_variable_names()[0])
-        sep = ";"
-        if self._morphism is not None:
-            s += sep + latex(self._morphism)
-            sep = ","
-        if self._derivation is not None:
-            s += sep + latex(self._derivation)
+        twist = self._latex_twist()
+        if twist != "":
+            s += ";" + twist
         return s + "\\right]"
 
     def change_var(self, var):
@@ -679,7 +760,7 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
         else:
             twist = self._derivation
         return OrePolynomialRing(self.base_ring(), twist, names=var,
-                                 sparse=self.__is_sparse)
+                                 sparse=self.__is_sparse, polcast=False)
 
     def characteristic(self):
         r"""
@@ -1095,36 +1176,6 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
             if irred.is_irreducible():
                 return irred
 
-    def is_commutative(self) -> bool:
-        r"""
-        Return ``True`` if this Ore polynomial ring is commutative.
-
-        This holds if the twisting morphism is the identity and the
-        twisting derivation vanishes.
-
-        EXAMPLES::
-
-            sage: # needs sage.rings.finite_rings
-            sage: k.<a> = GF(5^3)
-            sage: Frob = k.frobenius_endomorphism()
-            sage: S.<x> = k['x', Frob]
-            sage: S.is_commutative()
-            False
-            sage: T.<y> = k['y', Frob^3]
-            sage: T.is_commutative()
-            True
-
-            sage: R.<t> = GF(5)[]
-            sage: der = R.derivation()
-            sage: A.<d> = R['d', der]
-            sage: A.is_commutative()
-            False
-            sage: B.<b> = R['b', 5*der]
-            sage: B.is_commutative()
-            True
-        """
-        return self._morphism is None and self._derivation is None
-
     def is_field(self, proof=False) -> bool:
         r"""
         Return always ``False`` since Ore polynomial rings are never fields.
@@ -1201,6 +1252,67 @@ class OrePolynomialRing(UniqueRepresentation, Parent):
                 self._fraction_field.register_coercion(self)
         return self._fraction_field
 
+    def quotient_module(self, P, names=None):
+        r"""
+        Return the quotient ring `A/AP` as a module over `A`
+        where `A` is this Ore polynomial ring.
+
+        INPUT:
+
+        - ``names`` (default: ``None``) -- a string or a list
+          of string, the names of the vector of the canonical
+          basis
+
+        EXAMPLES::
+
+            sage: k.<a> = GF(5^3)
+            sage: S.<x> = k['a', k.frobenius_endomorphism()]
+            sage: P = x^3 + a*x^2 + a^2 + 1
+            sage: M = S.quotient_module(P)
+            sage: M
+            Ore module of rank 3 over Finite Field in a of size 5^3 twisted by a |--> a^5
+
+        The argument ``names`` can be used to give chosen names
+        to the vectors in the canonical basis::
+
+            sage: M = S.quotient_module(P, names=('u', 'v', 'w'))
+            sage: M.basis()
+            [u, v, w]
+
+        or even::
+
+            sage: M = S.quotient_module(P, names='e')
+            sage: M.basis()
+            [e0, e1, e2]
+
+        Note that the bracket construction also works::
+
+            sage: M.<u,v,w> = S.quotient_module(P)
+            sage: M.basis()
+            [u, v, w]
+
+        With this construction, the vectors `u`, `v` and `w`
+        are directly available in the namespace::
+
+            sage: x*u + v
+            2*v
+
+        We refer to :mod:`sage.modules.ore_module` for a
+        tutorial on Ore modules in SageMath.
+
+        .. SEEALSO::
+
+            :mod:`sage.modules.ore_module`
+        """
+        from sage.matrix.special import companion_matrix
+        from sage.modules.ore_module import OreModule, OreAction
+        coeffs = self(P).right_monic().list()
+        f = companion_matrix(coeffs, format='bottom')
+        M = OreModule(f, self, names=names)
+        M._unset_coercions_used()
+        M.register_action(OreAction(self, M, True, operator.mul))
+        return M
+
     def _pushout_(self, other):
         r"""
         Return the pushout of this Ore polynomial ring and ``other``.
