@@ -1,5 +1,4 @@
-from .pbori import ReductionStrategy
-from .PyPolyBoRi import Polynomial
+from sage.rings.polynomial.pbori.pbori import Polynomial, ReductionStrategy
 
 
 def interred(l, completely=False):
