@@ -95,7 +95,7 @@ from .constructor import EllipticCurve, EllipticCurve_from_j
 
 def is_possible_j(j, S=[]):
     r"""
-    Tests if the rational `j` is a possible `j`-invariant of an
+    Test if the rational `j` is a possible `j`-invariant of an
     elliptic curve with good reduction outside `S`.
 
     .. NOTE::
@@ -155,7 +155,7 @@ def egros_from_j_1728(S=[]):
 
     INPUT:
 
-    - S -- list of primes (default: empty list).
+    - ``S`` -- list of primes (default: empty list)
 
     .. NOTE::
 
@@ -199,7 +199,7 @@ def egros_from_j_0(S=[]):
 
     INPUT:
 
-    - S -- list of primes (default: empty list).
+    - ``S`` -- list of primes (default: empty list)
 
     .. NOTE::
 
@@ -247,9 +247,9 @@ def egros_from_j(j, S=[]):
 
     INPUT:
 
-    - j -- a rational number.
+    - ``j`` -- a rational number
 
-    - S -- list of primes (default: empty list).
+    - ``S`` -- list of primes (default: empty list)
 
     .. NOTE::
 
@@ -302,9 +302,9 @@ def egros_from_jlist(jlist, S=[]):
 
     INPUT:
 
-    - j -- list of rational numbers.
+    - ``j`` -- list of rational numbers
 
-    - S -- list of primes (default: empty list).
+    - ``S`` -- list of primes (default: empty list)
 
     .. NOTE::
 
@@ -341,19 +341,19 @@ def egros_from_jlist(jlist, S=[]):
 
 def egros_get_j(S=[], proof=None, verbose=False):
     r"""
-    Returns a list of rational `j` such that all elliptic curves
+    Return a list of rational `j` such that all elliptic curves
     defined over `\QQ` with good reduction outside `S` have
     `j`-invariant in the list, sorted by height.
 
     INPUT:
 
-    - ``S`` -- list of primes (default: empty list).
+    - ``S`` -- list of primes (default: empty list)
 
-    - ``proof`` -- ``True``/``False`` (default ``True``): the MW basis for
-      auxiliary curves will be computed with this proof flag.
+    - ``proof`` -- boolean (default: ``True``); the MW basis for
+      auxiliary curves will be computed with this proof flag
 
-    - ``verbose`` -- ``True``/``False`` (default ``False````): if ``True``, some
-      details of the computation will be output.
+    - ``verbose`` -- boolean (default: ``False``); if ``True``, some
+      details of the computation will be output
 
     .. NOTE::
 
