@@ -62,9 +62,9 @@ def Jacobian(X, **kwds):
     INPUT:
 
     - ``X`` -- polynomial, algebraic variety, or anything else that
-      has a Jacobian elliptic curve.
+      has a Jacobian elliptic curve
 
-    - ``kwds`` -- optional keyword arguments.
+    - ``kwds`` -- optional keyword arguments
 
     The input ``X`` can be one of the following:
 
@@ -118,13 +118,13 @@ def Jacobian(X, **kwds):
 
 def Jacobian_of_curve(curve, morphism=False):
     """
-    Return the Jacobian of a genus-one curve
+    Return the Jacobian of a genus-one curve.
 
     INPUT:
 
-    - ``curve`` -- a one-dimensional algebraic variety of genus one.
+    - ``curve`` -- a one-dimensional algebraic variety of genus one
 
-    OUTPUT: Its Jacobian elliptic curve.
+    OUTPUT: its Jacobian elliptic curve
 
     EXAMPLES::
 
@@ -155,7 +155,7 @@ def Jacobian_of_equation(polynomial, variables=None, curve=None):
     INPUT:
 
     - ``F`` -- a polynomial defining a plane curve of genus one. May
-      be homogeneous or inhomogeneous.
+      be homogeneous or inhomogeneous
 
     - ``variables`` -- list of two or three variables or ``None``
       (default). The inhomogeneous or homogeneous coordinates. By
