@@ -12,23 +12,23 @@ Hyperelliptic curves over a `p`-adic field
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-
-from sage.rings.power_series_ring import PowerSeriesRing
-from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
-from sage.rings.integer_ring import ZZ
-from sage.rings.rational_field import QQ
-from sage.rings.padics.factory import Qp as pAdicField
-from sage.rings.finite_rings.finite_field_constructor import FiniteField as GF
-from sage.rings.real_mpfr import RR
-from sage.rings.rational_field import RationalField
-from sage.rings.infinity import Infinity
-from sage.functions.log import log
-from sage.modules.free_module import VectorSpace
 from sage.matrix.constructor import matrix
+from sage.misc.lazy_import import lazy_import
+from sage.modules.free_module import VectorSpace
 from sage.modules.free_module_element import vector
-
+from sage.rings.finite_rings.finite_field_constructor import FiniteField as GF
+from sage.rings.infinity import Infinity
+from sage.rings.integer_ring import ZZ
+from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+from sage.rings.power_series_ring import PowerSeriesRing
+from sage.rings.rational_field import QQ
+from sage.rings.rational_field import RationalField
+from sage.rings.real_mpfr import RR
 from sage.schemes.curves.projective_curve import ProjectivePlaneCurve_field
 
+lazy_import("sage.functions.log", "log")
+lazy_import("sage.rings.padics.factory", "Qp", as_="pAdicField")
+
 from . import hyperelliptic_generic
 
 
@@ -50,7 +50,7 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
         INPUT:
 
-        - P and Q points on self in the same residue disc
+        - ``P``, ``Q`` -- points on ``self`` in the same residue disc
 
         OUTPUT:
 
@@ -149,9 +149,9 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def weierstrass_points(self):
         """
-        Return the Weierstrass points of self defined over self.base_ring(),
-        that is, the point at infinity and those points in the support
-        of the divisor of `y`
+        Return the Weierstrass points of ``self`` defined over
+        ``self.base_ring()``, that is, the point at infinity and those points
+        in the support of the divisor of `y`.
 
         EXAMPLES::
 
@@ -168,7 +168,7 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def is_in_weierstrass_disc(self, P):
         """
-        Checks if `P` is in a Weierstrass disc
+        Check if `P` is in a Weierstrass disc.
 
         EXAMPLES::
 
@@ -198,7 +198,8 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def is_weierstrass(self, P):
         """
-        Checks if `P` is a Weierstrass point (i.e., fixed by the hyperelliptic involution)
+        Check if `P` is a Weierstrass point (i.e., fixed by the hyperelliptic
+        involution).
 
         EXAMPLES::
 
@@ -228,8 +229,8 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def find_char_zero_weier_point(self, Q):
         """
-        Given `Q` a point on self in a Weierstrass disc, finds the
-        center of the Weierstrass disc (if defined over self.base_ring())
+        Given `Q` a point on ``self`` in a Weierstrass disc, finds the
+        center of the Weierstrass disc (if defined over ``self.base_ring()``).
 
         EXAMPLES::
 
@@ -263,7 +264,7 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def residue_disc(self, P):
         """
-        Gives the residue disc of `P`
+        Give the residue disc of `P`.
 
         EXAMPLES::
 
@@ -309,7 +310,7 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def is_same_disc(self, P, Q):
         """
-        Checks if `P,Q` are in same residue disc
+        Check if `P,Q` are in same residue disc.
 
         EXAMPLES::
 
@@ -338,13 +339,11 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
         INPUT:
 
-        - F a list of functions `f_i`
-        - P a point on self
-        - Q a point on self (in the same residue disc as P)
+        - ``F`` -- list of functions `f_i`
+        - ``P`` -- point on ``self``
+        - ``Q`` -- point on ``self`` (in the same residue disc as `P`)
 
-        OUTPUT:
-
-        The integrals `\int_P^Q f_i dx/2y`
+        OUTPUT: the integrals `\int_P^Q f_i dx/2y`
 
         EXAMPLES::
 
@@ -373,7 +372,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
             Traceback (most recent call last):
             ...
             ValueError: (11^-2 + O(11^3) : 11^-5 + 8*11^-2 + O(11^0) : 1 + O(11^5)) and (0 : 3 + 8*11 + 2*11^2 + 8*11^3 + 2*11^4 + O(11^5) : 1 + O(11^5)) are not in the same residue disc
-
         """
         x, y, z = self.local_analytic_interpolation(P, Q)  #homogeneous coordinates
         x = x/z
@@ -402,12 +400,10 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
         INPUT:
 
-        - P a point on self
-        - Q a point on self (in the same residue disc as P)
+        - ``P`` -- point on ``self``
+        - ``Q`` -- point on ``self`` (in the same residue disc as `P`)
 
-        OUTPUT:
-
-        The integrals `\{\int_P^Q x^i dx/2y \}_{i=0}^{2g-1}`
+        OUTPUT: the integrals `\{\int_P^Q x^i dx/2y \}_{i=0}^{2g-1}`
 
         EXAMPLES::
 
@@ -436,7 +432,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
             Traceback (most recent call last):
             ...
             ValueError: (11^-2 + O(11^3) : 11^-5 + 8*11^-2 + O(11^0) : 1 + O(11^5)) and (0 : 3 + 8*11 + 2*11^2 + 8*11^3 + 2*11^4 + O(11^5) : 1 + O(11^5)) are not in the same residue disc
-
         """
         if P == Q:
             V = VectorSpace(self.base_ring(), 2*self.genus())
@@ -477,17 +472,16 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def coleman_integrals_on_basis(self, P, Q, algorithm=None):
         r"""
-        Computes the Coleman integrals `\{\int_P^Q x^i dx/2y \}_{i=0}^{2g-1}`
+        Compute the Coleman integrals `\{\int_P^Q x^i dx/2y \}_{i=0}^{2g-1}`.
 
         INPUT:
 
-        - P point on self
-        - Q point on self
-        - algorithm (optional) = None (uses Frobenius) or teichmuller (uses Teichmuller points)
+        - ``P`` -- point on ``self``
+        - ``Q`` -- point on ``self``
+        - ``algorithm`` -- ``None`` (default, uses Frobenius) or teichmuller
+          (uses Teichmuller points)
 
-        OUTPUT:
-
-        the Coleman integrals `\{\int_P^Q x^i dx/2y \}_{i=0}^{2g-1}`
+        OUTPUT: the Coleman integrals `\{\int_P^Q x^i dx/2y \}_{i=0}^{2g-1}`
 
         EXAMPLES::
 
@@ -705,14 +699,13 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
         INPUT:
 
-        - w differential (if one of P,Q is Weierstrass, w must be odd)
-        - P point on self
-        - Q point on self
-        - algorithm (optional) = None (uses Frobenius) or teichmuller (uses Teichmuller points)
+        - ``w`` -- differential (if one of P,Q is Weierstrass, w must be odd)
+        - ``P`` -- point on ``self``
+        - ``Q`` -- point on ``self``
+        - ``algorithm`` -- ``None`` (default, uses Frobenius) or teichmuller
+          (uses Teichmuller points)
 
-        OUTPUT:
-
-        the Coleman integral `\int_P^Q w`
+        OUTPUT: the Coleman integral `\int_P^Q w`
 
         EXAMPLES:
 
@@ -837,7 +830,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
         - Robert Bradshaw (2007-03)
         - Kiran Kedlaya (2008-05)
         - Jennifer Balakrishnan (2010-02)
-
         """
         # TODO: implement Jacobians and show the relationship directly
         import sage.schemes.hyperelliptic_curves.monsky_washnitzer as monsky_washnitzer
@@ -872,7 +864,7 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def frobenius(self, P=None):
         """
-        Returns the `p`-th power lift of Frobenius of `P`
+        Return the `p`-th power lift of Frobenius of `P`.
 
         EXAMPLES::
 
@@ -963,7 +955,7 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def newton_sqrt(self, f, x0, prec):
         r"""
-        Takes the square root of the power series `f` by Newton's method
+        Take the square root of the power series `f` by Newton's method.
 
         NOTE:
 
@@ -1009,11 +1001,9 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
         INPUT:
 
-        - deg: the degree of the ramified extension
+        - ``deg`` -- the degree of the ramified extension
 
-        OUTPUT:
-
-        ``self`` over `\QQ_p(p^(1/deg))`
+        OUTPUT: ``self`` over `\QQ_p(p^(1/deg))`
 
         EXAMPLES::
 
@@ -1028,7 +1018,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
         AUTHOR:
 
         - Jennifer Balakrishnan
-
         """
         from sage.schemes.hyperelliptic_curves.constructor import HyperellipticCurve
         K = self.base_ring()
@@ -1045,16 +1034,15 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def get_boundary_point(self, curve_over_extn, P):
         """
-        Given self over an extension field, find a point in the disc of `P` near the boundary
+        Given ``self`` over an extension field, find a point in the disc of `P`
+        near the boundary.
 
         INPUT:
 
-        - curve_over_extn: self over a totally ramified extension
-        - P: Weierstrass point
+        - ``curve_over_extn`` -- ``self`` over a totally ramified extension
+        - ``P`` -- Weierstrass point
 
-        OUTPUT:
-
-        a point in the disc of `P` near the boundary
+        OUTPUT: a point in the disc of `P` near the boundary
 
         EXAMPLES::
 
@@ -1072,7 +1060,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
         AUTHOR:
 
         - Jennifer Balakrishnan
-
         """
         J = curve_over_extn.base_ring()
         a = J.gen()
@@ -1082,17 +1069,15 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def P_to_S(self, P, S):
         r"""
-        Given a finite Weierstrass point `P` and a point `S`
-        in the same disc, computes the Coleman integrals `\{\int_P^S x^i dx/2y \}_{i=0}^{2g-1}`
+        Given a finite Weierstrass point `P` and a point `S` in the same disc,
+        compute the Coleman integrals `\{\int_P^S x^i dx/2y \}_{i=0}^{2g-1}`.
 
         INPUT:
 
-        - P: finite Weierstrass point
-        - S: point in disc of P
+        - ``P`` -- finite Weierstrass point
+        - ``S`` -- point in disc of `P`
 
-        OUTPUT:
-
-        Coleman integrals `\{\int_P^S x^i dx/2y \}_{i=0}^{2g-1}`
+        OUTPUT: Coleman integrals `\{\int_P^S x^i dx/2y \}_{i=0}^{2g-1}`
 
         EXAMPLES::
 
@@ -1109,7 +1094,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
         AUTHOR:
 
         - Jennifer Balakrishnan
-
         """
         prec = self.base_ring().precision_cap()
         deg = (S[0]).parent().defining_polynomial().degree()
@@ -1123,18 +1107,16 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
     def coleman_integral_P_to_S(self, w, P, S):
         r"""
         Given a finite Weierstrass point `P` and a point `S`
-        in the same disc, computes the Coleman integral `\int_P^S w`
+        in the same disc, compute the Coleman integral `\int_P^S w`.
 
         INPUT:
 
-        - w: differential
-        - P: Weierstrass point
-        - S: point in the same disc of P (S is defined over an extension of `\QQ_p`; coordinates
-          of S are given in terms of uniformizer `a`)
+        - ``w`` -- differential
+        - ``P`` -- Weierstrass point
+        - ``S`` -- point in the same disc of `P` (S is defined over an extension
+          of `\QQ_p`; coordinates of S are given in terms of uniformizer `a`)
 
-        OUTPUT:
-
-        Coleman integral `\int_P^S w` in terms of `a`
+        OUTPUT: Coleman integral `\int_P^S w` in terms of `a`
 
         EXAMPLES::
 
@@ -1155,7 +1137,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
         AUTHOR:
 
         - Jennifer Balakrishnan
-
         """
         prec = self.base_ring().precision_cap()
         deg = S[0].parent().defining_polynomial().degree()
@@ -1167,20 +1148,20 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def S_to_Q(self, S, Q):
         r"""
-        Given `S` a point on self over an extension field, computes the
-        Coleman integrals `\{\int_S^Q x^i dx/2y \}_{i=0}^{2g-1}`
+        Given `S` a point on ``self`` over an extension field, compute the
+        Coleman integrals `\{\int_S^Q x^i dx/2y \}_{i=0}^{2g-1}`.
 
         **one should be able to feed `S,Q` into coleman_integral,
         but currently that segfaults**
 
         INPUT:
 
-        - S: a point with coordinates in an extension of `\QQ_p` (with unif. a)
-        - Q: a non-Weierstrass point defined over `\QQ_p`
+        - ``S`` -- a point with coordinates in an extension of `\QQ_p` (with unif. a)
+        - ``Q`` -- a non-Weierstrass point defined over `\QQ_p`
 
         OUTPUT:
 
-        the Coleman integrals `\{\int_S^Q x^i dx/2y \}_{i=0}^{2g-1}` in terms of `a`
+        The Coleman integrals `\{\int_S^Q x^i dx/2y \}_{i=0}^{2g-1}` in terms of `a`.
 
         EXAMPLES::
 
@@ -1205,7 +1186,6 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
         AUTHOR:
 
         - Jennifer Balakrishnan
-
         """
         FS = self.frobenius(S)
         FS = (FS[0],FS[1])
@@ -1252,20 +1232,18 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def coleman_integral_S_to_Q(self, w, S, Q):
         r"""
-        Compute the Coleman integral `\int_S^Q w`
+        Compute the Coleman integral `\int_S^Q w`.
 
         **one should be able to feed `S,Q` into coleman_integral,
         but currently that segfaults**
 
         INPUT:
 
-        - w: a differential
-        - S: a point with coordinates in an extension of `\QQ_p`
-        - Q: a non-Weierstrass point defined over `\QQ_p`
+        - ``w`` -- a differential
+        - ``S`` -- a point with coordinates in an extension of `\QQ_p`
+        - ``Q`` -- a non-Weierstrass point defined over `\QQ_p`
 
-        OUTPUT:
-
-        the Coleman integral `\int_S^Q w`
+        OUTPUT: the Coleman integral `\int_S^Q w`
 
         EXAMPLES::
 
@@ -1308,15 +1286,15 @@ class HyperellipticCurve_padic_field(hyperelliptic_generic.HyperellipticCurve_ge
 
     def coleman_integral_from_weierstrass_via_boundary(self, w, P, Q, d):
         r"""
-        Computes the Coleman integral `\int_P^Q w` via a boundary point
+        Compute the Coleman integral `\int_P^Q w` via a boundary point
         in the disc of `P`, defined over a degree `d` extension
 
         INPUT:
 
-        - w: a differential
-        - P: a Weierstrass point
-        - Q: a non-Weierstrass point
-        - d: degree of extension where coordinates of boundary point lie
+        - ``w`` -- a differential
+        - ``P`` -- a Weierstrass point
+        - ``Q`` -- a non-Weierstrass point
+        - ``d`` -- degree of extension where coordinates of boundary point lie
 
         OUTPUT:
 
