@@ -185,7 +185,7 @@ class HyperellipticJacobian_generic(Jacobian_generic):
         trivial.
 
         This is related to the warning at the top of the
-        `jacobian_endomorphism_utils.py` module.
+        ``jacobian_endomorphism_utils.py`` module.
 
         INPUT:
 
@@ -214,7 +214,7 @@ class HyperellipticJacobian_generic(Jacobian_generic):
         trivial.
 
         This is related to the warning at the top of the
-        `jacobian_endomorphism_utils.py` module.
+        ``jacobian_endomorphism_utils.py`` module.
 
         INPUT:
 
