@@ -20,18 +20,18 @@ import itertools
 
 from math import floor
 
-from sage.schemes.projective.projective_space import ProjectiveSpace
-from sage.rings.integer_ring import ZZ
-from sage.rings.rational_field import QQ
-from sage.rings.real_mpfr import RealField
-from sage.rings.number_field.unit_group import UnitGroup
-from sage.arith.misc import gcd
 from sage.arith.functions import lcm
-from sage.matrix.constructor import matrix, column_matrix
-from sage.libs.pari.all import pari
-from sage.modules.free_module_element import vector
+from sage.arith.misc import gcd
+from sage.misc.lazy_import import lazy_import
 from sage.rings.integer import Integer
-from sage.geometry.polyhedron.constructor import Polyhedron
+from sage.rings.rational_field import QQ
+
+lazy_import('sage.geometry.polyhedron.constructor', 'Polyhedron')
+lazy_import('sage.libs.pari', 'pari')
+lazy_import('sage.matrix.constructor', ['matrix', 'column_matrix'])
+lazy_import('sage.modules.free_module_element', 'vector')
+lazy_import('sage.rings.number_field.unit_group', 'UnitGroup')
+lazy_import('sage.rings.real_mpfr', 'RealField')
 
 
 def ZZ_points_of_bounded_height(PS, dim, bound):
@@ -43,13 +43,11 @@ def ZZ_points_of_bounded_height(PS, dim, bound):
 
     - ``PS`` -- a projective space
 
-    - ``dim`` -- a positive integer
+    - ``dim`` -- positive integer
 
-    - ``bound`` -- a positive integer
+    - ``bound`` -- positive integer
 
-    OUTPUT:
-
-    - an iterator of points of bounded height
+    OUTPUT: an iterator of points of bounded height
 
     EXAMPLES::
 
@@ -98,16 +96,14 @@ def QQ_points_of_bounded_height(PS, dim, bound, normalize=False):
 
     - ``PS`` -- a projective space
 
-    - ``dim`` -- a positive integer
+    - ``dim`` -- positive integer
 
     - ``bound`` -- a real number
 
     - ``normalize`` -- boolean (default: ``False``); whether to
       normalize the coordinates of returned points
 
-    OUTPUT:
-
-    - an iterator of points of bounded height
+    OUTPUT: an iterator of points of bounded height
 
     EXAMPLES::
 
@@ -161,13 +157,11 @@ def IQ_points_of_bounded_height(PS, K, dim, bound):
 
     - ``K`` -- a number field
 
-    - ``dim`` -- a positive interger
+    - ``dim`` -- a positive integer
 
     - ``bound`` -- a real number
 
-    OUTPUT:
-
-    - an iterator of points of bounded height
+    OUTPUT: an iterator of points of bounded height
 
     EXAMPLES:
 
@@ -241,15 +235,13 @@ def points_of_bounded_height(PS, K, dim, bound, prec=53):
 
     - ``K`` -- a number field
 
-    - ``dim`` -- a positive integer
+    - ``dim`` -- positive integer
 
     - ``bound`` -- a real number
 
     - ``prec`` -- (default: 53) a positive integer
 
-    OUTPUT:
-
-    - an iterator of points of bounded height
+    OUTPUT: an iterator of points of bounded height
 
     EXAMPLES::
 
