@@ -160,7 +160,7 @@ def Discriminant(polynomial, variables=None):
     See :func:`WeierstrassForm` for how to specify the input
     polynomial(s) and variables.
 
-    OUTPUT: The discriminant of the elliptic curve.
+    OUTPUT: the discriminant of the elliptic curve
 
     EXAMPLES::
 
@@ -199,7 +199,7 @@ def j_invariant(polynomial, variables=None):
     * A nodal cubic: `j(-y^2 + x^2 + x^3) = \infty`
 
     * A cuspidal cubic `y^2=x^3` has undefined `j`-invariant. In this
-      case, a :class:`ValueError` is raised.
+      case, a :exc:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -364,16 +364,16 @@ def WeierstrassForm(polynomial, variables=None, transformation=False):
       If two polynomials are passed, they must both be quadratics in
       `\mathbb{P}^3`.
 
-    - ``variables`` -- a list of variables of the parent polynomial
+    - ``variables`` -- list of variables of the parent polynomial
       ring or ``None`` (default). In the latter case, all variables
       are taken to be polynomial ring variables. If a subset of
       polynomial ring variables are given, the Weierstrass form is
       determined over the function field generated by the remaining
       variables.
 
-    - ``transformation`` -- boolean (default: ``False``). Whether to
+    - ``transformation`` -- boolean (default: ``False``); whether to
       return the new variables that bring ``polynomial`` into
-      Weierstrass form.
+      Weierstrass form
 
     OUTPUT:
 
@@ -505,28 +505,28 @@ def WeierstrassForm(polynomial, variables=None, transformation=False):
 ######################################################################
 def _check_homogeneity(polynomial, variables, weights, total_weight=None):
     """
-    Raise :class:`ValueError` if the polynomial is not weighted
+    Raise :exc:`ValueError` if the polynomial is not weighted
     homogeneous.
 
     INPUT:
 
-    - ``polynomial`` -- the input polynomial. See
-      :func:`WeierstrassForm` for details.
+    - ``polynomial`` -- the input polynomial; see
+      :func:`WeierstrassForm` for details
 
-    - ``variables`` -- the variables.  See :func:`WeierstrassForm` for
-      details.
+    - ``variables`` -- the variables; see :func:`WeierstrassForm` for
+      details
 
-    - ``weights`` -- list of integers, one per variable. the weights
-      of the variables.
+    - ``weights`` -- list of integers, one per variable; the weights
+      of the variables
 
-    - ``total_weight`` -- an integer or ``None`` (default). If an
+    - ``total_weight`` -- integer or ``None`` (default); if an
       integer is passed, it is also checked that the weighted total
-      degree of polynomial is this value.
+      degree of polynomial is this value
 
     OUTPUT:
 
     This function returns nothing. If the polynomial is not weighted
-    homogeneous, a :class:`ValueError` is raised.
+    homogeneous, a :exc:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -565,9 +565,9 @@ def _extract_coefficients(polynomial, monomials, variables):
 
     - ``polynomial`` -- the input polynomial
 
-    - ``monomials`` -- a list of monomials in the polynomial ring
+    - ``monomials`` -- list of monomials in the polynomial ring
 
-    - ``variables`` -- a list of variables in the polynomial ring
+    - ``variables`` -- list of variables in the polynomial ring
 
     OUTPUT:
 
@@ -614,16 +614,16 @@ def _check_polynomial_P2(cubic, variables):
 
     INPUT:
 
-    - ``cubic`` -- the input polynomial. See
-      :func:`WeierstrassForm` for details.
+    - ``cubic`` -- the input polynomial; see
+      :func:`WeierstrassForm` for details
 
-    - ``variables`` -- the variables or ``None``.  See
-      :func:`WeierstrassForm` for details.
+    - ``variables`` -- the variables or ``None``; see
+      :func:`WeierstrassForm` for details
 
     OUTPUT:
 
     This functions returns ``variables``, potentially guessed from the
-    polynomial ring. A :class:`ValueError` is raised if the polynomial is
+    polynomial ring. A :exc:`ValueError` is raised if the polynomial is
     not homogeneous.
 
     EXAMPLES::
@@ -771,16 +771,16 @@ def _check_polynomial_P1xP1(biquadric, variables):
 
     INPUT:
 
-    - ``biquadric`` -- the input polynomial. See
-      :func:`WeierstrassForm` for details.
+    - ``biquadric`` -- the input polynomial; see
+      :func:`WeierstrassForm` for details
 
-    - ``variables`` -- the variables or ``None``.  See
-      :func:`WeierstrassForm` for details.
+    - ``variables`` -- the variables or ``None``; see
+      :func:`WeierstrassForm` for details
 
     OUTPUT:
 
     This functions returns ``variables``, potentially guessed from the
-    polynomial ring. A :class:`ValueError` is raised if the polynomial is
+    polynomial ring. A :exc:`ValueError` is raised if the polynomial is
     not homogeneous.
 
     EXAMPLES::
@@ -820,14 +820,12 @@ def _partial_discriminant(quadric, y0, y1=None):
 
     INPUT:
 
-    - ``quadric`` -- a biquadric.
+    - ``quadric`` -- a biquadric
 
-    - ``y_0``, ``y_1`` -- the variables of the quadric. The ``y_1``
-      variable can be omitted if the quadric is inhomogeneous.
+    - ``y_0``, ``y_1`` -- the variables of the quadric; the ``y_1``
+      variable can be omitted if the quadric is inhomogeneous
 
-    OUTPUT:
-
-    A plane quartic in ``x0``, ``x1``.
+    OUTPUT: a plane quartic in ``x0``, ``x1``
 
     EXAMPLES::
 
@@ -862,7 +860,7 @@ def _partial_discriminant(quadric, y0, y1=None):
 ######################################################################
 def WeierstrassForm_P1xP1(biquadric, variables=None):
     r"""
-    Bring a biquadric into Weierstrass form
+    Bring a biquadric into Weierstrass form.
 
     Input/output is the same as :func:`WeierstrassForm`, except that
     the input polynomial must be a standard biquadric in `\mathbb{P}^2`,
@@ -955,16 +953,16 @@ def _check_polynomial_P2_112(polynomial, variables):
 
     INPUT:
 
-    - ``polynomial`` -- the input polynomial. See
-      :func:`WeierstrassForm` for details.
+    - ``polynomial`` -- the input polynomial; see
+      :func:`WeierstrassForm` for details
 
-    - ``variables`` -- the variables or ``None``.  See
-      :func:`WeierstrassForm` for details.
+    - ``variables`` -- the variables or ``None``; see
+      :func:`WeierstrassForm` for details
 
     OUTPUT:
 
     This functions returns ``variables``, potentially guessed from the
-    polynomial ring. A :class:`ValueError` is raised if the polynomial is
+    polynomial ring. A :exc:`ValueError` is raised if the polynomial is
     not homogeneous.
 
     EXAMPLES::
