@@ -68,7 +68,7 @@ class PositiveIntegers(IntegerRangeInfinite):
 
     def an_element(self):
         r"""
-        Returns an element of ``self``.
+        Return an element of ``self``.
 
         EXAMPLES::
 
