@@ -65,11 +65,11 @@ TESTS::
 #
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
-
-from sage.misc.repr import repr_lincomb
 import operator
 from collections import OrderedDict
 
+from sage.misc.persist import register_unpickle_override
+from sage.misc.repr import repr_lincomb
 from sage.modules.module import Module
 from sage.structure.element import ModuleElement
 from sage.structure.richcmp import richcmp
@@ -392,11 +392,14 @@ class FormalSums(UniqueRepresentation, Module):
             else:
                 x = x._data
         if isinstance(x, list):
-            return self.element_class(x, check=check,reduce=reduce,parent=self)
+            return self.element_class(x, check=check,
+                                      reduce=reduce, parent=self)
         if x == 0:
-            return self.element_class([], check=False, reduce=False, parent=self)
+            return self.element_class([], check=False,
+                                      reduce=False, parent=self)
         else:
-            return self.element_class([(self.base_ring()(1), x)], check=False, reduce=False, parent=self)
+            return self.element_class([(self.base_ring()(1), x)],
+                                      check=False, reduce=False, parent=self)
 
     def _coerce_map_from_(self, X):
         r"""
@@ -413,7 +416,7 @@ class FormalSums(UniqueRepresentation, Module):
               From: Abelian Group of all Formal Finite Sums over Integer Ring
               To:   Abelian Group of all Formal Finite Sums over Rational Field
         """
-        if isinstance(X,FormalSums):
+        if isinstance(X, FormalSums):
             if self.base_ring().has_coerce_map_from(X.base_ring()):
                 return True
         return False
@@ -475,7 +478,7 @@ class FormalSums(UniqueRepresentation, Module):
             1/2
         """
         return self.element_class([(self.base_ring().an_element(), 1)],
-                         check=check, reduce=reduce, parent=self)
+                                  check=check, reduce=reduce, parent=self)
 
 
 formal_sums = FormalSums()
@@ -483,5 +486,4 @@ formal_sums = FormalSums()
 # Formal sums now derives from UniqueRepresentation, which makes the
 # factory function unnecessary. This is why the name was changed from
 # class FormalSums_generic to class FormalSums.
-from sage.misc.persist import register_unpickle_override
 register_unpickle_override('sage.structure.formal_sum', 'FormalSums_generic', FormalSums)
