@@ -225,7 +225,8 @@ def get_flag(t=None, subsystem=None):
         False
     """
     if t is None:
-        if subsystem in ["arithmetic", "elliptic_curve", "linear_algebra", "number_field","polynomial"]:
+        if subsystem in ["arithmetic", "elliptic_curve",
+                         "linear_algebra", "number_field", "polynomial"]:
             return _proof_prefs._require_proof[subsystem]
         else:
             return _proof_prefs._require_proof["other"]
