@@ -145,7 +145,7 @@ We can solve equations::
     sage: solve(z^2 == sqrt(3),z)
     Traceback (most recent call last):
     ...
-    TypeError: 5 is not a valid variable.
+    TypeError: 5 is not a valid variable
 
 We can also solve equations involving matrices. The following
 example defines a multivariable function ``f(x,y)``, then solves
@@ -360,65 +360,65 @@ from itertools import product
 import operator
 
 
-def test_relation_maxima(relation):
+def check_relation_maxima(relation):
     """
     Return ``True`` if this (in)equality is definitely true. Return ``False``
     if it is false or the algorithm for testing (in)equality is inconclusive.
 
     EXAMPLES::
 
-        sage: from sage.symbolic.relation import test_relation_maxima
+        sage: from sage.symbolic.relation import check_relation_maxima
         sage: k = var('k')
         sage: pol = 1/(k-1) - 1/k -1/k/(k-1)
-        sage: test_relation_maxima(pol == 0)
+        sage: check_relation_maxima(pol == 0)
         True
         sage: f = sin(x)^2 + cos(x)^2 - 1
-        sage: test_relation_maxima(f == 0)
+        sage: check_relation_maxima(f == 0)
         True
-        sage: test_relation_maxima( x == x )
+        sage: check_relation_maxima( x == x )
         True
-        sage: test_relation_maxima( x != x )
+        sage: check_relation_maxima( x != x )
         False
-        sage: test_relation_maxima( x > x )
+        sage: check_relation_maxima( x > x )
         False
-        sage: test_relation_maxima( x^2 > x )
+        sage: check_relation_maxima( x^2 > x )
         False
-        sage: test_relation_maxima( x + 2 > x )
+        sage: check_relation_maxima( x + 2 > x )
         True
-        sage: test_relation_maxima( x - 2 > x )
+        sage: check_relation_maxima( x - 2 > x )
         False
 
     Here are some examples involving assumptions::
 
         sage: x, y, z = var('x, y, z')
         sage: assume(x>=y,y>=z,z>=x)
-        sage: test_relation_maxima(x==z)
+        sage: check_relation_maxima(x==z)
         True
-        sage: test_relation_maxima(z<x)
+        sage: check_relation_maxima(z<x)
         False
-        sage: test_relation_maxima(z>y)
+        sage: check_relation_maxima(z>y)
         False
-        sage: test_relation_maxima(y==z)
+        sage: check_relation_maxima(y==z)
         True
         sage: forget()
         sage: assume(x>=1,x<=1)
-        sage: test_relation_maxima(x==1)
+        sage: check_relation_maxima(x==1)
         True
-        sage: test_relation_maxima(x>1)
+        sage: check_relation_maxima(x>1)
         False
-        sage: test_relation_maxima(x>=1)
+        sage: check_relation_maxima(x>=1)
         True
-        sage: test_relation_maxima(x!=1)
+        sage: check_relation_maxima(x!=1)
         False
         sage: forget()
         sage: assume(x>0)
-        sage: test_relation_maxima(x==0)
+        sage: check_relation_maxima(x==0)
         False
-        sage: test_relation_maxima(x>-1)
+        sage: check_relation_maxima(x>-1)
         True
-        sage: test_relation_maxima(x!=0)
+        sage: check_relation_maxima(x!=0)
         True
-        sage: test_relation_maxima(x!=1)
+        sage: check_relation_maxima(x!=1)
         False
         sage: forget()
 
@@ -433,7 +433,7 @@ def test_relation_maxima(relation):
         sage: f = log(x*y) - (log(x) + log(y))
         sage: f(x=-1, y=i)
         -2*I*pi
-        sage: test_relation_maxima(f == 0)
+        sage: check_relation_maxima(f == 0)
         False
         sage: forget()
 
@@ -442,7 +442,7 @@ def test_relation_maxima(relation):
 
         sage: assume(x, 'complex')
         sage: f = sqrt(x^2) - abs(x)
-        sage: test_relation_maxima(f == 0)
+        sage: check_relation_maxima(f == 0)
         False
         sage: forget()
 
@@ -451,7 +451,7 @@ def test_relation_maxima(relation):
         sage: assume(x, 'real')
         sage: f1 = ( e^(I*x) - e^(-I*x) ) / ( I*e^(I*x) + I*e^(-I*x) )
         sage: f2 = sin(x)/cos(x)
-        sage: test_relation_maxima(f1 - f2 == 0)
+        sage: check_relation_maxima(f1 - f2 == 0)
         True
         sage: forget()
 
@@ -460,7 +460,7 @@ def test_relation_maxima(relation):
         sage: assume(x, 'complex')
         sage: f1 = ( e^(I*x) - e^(-I*x) ) / ( I*e^(I*x) + I*e^(-I*x) )
         sage: f2 = sin(x)/cos(x)
-        sage: test_relation_maxima(f1 - f2 == 0)
+        sage: check_relation_maxima(f1 - f2 == 0)
         False
         sage: forget()
 
@@ -471,7 +471,7 @@ def test_relation_maxima(relation):
         sage: assume(k, 'integer')
         sage: f1 = factorial(n+1)/factorial(n)
         sage: f2 = n + 1
-        sage: test_relation_maxima(f1 - f2 == 0)
+        sage: check_relation_maxima(f1 - f2 == 0)
         True
         sage: forget()
 
@@ -576,12 +576,105 @@ def string_to_list_of_solutions(s):
     v = symbolic_expression_from_maxima_string(s, equals_sub=True)
     return Sequence(v, universe=Objects(), cr_str=True)
 
+
+def _normalize_to_relational(f):
+    """
+    Normalize the input to a relational expression or a list of relational expressions.
+
+    TESTS::
+
+        sage: from sage.symbolic.relation import _normalize_to_relational
+        sage: x, y = var('x, y')
+        sage: _normalize_to_relational(x == 1)
+        x == 1
+        sage: _normalize_to_relational([x == 1, y == 2])
+        [x == 1, y == 2]
+        sage: _normalize_to_relational(x - 1)
+        x - 1 == 0
+        sage: _normalize_to_relational([x - 1, y - 2])
+        [x - 1 == 0, y - 2 == 0]
+        sage: _normalize_to_relational((x - 1, y - 2))
+        [x - 1 == 0, y - 2 == 0]
+        sage: _normalize_to_relational(1)
+        False
+    """
+    if isinstance(f, (list, tuple)):
+        return [_normalize_to_relational(g) for g in f]
+    from sage.symbolic.expression import Expression
+    if isinstance(f, bool) or (isinstance(f, Expression) and f.is_relational()):
+        return f
+    return f == 0
+
+
+def _normalize_to_nonrelational(f):
+    """
+    Normalize the input to a non-relational expression or a list of non-relational expressions.
+
+    TESTS::
+
+        sage: from sage.symbolic.relation import _normalize_to_nonrelational
+        sage: x, y = var('x, y')
+        sage: _normalize_to_nonrelational(x == 1)
+        x - 1
+        sage: _normalize_to_nonrelational([x == 1, y == 2])
+        [x - 1, y - 2]
+        sage: _normalize_to_nonrelational(x - 1)
+        x - 1
+        sage: _normalize_to_nonrelational([x - 1, y - 2])
+        [x - 1, y - 2]
+        sage: _normalize_to_nonrelational((x - 1, y - 2))
+        [x - 1, y - 2]
+        sage: _normalize_to_nonrelational(1)
+        1
+        sage: _normalize_to_nonrelational(True)
+        0
+        sage: _normalize_to_nonrelational(False)
+        1
+    """
+    if isinstance(f, (list, tuple)):
+        return [_normalize_to_nonrelational(g) for g in f]
+    if isinstance(f, bool):
+        return 0 if f else 1
+    from sage.symbolic.expression import Expression
+    if isinstance(f, Expression) and f.is_relational():
+        assert f.operator() == operator.eq
+        return f.lhs() - f.rhs()
+    return f
+
+
+def _normalize_to_list_expressions(f) -> list:
+    """
+    Normalize either a single equation or a list of equations into a list of
+    equations.
+
+    TESTS::
+
+        sage: from sage.symbolic.relation import _normalize_to_list_expressions
+        sage: x, y = var('x, y')
+        sage: _normalize_to_list_expressions(x == 1)
+        [x == 1]
+        sage: _normalize_to_list_expressions([x == 1, y == 2])
+        [x == 1, y == 2]
+        sage: _normalize_to_list_expressions({})
+        Traceback (most recent call last):
+        ...
+        TypeError: must be a symbolic expression or a list of symbolic expressions
+    """
+    from sage.symbolic.expression import Expression
+    if isinstance(f, (Expression, bool)):
+        f = [f]
+    if not isinstance(f, (list, tuple)) or not all(isinstance(s, (Expression, bool)) for s in f):
+        raise TypeError("must be a symbolic expression or a list of symbolic expressions")
+    return f
+
+
 ###########
 # Solving #
 ###########
 
 
-def solve(f, *args, **kwds):
+def solve(f, *args, explicit_solutions=None, multiplicities=None, to_poly_solve=None,
+          solution_dict=False, algorithm=None, domain=None):
     r"""
     Algebraically solve an equation or system of equations (over the
     complex numbers) for given variables. Inequalities and systems
@@ -697,7 +790,7 @@ def solve(f, *args, **kwds):
         sage: solve([8*z + y == 3, -z +7*y == 0],y,z)
         Traceback (most recent call last):
         ...
-        TypeError: 5 is not a valid variable.
+        TypeError: 5 is not a valid variable
 
     If we ask for dictionaries containing the solutions, we get them::
 
@@ -890,7 +983,7 @@ def solve(f, *args, **kwds):
     handled by Maxima::
 
         sage: _ = var('t')
-        sage: r = solve([x^2 - y^2/exp(x), y-1], x, y, algorithm='sympy')
+        sage: r = solve([x^2 - y^2/exp(x), y-1], x, y, algorithm='sympy', solution_dict=True)
         sage: (r[0][x], r[0][y])
         (2*lambert_w(-1/2), 1)
         sage: solve(-2*x**3 + 4*x**2 - 2*x + 6 > 0, x, algorithm='sympy')
@@ -899,10 +992,10 @@ def solve(f, *args, **kwds):
         [x == -8, x == 2]
         sage: solve(sqrt(2*x + 9) - sqrt(x + 1) - sqrt(x + 4),x,algorithm='sympy')
         [x == 0]
-        sage: r = solve([x + y + z + t, -z - t], x, y, z, t, algorithm='sympy')
+        sage: r = solve([x + y + z + t, -z - t], x, y, z, t, algorithm='sympy', solution_dict=True)
         sage: (r[0][x], r[0][z])
         (-y, -t)
-        sage: r = solve([x^2+y+z, y+x^2+z, x+y+z^2], x, y,z, algorithm='sympy')
+        sage: r = solve([x^2+y+z, y+x^2+z, x+y+z^2], x, y,z, algorithm='sympy', solution_dict=True)
         sage: (r[0][x], r[0][y])
         (z, -(z + 1)*z)
         sage: (r[1][x], r[1][y])
@@ -922,19 +1015,19 @@ def solve(f, *args, **kwds):
          ImageSet(Lambda(_n, 2*_n*pi + 5*pi/3), Integers),
          ImageSet(Lambda(_n, 2*_n*pi + pi/3), Integers)]
 
-        sage: solve(x^5 + 3*x^3 + 7, x, algorithm='sympy')[0] # known bug
-        complex_root_of(x^5 + 3*x^3 + 7, 0)
+        sage: solve(x^5 + 3*x^3 + 7, x, algorithm='sympy')[0]
+        x == complex_root_of(x^5 + 3*x^3 + 7, 0)
 
     A basic interface to Giac is provided::
 
         sage: # needs sage.libs.giac
         sage: solve([(2/3)^x-2], [x], algorithm='giac')
-        ...[[-log(2)/(log(3) - log(2))]]
+        [-log(2)/(log(3) - log(2))]
 
         sage: # needs sage.libs.giac
         sage: f = (sin(x) - 8*cos(x)*sin(x))*(sin(x)^2 + cos(x)) - (2*cos(x)*sin(x) - sin(x))*(-2*sin(x)^2 + 2*cos(x)^2 - cos(x))
         sage: solve(f, x, algorithm='giac')
-        ...[-2*arctan(sqrt(2)), 0, 2*arctan(sqrt(2)), pi]
+        [-2*arctan(sqrt(2)), 0, 2*arctan(sqrt(2)), pi]
 
         sage: # needs sage.libs.giac
         sage: x, y = SR.var('x,y')
@@ -946,9 +1039,7 @@ def solve(f, *args, **kwds):
         sage: solve([sin(x)==x,y^2==x],x,y)
         [sin(x) == x, y^2 == x]
         sage: solve(0==1,x)
-        Traceback (most recent call last):
-        ...
-        TypeError:  The first argument must be a symbolic expression or a list of symbolic expressions.
+        []
 
     Test if the empty list is returned, too, when (a list of)
     dictionaries (is) are requested (:issue:`8553`)::
@@ -986,22 +1077,22 @@ def solve(f, *args, **kwds):
         sage: solve([a+b+a*b == 1], a)
         Traceback (most recent call last):
         ...
-        TypeError: a is not a valid variable.
+        TypeError: a is not a valid variable
         sage: a,b = var('a,b')
         sage: solve([a+b+a*b == 1], a)
         [a == -(b - 1)/(b + 1)]
         sage: solve([a, b], (1, a))
         Traceback (most recent call last):
         ...
-        TypeError: 1 is not a valid variable.
+        TypeError: 1 is not a valid variable
         sage: solve([x == 1], (1, a))
         Traceback (most recent call last):
         ...
-        TypeError: 1 is not a valid variable.
+        TypeError: 1 is not a valid variable
         sage: x.solve((1,2))
         Traceback (most recent call last):
         ...
-        TypeError: 1 is not a valid variable.
+        TypeError: 1 is not a valid variable
 
     Test that the original version of a system in the French Sage book
     now works (:issue:`14306`)::
@@ -1026,108 +1117,123 @@ def solve(f, *args, **kwds):
         sage: solve([1], x)
         Traceback (most recent call last):
         ...
-        TypeError: The first argument to solve() should be a symbolic expression
-        or a list of symbolic expressions.
+        TypeError: must be a symbolic expression or a list of symbolic expressions
+
+    Automatic computation of the variables to solve for::
+
+        sage: var("x y")
+        (x, y)
+        sage: solve(x==1)
+        [x == 1]
+        sage: solve([x == 1, y == 2])  # random
+        [[y == 2, x == 1]]
+        sage: assert solve([x == 1, y == 2]) in ([[x == 1, y == 2]], [[y == 2, x == 1]])
+        sage: solve([x == 1])
+        [x == 1]
+        sage: solve(x == 1)
+        [x == 1]
+
+    Special case::
+
+        sage: solve([], [])
+        [[]]
+
+    Coverage test::
+
+        sage: y = function('y')(x)
+        sage: solve([diff(y)==x, diff(y)==x], y)
+        Traceback (most recent call last):
+        ...
+        TypeError: y(x) is not a valid variable
+        sage: solve([0==1], x, multiplicities=True)
+        ([], [])
+        sage: solve([0==0], [], multiplicities=True)
+        ([[]], [1])
+        sage: var("x y")
+        (x, y)
+        sage: solve([x==1, y==2], [x, y], algorithm='sympy', solution_dict=True)
+        [{x: 1, y: 2}]
+        sage: solve([x==1, y==2], [x, y], algorithm='sympy')
+        [[x == 1, y == 2]]
     """
     from sage.structure.element import Expression
-    explicit_solutions = kwds.get('explicit_solutions', None)
-    multiplicities = kwds.get('multiplicities', None)
-    to_poly_solve = kwds.get('to_poly_solve', None)
-    solution_dict = kwds.get('solution_dict', False)
-    algorithm = kwds.get('algorithm', None)
-    domain = kwds.get('domain', None)
-
-    if len(args) > 1:
-        x = args
-    else:
-        x = args[0]
-    if isinstance(x, (list, tuple)):
-        for i in x:
-            if not isinstance(i, Expression):
-                raise TypeError("%s is not a valid variable." % repr(i))
-    elif x is None:
-        vars = f.variables()
-        if len(vars) == 0:
-            if multiplicities:
-                return [], []
-            else:
-                return []
-        x = vars[0]
-    elif not isinstance(x, Expression):
-        raise TypeError("%s is not a valid variable." % repr(x))
-
-    if isinstance(f, (list, tuple)) and len(f) == 1:
-        # f is a list with a single element
-        if isinstance(f[0], Expression):
-            f = f[0]
-        else:
-            raise TypeError("The first argument to solve() should be a "
-                            "symbolic expression or a list of symbolic "
-                            "expressions.")
-
-    if isinstance(f, Expression):  # f is a single expression
-        return _solve_expression(f, x, explicit_solutions, multiplicities, to_poly_solve, solution_dict, algorithm, domain)
-
-    if not isinstance(f, (list, tuple)):
-        raise TypeError("The first argument must be a symbolic expression or a list of symbolic expressions.")
-
-    # f is a list of such expressions or equations
+    f = _normalize_to_list_expressions(f)
 
+    # Normalize x to list of variables
     if not args:
-        raise TypeError("Please input variables to solve for.")
-    if isinstance(x, Expression) and x.is_symbol():
-        variables = args
+        x = None
     else:
-        variables = tuple(x)
+        x = args
+        if len(x) == 1 and (isinstance(x[0], (list, tuple)) or x[0] is None):
+            x = x[0]
+    if x is None:
+        x = list({v for s in f for v in s.variables()})
 
-    for v in variables:
-        if not (isinstance(v, Expression) and v.is_symbol()):
-            raise TypeError("%s is not a valid variable." % repr(v))
-
-    try:
-        f = [s for s in f if s is not True]
-    except TypeError:
-        raise ValueError("Unable to solve %s for %s" % (f, args))
+    require_all_variables_to_be_symbol = len(f) > 1
+    # we support y = function('y')(x); solve(diff(y)==x, y), in this case y = y(x) is not a symbol
+    # but only if one equation is provided, otherwise it's unimplemented
+    # there is also desolve()
+    for i in x:
+        complain = False
+        if not isinstance(i, Expression):
+            complain = True
+        elif require_all_variables_to_be_symbol and not i.is_symbol():
+            complain = True
+        if complain:
+            raise TypeError(f"{i} is not a valid variable")
 
+    # Handle special cases
+    f = [s for s in f if s is not True]
     if any(s is False for s in f):
-        return []
+        if multiplicities:
+            return [], []
+        else:
+            return []
+
+    if not x:
+        if multiplicities:
+            from sage.rings.integer_ring import ZZ
+            return [[]], [ZZ.one()]
+        else:
+            return [[]]
+
+    if len(f) == 1:
+        return _solve_expression(f[0], x, explicit_solutions, multiplicities, to_poly_solve, solution_dict, algorithm, domain)
 
     if algorithm == 'sympy':
         from sympy import solve as ssolve
         from sage.interfaces.sympy import sympy_set_to_list
-        if isinstance(f, Expression):  # f is a single expression
-            sympy_f = f._sympy_()
-        else:
-            sympy_f = [s._sympy_() for s in f]
-        if isinstance(f, Expression) and f.is_symbol():
-            sympy_vars = (x._sympy_(),)
-        else:
-            sympy_vars = tuple([v._sympy_() for v in x])
-        if len(sympy_vars) > 1 or not isinstance(f, Expression):
-            ret = ssolve(sympy_f, sympy_vars, dict=True)
-            if isinstance(ret, dict):
-                if solution_dict:
-                    l = []
-                    for d in ret:
-                        r = {}
-                        for (v, ex) in d.items():
-                            r[v._sage_()] = ex._sage_()
-                        l.append(r)
-                    return l
-                else:
-                    return [[v._sage_() == ex._sage_()
-                             for v, ex in d.items()]
-                            for d in ret]
-            elif isinstance(ret, list):
+        sympy_f = [s._sympy_() for s in f]
+        sympy_vars = tuple([v._sympy_() for v in x])
+        ret = ssolve(sympy_f, sympy_vars, dict=True)
+        if isinstance(ret, dict):
+            # it is not clear how this branch could be reached
+            # because dict=True is passed above, however
+            # it is kept just in case
+            if solution_dict:
                 l = []
-                for sol in ret:
+                for d in ret:
                     r = {}
-                    for (v, ex) in sol.items():
+                    for (v, ex) in d.items():
                         r[v._sage_()] = ex._sage_()
                     l.append(r)
                 return l
             else:
-                return sympy_set_to_list(ret, sympy_vars)
+                return [[v._sage_() == ex._sage_()
+                         for v, ex in d.items()]
+                        for d in ret]
+        elif isinstance(ret, list):
+            if solution_dict:
+                return [{v._sage_(): ex._sage_()
+                         for v, ex in d.items()} for d in ret]
+            else:
+                return [[v._sage_() == ex._sage_()
+                         for v, ex in d.items()] for d in ret]
+        else:
+            # it is not clear how this branch could be reached
+            # because dict=True is passed above, however
+            # it is kept just in case
+            return sympy_set_to_list(ret, sympy_vars)
 
     if algorithm == 'giac':
         return _giac_solver(f, x, solution_dict)
@@ -1136,32 +1242,32 @@ def solve(f, *args, **kwds):
     m = maxima(f)
 
     try:
-        s = m.solve(variables)
+        s = m.solve(x)
     except Exception:  # if Maxima gave an error, try its to_poly_solve
         try:
-            s = m.to_poly_solve(variables)
+            s = m.to_poly_solve(x)
         except TypeError as mess:  # if that gives an error, raise an error.
             if "Error executing code in Maxima" in str(mess):
-                raise ValueError("Sage is unable to determine whether the system %s can be solved for %s" % (f, args))
+                raise ValueError(f"sage is unable to determine whether the system {f} can be solved for {x}")
             else:
                 raise
 
     if len(s) == 0:  # if Maxima's solve gave no solutions, try its to_poly_solve
         try:
-            s = m.to_poly_solve(variables)
+            s = m.to_poly_solve(x)
         except Exception:  # if that gives an error, stick with no solutions
             s = []
 
     if len(s) == 0:  # if to_poly_solve gave no solutions, try use_grobner
         try:
-            s = m.to_poly_solve(variables, 'use_grobner=true')
+            s = m.to_poly_solve(x, 'use_grobner=true')
         except Exception:  # if that gives an error, stick with no solutions
             s = []
 
     sol_list = string_to_list_of_solutions(repr(s))
 
     # Relaxed form suggested by Mike Hansen (#8553):
-    if kwds.get('solution_dict', None):
+    if solution_dict:
         if not sol_list:  # fixes IndexError on empty solution list (#8553)
             return []
         if isinstance(sol_list[0], list):
@@ -1270,6 +1376,9 @@ def _solve_expression(f, x, explicit_solutions, multiplicities,
     """
     from sage.structure.element import Expression
 
+    if isinstance(x, (list, tuple)) and len(x) == 1:
+        x = x[0]
+
     if f.is_relational():
         if f.operator() is not operator.eq:
             if algorithm == 'sympy':
@@ -1292,22 +1401,21 @@ def _solve_expression(f, x, explicit_solutions, multiplicities,
                     return solve_ineq([f])  # trying solve_ineq_fourier
                 except Exception:
                     raise NotImplementedError("solving only implemented for equalities and few special inequalities, see solve_ineq")
-        ex = f
     else:
-        ex = (f == 0)
+        f = (f == 0)
 
     if multiplicities and to_poly_solve:
         raise NotImplementedError("to_poly_solve does not return multiplicities")
     # check if all variables are assumed integer;
     # if so, we have a Diophantine
 
-    def has_integer_assumption(v):
+    def has_integer_assumption(v) -> bool:
         from sage.symbolic.assumptions import assumptions, GenericDeclaration
         alist = assumptions()
         return any(isinstance(a, GenericDeclaration) and a.has(v) and
                    a._assumption in ['even', 'odd', 'integer', 'integervalued']
                    for a in alist)
-    if len(ex.variables()) and all(has_integer_assumption(var) for var in ex.variables()):
+    if len(f.variables()) and all(has_integer_assumption(var) for var in f.variables()):
         return f.solve_diophantine(x, solution_dict=solution_dict)
 
     if algorithm == 'sympy':
@@ -1318,9 +1426,9 @@ def _solve_expression(f, x, explicit_solutions, multiplicities,
         else:
             sympy_vars = tuple([v._sympy_() for v in x])
         if domain == 'real':
-            ret = solveset(ex._sympy_(), sympy_vars[0], S.Reals)
+            ret = solveset(f._sympy_(), sympy_vars[0], S.Reals)
         else:
-            ret = solveset(ex._sympy_(), sympy_vars[0])
+            ret = solveset(f._sympy_(), sympy_vars[0])
         ret = sympy_set_to_list(ret, sympy_vars)
         if solution_dict:
             ret = [{sol.left(): sol.right()} for sol in ret]
@@ -1330,7 +1438,7 @@ def _solve_expression(f, x, explicit_solutions, multiplicities,
         return _giac_solver(f, x, solution_dict)
 
     # from here on, maxima is used for solution
-    m = ex._maxima_()
+    m = f._maxima_()
     P = m.parent()
     if explicit_solutions:
         P.eval('solveexplicit: true')  # switches Maxima to looking for only explicit solutions
@@ -1376,7 +1484,7 @@ def _solve_expression(f, x, explicit_solutions, multiplicities,
     if to_poly_solve:
         if len(X) == 0:
             # Maxima's solve gave no solutions
-            solutions_so_far = [ex]
+            solutions_so_far = [f]
             ignore_exceptions = True
         else:
             solutions_so_far = X
@@ -1440,16 +1548,16 @@ def _giac_solver(f, x, solution_dict=False):
 
         sage: # needs sage.libs.giac
         sage: solve([(2/3)^x-2], [x], algorithm='giac')
-        ...[[-log(2)/(log(3) - log(2))]]
+        [-log(2)/(log(3) - log(2))]
         sage: solve([(2/3)^x-2], [x], algorithm='giac', solution_dict=True)
-        ...[{x: -log(2)/(log(3) - log(2))}]
+        [{x: -log(2)/(log(3) - log(2))}]
 
         sage: # needs sage.libs.giac
         sage: f = (sin(x) - 8*cos(x)*sin(x))*(sin(x)^2 + cos(x)) - (2*cos(x)*sin(x) - sin(x))*(-2*sin(x)^2 + 2*cos(x)^2 - cos(x))
         sage: solve(f, x, algorithm='giac')
-        ...[-2*arctan(sqrt(2)), 0, 2*arctan(sqrt(2)), pi]
+        [-2*arctan(sqrt(2)), 0, 2*arctan(sqrt(2)), pi]
         sage: solve(f, x, algorithm='giac', solution_dict=True)
-        ...[{x: -2*arctan(sqrt(2))}, {x: 0}, {x: 2*arctan(sqrt(2))}, {x: pi}]
+        [{x: -2*arctan(sqrt(2))}, {x: 0}, {x: 2*arctan(sqrt(2))}, {x: pi}]
 
         sage: # needs sage.libs.giac
         sage: x, y = SR.var('x,y')
@@ -1457,7 +1565,12 @@ def _giac_solver(f, x, solution_dict=False):
         [[2, 5], [5, 2]]
     """
     from sage.libs.giac.giac import libgiac
+    f = _normalize_to_list_expressions(_normalize_to_nonrelational(f))
     giac_f = libgiac(f)
+    if isinstance(x, tuple):
+        # Python tuple is translated to giac seq which we don't want
+        # (if its length is > 1 then the library call errors out)
+        x = list(x)
     giac_vars = libgiac(x)
     ret = giac_f.solve(giac_vars)
     sols = ret.sage()
@@ -1698,7 +1811,7 @@ def _solve_mod_prime_power(eqns, p, m, vars):
             pairs = product(shifts, ans)
             possibles = (tuple(vector(t) + vector(shift) * (mrunning // p))
                          for shift, t in pairs)
-        ans = list(t for t in possibles if all(e(*t) == 0 for e in eqns_mod))
+        ans = [t for t in possibles if all(e(*t) == 0 for e in eqns_mod)]
         if not ans:
             return ans
 
