@@ -544,7 +544,7 @@ class GenericCellComplex(SageObject):
              [0,0] x [0,1] x [0,1] - [0,1] x [0,0] x [0,1] + [0,1] x [0,1] x [0,0]
              - [0,1] x [0,1] x [1,1] + [0,1] x [1,1] x [0,1] - [1,1] x [0,1] x [0,1])]
 
-        Similarly for simpicial sets::
+        Similarly for simplicial sets::
 
             sage: S = simplicial_sets.Sphere(2)
             sage: S.homology(generators=True)                                           # needs sage.modules
