@@ -26,7 +26,7 @@ class CharacterArtFactory(SageObject):
                  art_type, string_type, magic_method_name,
                  parenthesis, square_bracet, curly_brace):
         r"""
-        Abstract base class for character art factory
+        Abstract base class for character art factory.
 
         This class is the common implementation behind
         :func:`~sage.typeset.ascii_art.ascii_art` and
@@ -38,10 +38,10 @@ class CharacterArtFactory(SageObject):
           :class:`~sage.typeset.character_art.CharacterArt`)
 
         - ``string_type`` -- type of strings (the lines in the
-          character art, e.g. ``str`` or ``unicode``).
+          character art, e.g. ``str`` or ``unicode``)
 
         - ``magic_method_name`` -- name of the Sage magic method (e.g.
-          ``'_ascii_art_'`` or ``'_unicode_art_'``).
+          ``'_ascii_art_'`` or ``'_unicode_art_'``)
 
         - ``parenthesis`` -- left/right pair of two multi-line
           symbols. The parenthesis, a.k.a. round brackets (used for printing
@@ -78,9 +78,7 @@ class CharacterArtFactory(SageObject):
           we want
         - ``baseline`` -- (optional) the baseline of the object
 
-        OUTPUT:
-
-        Character art object.
+        OUTPUT: character art object
 
         EXAMPLES::
 
@@ -136,11 +134,9 @@ class CharacterArtFactory(SageObject):
 
     def build_empty(self):
         """
-        Return the empty character art object
+        Return the empty character art object.
 
-        OUTPUT:
-
-        Character art instance.
+        OUTPUT: character art instance
 
         EXAMPLES::
 
@@ -152,11 +148,9 @@ class CharacterArtFactory(SageObject):
 
     def build_from_magic_method(self, obj, baseline=None):
         """
-        Return the character art object created by the object's magic method
+        Return the character art object created by the object's magic method.
 
-        OUTPUT:
-
-        Character art instance.
+        OUTPUT: character art instance
 
         EXAMPLES::
 
@@ -183,9 +177,7 @@ class CharacterArtFactory(SageObject):
         - ``obj`` -- utf-8 encoded byte string or unicode
         - ``baseline`` -- (default: 0) the baseline of the object
 
-        OUTPUT:
-
-        Character art instance.
+        OUTPUT: character art instance
 
         EXAMPLES::
 
@@ -416,7 +408,7 @@ class CharacterArtFactory(SageObject):
     def concatenate(self, iterable, separator, empty=None, baseline=0,
                     nested=False):
         r"""
-        Concatenate multiple character art instances
+        Concatenate multiple character art instances.
 
         The breakpoints are set as the breakpoints of the ``separator``
         together with the breakpoints of the objects in ``iterable``.
@@ -477,11 +469,9 @@ class CharacterArtFactory(SageObject):
         top = separator._h - bot
         for obj in iterable:
             bot1 = obj.get_baseline()
-            if bot1 > bot:
-                bot = bot1
+            bot = max(bot1, bot)
             top1 = obj._h - bot1
-            if top1 > top:
-                top = top1
+            top = max(top1, top)
         # bot + top is the new height
 
         def padded_line(obj, i):
@@ -531,7 +521,7 @@ class CharacterArtFactory(SageObject):
 
         INPUT:
 
-        - ``kwds`` -- a dict
+        - ``kwds`` -- dictionary
 
         OUTPUT:
 
